@@ -1,4 +1,4 @@
-# sage.doctest: needs sage.modules sage.rings.finite_rings
+# sage.doctest: needs sage.modules sage.rings.finite_rings sage.symbolic
 r"""
 Guruswami-Sudan decoder for (Generalized) Reed-Solomon codes
 
@@ -25,6 +25,7 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
+from sage.arith.misc import integer_floor as floor
 from sage.coding.grs_code import GeneralizedReedSolomonCode
 from sage.rings.integer_ring import ZZ
 from sage.coding.decoder import Decoder
@@ -35,6 +36,7 @@ from sage.coding.guruswami_sudan.utils import (johnson_radius,
 from sage.functions.other import floor
 from sage.misc.functional import sqrt
 
+
 def n_k_params(C, n_k):
     r"""
     Internal helper function for the :class:`GRSGuruswamiSudanDecoder` class for
@@ -47,14 +49,14 @@ def n_k_params(C, n_k):
 
     INPUT:
 
-    - ``C`` -- A GRS code or ``None``
+    - ``C`` -- a GRS code or ``None``
 
-    - ``n_k`` -- A tuple `(n,k)` being length and dimension of a GRS code, or
-      ``None``.
+    - ``n_k`` -- tuple `(n,k)` being length and dimension of a GRS code, or
+      ``None``
 
     OUTPUT:
 
-    - ``n_k`` -- A tuple `(n,k)` being length and dimension of a GRS code.
+    - ``n_k`` -- tuple `(n,k)` being length and dimension of a GRS code
 
     EXAMPLES::
 
@@ -84,6 +86,7 @@ def n_k_params(C, n_k):
     elif n_k is not None:
         return n_k
 
+
 def roth_ruckenstein_root_finder(p, maxd=None, precision=None):
     """
     Wrapper for Roth-Ruckenstein algorithm to compute the roots of a polynomial
@@ -101,7 +104,8 @@ def roth_ruckenstein_root_finder(p, maxd=None, precision=None):
     gens = p.parent().gens()
     if len(gens) == 2:
         p = p.polynomial(gens[1])
-    return p.roots(multiplicities=False, degree_bound=maxd, algorithm="Roth-Ruckenstein")
+    return p.roots(multiplicities=False, degree_bound=maxd, algorithm='Roth-Ruckenstein')
+
 
 def alekhnovich_root_finder(p, maxd=None, precision=None):
     """
@@ -120,7 +124,8 @@ def alekhnovich_root_finder(p, maxd=None, precision=None):
     gens = p.parent().gens()
     if len(gens) == 2:
         p = p.polynomial(gens[1])
-    return p.roots(multiplicities=False, degree_bound=maxd, algorithm="Alekhnovich")
+    return p.roots(multiplicities=False, degree_bound=maxd, algorithm='Alekhnovich')
+
 
 class GRSGuruswamiSudanDecoder(Decoder):
     r"""
@@ -151,10 +156,10 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     INPUT:
 
-    - ``code`` -- A code associated to this decoder.
+    - ``code`` -- a code associated to this decoder
 
-    - ``tau`` -- (default: ``None``) an integer, the number of errors one wants the
-      Guruswami-Sudan algorithm to correct.
+    - ``tau`` -- integer (default: ``None``); the number of errors one wants the
+      Guruswami-Sudan algorithm to correct
 
     - ``parameters`` -- (default: ``None``) a pair of integers, where:
 
@@ -164,8 +169,8 @@ class GRSGuruswamiSudanDecoder(Decoder):
     - ``interpolation_alg`` -- (default: ``None``) the interpolation algorithm
       that will be used. The following possibilities are currently available:
 
-      * ``"LinearAlgebra"`` -- uses a linear system solver.
-      * ``"LeeOSullivan"`` -- uses Lee O'Sullivan method based on row reduction
+      * ``'LinearAlgebra'`` -- uses a linear system solver.
+      * ``'LeeOSullivan'`` -- uses Lee O'Sullivan method based on row reduction
         of a matrix
       * ``None`` -- one of the above will be chosen based on the size of the
         code and the parameters.
@@ -176,9 +181,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
     - ``root_finder`` -- (default: ``None``) the rootfinding algorithm that will
       be used. The following possibilities are currently available:
 
-      * ``"Alekhnovich"`` -- uses Alekhnovich's algorithm.
+      * ``'Alekhnovich'`` -- uses Alekhnovich's algorithm.
 
-      * ``"RothRuckenstein"`` -- uses Roth-Ruckenstein algorithm.
+      * ``'RothRuckenstein'`` -- uses Roth-Ruckenstein algorithm.
 
       * ``None`` -- one of the above will be chosen based on the size of the
         code and the parameters.
@@ -230,7 +235,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
 
         sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters=(1,2),
-        ....:                                             root_finder="RothRuckenstein"); D
+        ....:                                             root_finder='RothRuckenstein'); D
         Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251)
          decoding 97 errors with parameters (1, 2)
 
@@ -251,7 +256,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         INPUT:
 
-        - ``tau`` -- an integer, number of errors one wants the Guruswami-Sudan
+        - ``tau`` -- integer; number of errors one wants the Guruswami-Sudan
           algorithm to correct
         - ``C`` -- (default: ``None``) a :class:`GeneralizedReedSolomonCode`
         - ``n_k`` -- (default: ``None``) a pair of integers, respectively the
@@ -330,8 +335,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
         - ``C`` -- (default: ``None``) a :class:`GeneralizedReedSolomonCode`
         - ``n_k`` -- (default: ``None``) a pair of integers, respectively the
           length and the dimension of the :class:`GeneralizedReedSolomonCode`
-        - ``s`` -- (default: ``None``) an integer, the multiplicity parameter of Guruswami-Sudan algorithm
-        - ``l`` -- (default: ``None``) an integer, the list size parameter
+        - ``s`` -- integer (default: ``None``); the multiplicity parameter of
+          Guruswami-Sudan algorithm
+        - ``l`` -- integer (default: ``None``); the list size parameter
 
         .. NOTE::
 
@@ -344,8 +350,8 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
           - ``tau`` is the obtained decoding radius, and
 
-          - ``s, ell`` are the multiplicity parameter, respectively list size
-            parameter giving this radius.
+          - ``(s, l)`` are the multiplicity parameter and the list size
+            parameter giving the radius
 
         EXAMPLES::
 
@@ -369,9 +375,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
         """
         n,k = n_k_params(C, n_k)
 
-        def get_tau(s,l):
+        def get_tau(s, l):
             "Return the decoding radius given this s and l"
-            if s<=0 or l<=0:
+            if s <= 0 or l <= 0:
                 return -1
             return gilt(n - n/2*(s+1)/(l+1) - (k-1)/2*l/s)
         if l is None and s is None:
@@ -426,7 +432,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         INPUT:
 
-        - ``tau`` -- an integer, number of errors one wants the Guruswami-Sudan
+        - ``tau`` -- integer; number of errors one wants the Guruswami-Sudan
           algorithm to correct
         - ``C`` -- (default: ``None``) a :class:`GeneralizedReedSolomonCode`
         - ``n_k`` -- (default: ``None``) a pair of integers, respectively the
@@ -482,7 +488,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         atau = n - tau
         smin = tau * w / (atau ** 2 - n * w)
         s = floor(1 + smin)
-        D = (s - smin) * (atau ** 2 - n * w) * s + (w**2) /4
+        D = (s - smin) * (atau ** 2 - n * w) * s + (w**2) / 4
         l = floor(atau / w * s + 0.5 - sqrt(D)/w)
         return (s, l)
 
@@ -496,10 +502,10 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         INPUT:
 
-        - ``tau`` -- an integer, number of errors one expects Guruswami-Sudan algorithm
+        - ``tau`` -- integer; number of errors one expects Guruswami-Sudan algorithm
           to correct
-        - ``s`` -- an integer, multiplicity parameter of Guruswami-Sudan algorithm
-        - ``l`` -- an integer, list size parameter
+        - ``s`` -- integer; multiplicity parameter of Guruswami-Sudan algorithm
+        - ``l`` -- integer; list size parameter
         - ``C`` -- (default: ``None``) a :class:`GeneralizedReedSolomonCode`
         - ``n_k`` -- (default: ``None``) a tuple of integers, respectively the
           length and the dimension of the :class:`GeneralizedReedSolomonCode`
@@ -575,7 +581,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         Same thing for ``root_finder``::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = GSD(C, tau=97, root_finder="FortyTwo")
+            sage: D = GSD(C, tau=97, root_finder='FortyTwo')
             Traceback (most recent call last):
             ...
             ValueError: Please provide a method or one of the allowed strings for root_finder
@@ -659,7 +665,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def __eq__(self, other):
         r"""
-        Tests equality between GRSGuruswamiSudanDecoder objects.
+        Test equality between GRSGuruswamiSudanDecoder objects.
 
         EXAMPLES::
 
@@ -761,7 +767,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         INPUT:
 
         - ``r`` -- a received word, i.e. a vector in `F^n` where `F` and `n` are
-          the base field respectively length of :meth:`self.code`.
+          the base field respectively length of :meth:`self.code`
 
         EXAMPLES::
 
@@ -806,7 +812,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         INPUT:
 
         - ``r`` -- a received word, i.e. a vector in `F^n` where `F` and `n` are
-          the base field respectively length of :meth:`self.code`.
+          the base field respectively length of :meth:`self.code`
 
         EXAMPLES::
 
@@ -827,7 +833,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         TESTS:
 
-        Check that :trac:`21347` is fixed::
+        Check that :issue:`21347` is fixed::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(13).list()[:10], 3)
             sage: D = GSD(C, tau=4)
