@@ -140,7 +140,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
     def __init__(self, base_field, length, default_encoder_name, default_decoder_name, metric='Hamming'):
         """
-        Initializes mandatory parameters that any linear code shares.
+        Initialize mandatory parameters that any linear code shares.
 
         This method only exists for inheritance purposes as it initializes
         parameters that need to be known by every linear code. The class
@@ -231,7 +231,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
           will be used if default value is kept.
 
         - ``kwargs`` -- all additional arguments are forwarded to the construction of the
-          encoder that is used.
+          encoder that is used
 
         EXAMPLES::
 
@@ -246,7 +246,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
     def __eq__(self, other):
         r"""
-        Tests equality between two linear codes.
+        Test equality between two linear codes.
 
         EXAMPLES::
 
@@ -282,9 +282,10 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
     def __ne__(self, other):
         r"""
-        Tests inequality of ``self`` and ``other``.
+        Test inequality of ``self`` and ``other``.
 
-        This is a generic implementation, which returns the inverse of ``__eq__`` for self.
+        This is a generic implementation, which returns the inverse of
+        ``__eq__`` for ``self``.
 
         EXAMPLES::
 
@@ -390,9 +391,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
         r"""
         Return a basis of ``self``.
 
-        OUTPUT:
-
-        -  ``Sequence`` -- an immutable sequence whose universe is ambient space of ``self``.
+        OUTPUT: ``Sequence`` -- an immutable sequence whose universe is ambient space of ``self``
 
         EXAMPLES::
 
@@ -463,9 +462,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
         - ``r`` -- a vector of the same length as ``self``
 
-        OUTPUT:
-
-        - a column vector
+        OUTPUT: a column vector
 
         EXAMPLES::
 
@@ -497,7 +494,8 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
     def __contains__(self, v):
         r"""
-        Return True if `v` can be coerced into ``self``. Otherwise, returns False.
+        Return ``True`` if `v` can be coerced into ``self``.
+        Otherwise, return ``False``.
 
         EXAMPLES::
 
@@ -560,14 +558,12 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
         INPUT:
 
-        - ``return_permutation`` -- (default: ``True``) if ``True``, the column
-          permutation which brings ``self`` into the returned code is also
-          returned.
+        - ``return_permutation`` -- boolean (default: ``True``); if ``True``,
+          the column permutation which brings ``self`` into the returned code
+          is also returned
 
-        OUTPUT:
-
-        - A :class:`LinearCode` whose :meth:`systematic_generator_matrix` is
-          guaranteed to be of the form `[I \vert A]`.
+        OUTPUT: a :class:`LinearCode` whose :meth:`systematic_generator_matrix`
+        is guaranteed to be of the form `[I \vert A]`.
 
         EXAMPLES::
 
@@ -656,9 +652,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
         is called an information set if the corresponding columns
         form a square matrix of full rank.
 
-        OUTPUT:
-
-        - Information set of a systematic generator matrix of the code.
+        OUTPUT: information set of a systematic generator matrix of the code
 
         EXAMPLES::
 
@@ -682,10 +676,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
         - A list of positions, i.e. integers in the range 0 to `n-1` where `n`
           is the length of ``self``.
 
-        OUTPUT:
-
-        - A boolean indicating whether the positions form an information set.
-
+        OUTPUT: boolean indicating whether the positions form an information set
 
         EXAMPLES::
 
@@ -722,7 +713,6 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
             sage: L = list(C)
             sage: L[10].is_immutable()
             True
-
         """
         from sage.modules.finite_submodule_iter import \
                                                 FiniteFieldsubspace_iterator
@@ -755,7 +745,7 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
            ``[i*a^0 * G[0] + a^0*G[1] for i in range(p)]``,
 
         and so on.
-        Hence the `i`-th element can be obtained by the p-adic expansion
+        Hence the `i`-th element can be obtained by the `p`-adic expansion
         of `i` as ``[i_0, i_1, ...,i_{m-1}, i_m, i_{m+1}, ..., i_{km-1}].``
 
         The element that is generated is:
@@ -800,7 +790,6 @@ class AbstractLinearCodeNoMetric(AbstractCode, Module):
 
             sage: C[0].is_immutable()
             True
-
         """
         # IMPORTANT: If the __iter__() function implementation is changed
         # then the implementation here must also be changed so that
@@ -1050,14 +1039,14 @@ class LinearCodeSystematicEncoder(Encoder):
 
     INPUT:
 
-    - ``code`` -- The associated code of this encoder.
+    - ``code`` -- the associated code of this encoder
 
     - ``systematic_positions`` -- (default: ``None``) the positions in codewords that
       should correspond to the message symbols. A list of `k` distinct integers in
       the range 0 to `n-1` where `n` is the length of the code and `k` its
-      dimension. The 0th symbol of a message will then be at position
+      dimension. The `0`-th symbol of a message will then be at position
       ``systematic_positions[0]``, the 1st index at position
-      ``systematic_positions[1]``, etc. A :class:`ValueError` is raised at
+      ``systematic_positions[1]``, etc. A :exc:`ValueError` is raised at
       construction time if the supplied indices do not form an information set.
 
     EXAMPLES:
@@ -1153,7 +1142,7 @@ class LinearCodeSystematicEncoder(Encoder):
 
     def __eq__(self, other):
         r"""
-        Tests equality between LinearCodeSystematicEncoder objects.
+        Test equality between LinearCodeSystematicEncoder objects.
 
         EXAMPLES::
 
@@ -1285,7 +1274,7 @@ class LinearCodeSystematicEncoder(Encoder):
 
     def systematic_permutation(self):
         r"""
-        Return a permutation which would take the systematic positions into [0,..,k-1]
+        Return a permutation which would take the systematic positions into [0,..,k-1].
 
         EXAMPLES::
 
