@@ -23,10 +23,10 @@ called.
     :func:`~sage.combinat.designs.orthogonal_arrays_build_recursive.construction_3_6` | Return a `OA(k,nm+i)`.
     :func:`~sage.combinat.designs.orthogonal_arrays_build_recursive.construction_q_x` | Return an `OA(k,(q-1)*(q-x)+x+2)` using the `q-x` construction.
     :func:`OA_and_oval` | Return a `OA(q+1,q)` whose blocks contains `\leq 2` zeroes in the last `q` columns.
-    :func:`thwart_lemma_3_5` | Returns an `OA(k,nm+a+b+c+d)`.
-    :func:`thwart_lemma_4_1` | Returns an `OA(k,nm+4(n-2))`.
-    :func:`three_factor_product` | Returns an `OA(k+1,n_1n_2n_3)`.
-    :func:`brouwer_separable_design` | Returns a `OA(k,t(q^2+q+1)+x)` using Brouwer's result on separable designs.
+    :func:`thwart_lemma_3_5` | Return an `OA(k,nm+a+b+c+d)`.
+    :func:`thwart_lemma_4_1` | Return an `OA(k,nm+4(n-2))`.
+    :func:`three_factor_product` | Return an `OA(k+1,n_1n_2n_3)`.
+    :func:`brouwer_separable_design` | Return a `OA(k,t(q^2+q+1)+x)` using Brouwer's result on separable designs.
 
 Functions
 ---------
@@ -35,7 +35,7 @@ from itertools import repeat
 from .orthogonal_arrays import orthogonal_array, wilson_construction, is_orthogonal_array
 
 
-def construction_3_3(k,n,m,i,explain_construction=False):
+def construction_3_3(k, n, m, i, explain_construction=False):
     r"""
     Return an `OA(k,nm+i)`.
 
@@ -49,11 +49,11 @@ def construction_3_3(k,n,m,i,explain_construction=False):
 
     INPUT:
 
-    - ``k``, ``n``, ``m``, ``i`` (integers) such that the following designs are
-      available: `OA(k,n)`, `OA(k,m)`, `OA(k,m+1)`, `OA(k,r)`.
+    - ``k``, ``n``, ``m``, ``i`` -- integers such that the following designs are
+      available: `OA(k,n)`, `OA(k,m)`, `OA(k,m+1)`, `OA(k,r)`
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -96,7 +96,8 @@ def construction_3_3(k,n,m,i,explain_construction=False):
     assert is_orthogonal_array(OA,k,n*m+i)
     return OA
 
-def construction_3_4(k,n,m,r,s,explain_construction=False):
+
+def construction_3_4(k, n, m, r, s, explain_construction=False):
     r"""
     Return a `OA(k,nm+rs)`.
 
@@ -123,8 +124,8 @@ def construction_3_4(k,n,m,r,s,explain_construction=False):
       `OA(k,m+1)`, `OA(k,m+2)`, `OA(k,s)`. Additionally, it requires either a
       `OA(k,m+r)` or a `OA(k,m+r+1)`.
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -178,7 +179,8 @@ def construction_3_4(k,n,m,r,s,explain_construction=False):
     OA = wilson_construction(OA,k,n,m,[1]*r+[s],check=False)
     return OA
 
-def construction_3_5(k,n,m,r,s,t,explain_construction=False):
+
+def construction_3_5(k, n, m, r, s, t, explain_construction=False):
     r"""
     Return an `OA(k,nm+r+s+t)`.
 
@@ -190,13 +192,13 @@ def construction_3_5(k,n,m,r,s,t,explain_construction=False):
 
     INPUT:
 
-    - ``k``, ``n``, ``m`` (integers)
+    - ``k``, ``n``, ``m`` -- integers
 
-    - ``r``, ``s``, ``t`` (integers) -- sizes of the three truncated groups,
-      such that `r\leq s` and `(q-r-1)(q-s) \geq (q-s-1)*(q-r)`.
+    - ``r``, ``s``, ``t`` -- integers; sizes of the three truncated groups,
+      such that `r\leq s` and `(q-r-1)(q-s) \geq (q-s-1)*(q-r)`
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     The following designs must be available : `OA(k,n)`, `OA(k,r)`, `OA(k,s)`,
     `OA(k,t)`, `OA(k,m+1)`, `OA(k,m+2)`, `OA(k,m+3)`.
@@ -220,7 +222,6 @@ def construction_3_5(k,n,m,r,s,t,explain_construction=False):
            Concerning eight mutually orthogonal latin squares,
            Vol. 15, n.3, pp. 255-261,
            Journal of Combinatorial Designs, 2007
-
     """
     from .orthogonal_arrays import wilson_construction, OA_relabel
     assert r <= s
@@ -273,9 +274,10 @@ def construction_3_5(k,n,m,r,s,t,explain_construction=False):
     OA = wilson_construction(OA,k,q,m,[r,s,t], check=False)
     return OA
 
-def construction_3_6(k,n,m,i,explain_construction=False):
+
+def construction_3_6(k, n, m, i, explain_construction=False):
     r"""
-    Return a `OA(k,nm+i)`
+    Return a `OA(k,nm+i)`.
 
     This is Wilson's construction with `r` columns of order `1`, in which each
     block intersects at most two truncated columns. Such a design exists when
@@ -283,12 +285,12 @@ def construction_3_6(k,n,m,i,explain_construction=False):
 
     INPUT:
 
-    - ``k``, ``n``, ``m``, ``i`` (integers) -- `n` must be a prime power. The
+    - ``k``, ``n``, ``m``, ``i`` -- integers; `n` must be a prime power. The
       following designs must be available: `OA(k+r,q)`, `OA(k,m)`, `OA(k,m+1)`,
-      `OA(k,m+2)`.
+      `OA(k,m+2)`
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     This is construction 3.6 from [AC07]_.
 
@@ -329,6 +331,7 @@ def construction_3_6(k,n,m,i,explain_construction=False):
     assert is_orthogonal_array(OA,k,n*m+i)
     return OA
 
+
 def OA_and_oval(q, *, solver=None, integrality_tolerance=1e-3):
     r"""
     Return a `OA(q+1,q)` whose blocks contains `\leq 2` zeroes in the last `q`
@@ -346,7 +349,7 @@ def OA_and_oval(q, *, solver=None, integrality_tolerance=1e-3):
 
     - ``q`` -- a prime power
 
-    - ``solver`` -- (default: ``None``) Specify a Mixed Integer Linear
+    - ``solver`` -- (default: ``None``) specify a Mixed Integer Linear
       Programming (MILP) solver to be used. If set to ``None``, the default one
       is used. For more information on MILP solvers and which default solver is
       used, see the method :meth:`solve
@@ -355,7 +358,7 @@ def OA_and_oval(q, *, solver=None, integrality_tolerance=1e-3):
       <sage.numerical.mip.MixedIntegerLinearProgram>`.
 
     - ``integrality_tolerance`` -- parameter for use with MILP solvers over an
-      inexact base ring; see :meth:`MixedIntegerLinearProgram.get_values`.
+      inexact base ring; see :meth:`MixedIntegerLinearProgram.get_values`
 
     .. NOTE::
 
@@ -366,7 +369,6 @@ def OA_and_oval(q, *, solver=None, integrality_tolerance=1e-3):
 
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import OA_and_oval
         sage: _ = OA_and_oval
-
     """
     from sage.arith.misc import is_prime_power
     from sage.combinat.designs.block_design import projective_plane
@@ -482,13 +484,12 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
         - `OA(k,q)-q.OA(k,1)`
         - `OA(k,x+2)`
 
-    - ``check`` -- (boolean) Whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to
-      ``True`` by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -536,9 +537,9 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
 
     # Add rows, extended with p1 and p2
     p1 = q**2
-    p2 = p1+1
-    TD.extend([[ii*q+i for ii in range(q)]+[p1] for i in range(1,q)])
-    TD.append( [ii*q   for ii in range(q)]+[p1,p2])
+    p2 = p1 + 1
+    TD.extend([ii*q + i for ii in range(q)] + [p1] for i in range(1, q))
+    TD.append([ii*q for ii in range(q)] + [p1, p2])
 
     # Add Columns. We do not add some columns which would have size 1 after we
     # delete points.
@@ -577,9 +578,9 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
     return OA
 
 
-def thwart_lemma_3_5(k,n,m,a,b,c,d=0,complement=False,explain_construction=False):
+def thwart_lemma_3_5(k, n, m, a, b, c, d=0, complement=False, explain_construction=False):
     r"""
-    Returns an `OA(k,nm+a+b+c+d)`
+    Return an `OA(k,nm+a+b+c+d)`.
 
     *(When `d=0`)*
 
@@ -637,14 +638,14 @@ def thwart_lemma_3_5(k,n,m,a,b,c,d=0,complement=False,explain_construction=False
     INPUT:
 
     - ``k``, ``n``, ``m``, ``a``, ``b``, ``c``, ``d`` -- integers which must
-      satisfy the constraints above. In particular, `a+b+c\leq n+1` must hold.
+      satisfy the constraints above. In particular, `a+b+c\leq n+1` must hold
       By default, `d=0`.
 
-    - ``complement`` (boolean) -- whether to complement the sets, i.e. follow
-      the `n-a,n-b,n-c` variant described above.
+    - ``complement`` -- boolean; whether to complement the sets, i.e. follow
+      the `n-a,n-b,n-c` variant described above
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -755,9 +756,10 @@ def thwart_lemma_3_5(k,n,m,a,b,c,d=0,complement=False,explain_construction=False
 
     return wilson_construction(OA,k,n,m,sizes, check=False)
 
-def thwart_lemma_4_1(k,n,m,explain_construction=False):
+
+def thwart_lemma_4_1(k, n, m, explain_construction=False):
     r"""
-    Returns an `OA(k,nm+4(n-2))`.
+    Return an `OA(k,nm+4(n-2))`.
 
     Implements Lemma 4.1 from [Thwarts]_.
 
@@ -777,10 +779,10 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
 
     INPUT:
 
-    - ``k``, ``n``, ``m`` (integers)
+    - ``k``, ``n``, ``m`` -- integers
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -883,9 +885,10 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
 
     return wilson_construction(OA,k,n,m,[n-2,]*4,check=False)
 
-def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
+
+def three_factor_product(k, n1, n2, n3, check=False, explain_construction=False):
     r"""
-    Returns an `OA(k+1,n_1n_2n_3)`
+    Return an `OA(k+1,n_1n_2n_3)`.
 
     The three factor product construction from [DukesLing14]_ does the following:
 
@@ -949,14 +952,14 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
 
     INPUT:
 
-    - ``k``, ``n1``, ``n2``, ``n3`` (integers)
+    - ``k``, ``n1``, ``n2``, ``n3`` -- integers
 
-    - ``check`` -- (boolean) Whether to check that everything is going smoothly
+    - ``check`` -- boolean; whether to check that everything is going smoothly
       while the design is being built. It is disabled by default, as the
       constructor of orthogonal arrays checks the final design anyway.
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -1007,7 +1010,7 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
                 "   A three-factor product construction for mutually orthogonal latin squares,\n" +
                 "   https://arxiv.org/abs/1401.1466").format(n1, n2, n3)
 
-    def assert_c_partition(classs,k,n,c):
+    def assert_c_partition(classs, k, n, c):
         r"""
         Makes sure that ``classs`` contains blocks `B` of size `k` such that the list of
         ``B[i]`` covers `[n]` exactly `c` times for every index `i`.
@@ -1018,13 +1021,13 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
         for p in zip(*classs):
             assert all(x == i//c for i,x in enumerate(sorted(p))), "A class is not c(={})-parallel".format(c)
 
-    def product_with_parallel_classes(OA1,k,g1,g2,g1_parall,parall,check=True):
+    def product_with_parallel_classes(OA1, k, g1, g2, g1_parall, parall, check=True):
         r"""
-        Returns the product of two OA while keeping track of parallel classes
+        Return the product of two OA while keeping track of parallel classes.
 
         INPUT:
 
-        - ``OA1`` (an `OA(k,g_1)`
+        - ``OA1`` -- (an `OA(k,g_1)`
 
         - ``k``, ``g1``, ``g2`` -- integers
 
@@ -1040,7 +1043,7 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
 
         Two lists of classes ``g1_parall`` and ``parallel`` which are respectively
         `g_1`-parallel and parallel classes such that ``g1_parall+parallel`` is an
-        `OA(k,g1*g2)``.
+        ``OA(k,g1*g2)``.
         """
         if check:
             for classs in g1_parall:
@@ -1148,6 +1151,7 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
 
     return OA
 
+
 def _reorder_matrix(matrix):
     r"""
     Return a matrix which is obtained from ``matrix`` by permutation of each row
@@ -1187,7 +1191,7 @@ def _reorder_matrix(matrix):
     g.add_edges((x,N+i) for i,S in enumerate(matrix) for x in S)
     matrix = []
     for _ in range(k):
-        matching = g.matching(algorithm="LP")
+        matching = g.matching(algorithm='LP')
         col = [0]*N
         for x,i,_ in matching:
             if i < N:
@@ -1198,9 +1202,10 @@ def _reorder_matrix(matrix):
 
     return list(zip(*matrix))
 
-def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construction=False):
+
+def brouwer_separable_design(k, t, q, x, check=False, verbose=False, explain_construction=False):
     r"""
-    Returns a `OA(k,t(q^2+q+1)+x)` using Brouwer's result on separable designs.
+    Return a `OA(k,t(q^2+q+1)+x)` using Brouwer's result on separable designs.
 
     This method is an implementation of Brouwer's construction presented in
     [Brouwer80]_. It consists in a systematic application of the usual
@@ -1323,16 +1328,16 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
 
     INPUT:
 
-    - ``k``, ``t``, ``q``, ``x`` (integers)
+    - ``k``, ``t``, ``q``, ``x`` -- integers
 
-    - ``check`` -- (boolean) Whether to check that output is correct before
-      returning it. Set to ``False`` by default.
+    - ``check`` -- boolean (default: ``False``); whether to check that output
+      is correct before returning it
 
-    - ``verbose`` (boolean) -- whether to print some information on the
-      construction and parameters being used.
+    - ``verbose`` -- boolean; whether to print some information on the
+      construction and parameters being used
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
     .. SEEALSO::
 
@@ -1448,9 +1453,9 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         else:
             partition_of_blocks_of_size_t[plane-t].append([relabel[xx] for xx in B if xx % m < t])
 
-    ###############################################################################
+    ###########################################################################
     # Separable design built !
-    #-------------------------
+    # ------------------------
     #
     # At this point we have a PBD on t*(q**2+q+1) points. Its blocks are
     # split into:
@@ -1461,7 +1466,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
     # - blocks_of_size_q_plus_t : contains all t*(q**2+q+1)blocks of size q+t,
     #                             covering the same number of points: it is a
     #                             symmetric design.
-    ###############################################################################
+    ###########################################################################
 
     ##############################################
     # Part 2: Build an OA on t(q^2+q+1)+x points #
