@@ -64,13 +64,15 @@ from sage.misc.cachefunc import cached_function
 from sage.combinat.designs.incidence_structures import IncidenceStructure
 
 # Construction 1
+
+
 def two_n(B):
     r"""
     Return a Steiner Quadruple System on `2n` points.
 
     INPUT:
 
-    - ``B`` -- A Steiner Quadruple System on `n` points.
+    - ``B`` -- a Steiner Quadruple System on `n` points
 
     EXAMPLES::
 
@@ -80,7 +82,6 @@ def two_n(B):
         ....:         sqs = designs.steiner_quadruple_system(n)
         ....:         if not two_n(sqs).is_t_design(3,2*n,4,1):
         ....:             print("Something is wrong !")
-
     """
     n = B.num_points()
     Y = []
@@ -90,7 +91,7 @@ def two_n(B):
         for a in range(2):
             for b in range(2):
                 for c in range(2):
-                    d = (a+b+c)%2
+                    d = (a+b+c) % 2
                     Y.append([x+a*n,y+b*n,z+c*n,t+d*n])
 
     # Line 2
@@ -101,13 +102,15 @@ def two_n(B):
     return IncidenceStructure(2*n,Y,check=False,copy=False)
 
 # Construction 2
+
+
 def three_n_minus_two(B):
     """
     Return a Steiner Quadruple System on `3n-2` points.
 
     INPUT:
 
-    - ``B`` -- A Steiner Quadruple System on `n` points.
+    - ``B`` -- a Steiner Quadruple System on `n` points
 
     EXAMPLES::
 
@@ -122,13 +125,13 @@ def three_n_minus_two(B):
     A = n-1
     Y = []
     # relabel function
-    r = lambda i,x : (i%3)*(n-1)+x
+    r = lambda i,x : (i % 3)*(n-1)+x
     for x,y,z,t in B._blocks:
         if t == A:
             # Line 2.
             for a in range(3):
                 for b in range(3):
-                    c = -(a+b)%3
+                    c = -(a+b) % 3
                     Y.append([r(a,x),r(b,y),r(c,z),3*n-3])
 
             # Line 3.
@@ -141,7 +144,7 @@ def three_n_minus_two(B):
             for a in range(3):
                 for b in range(3):
                     for c in range(3):
-                        d = -(a+b+c)%3
+                        d = -(a+b+c) % 3
                         Y.append([r(a,x),r(b,y),r(c,z),r(d,t)])
 
     # Line 4.
@@ -156,13 +159,15 @@ def three_n_minus_two(B):
     return IncidenceStructure(3*n-2,Y,check=False,copy=False)
 
 # Construction 3
+
+
 def three_n_minus_eight(B):
     r"""
     Return a Steiner Quadruple System on `3n-8` points.
 
     INPUT:
 
-    - ``B`` -- A Steiner Quadruple System on `n` points.
+    - ``B`` -- a Steiner Quadruple System on `n` points
 
     EXAMPLES::
 
@@ -172,15 +177,14 @@ def three_n_minus_eight(B):
         ....:         sqs = designs.steiner_quadruple_system(n)
         ....:         if not three_n_minus_eight(sqs).is_t_design(3,3*n-8,4,1):
         ....:             print("Something is wrong !")
-
     """
     n = B.num_points()
 
-    if (n%12) != 2:
+    if (n % 12) != 2:
         raise ValueError("n must be equal to 2 mod 12")
 
     B = relabel_system(B)
-    r = lambda i,x : (i%3)*(n-4)+(x%(n-4))
+    r = lambda i,x : (i % 3)*(n-4)+(x % (n-4))
 
     # Line 1.
     Y = [[x+2*(n-4) for x in B._blocks[-1]]]
@@ -188,13 +192,13 @@ def three_n_minus_eight(B):
     # Line 2.
     for s in B._blocks[:-1]:
         for i in range(3):
-            Y.append([r(i,x) if x<= n-5 else x+2*(n-4) for x in s])
+            Y.append([r(i,x) if x <= n-5 else x+2*(n-4) for x in s])
 
     # Line 3.
     for a in range(4):
         for aa in range(n-4):
             for aaa in range(n-4):
-                aaaa = -(a+aa+aaa)%(n-4)
+                aaaa = -(a+aa+aaa) % (n-4)
                 Y.append([r(0,aa),r(1,aaa), r(2,aaaa),3*(n-4)+a])
 
     # Line 4.
@@ -202,7 +206,7 @@ def three_n_minus_eight(B):
     for i in range(3):
         for b in range(n-4):
             for bb in range(n-4):
-                bbb = -(b+bb)%(n-4)
+                bbb = -(b+bb) % (n-4)
                 for d in range(2*k+1):
                     Y.append([r(i+2,bbb), r(i, b+2*k+1+i*(4*k+2)-d) , r(i, b+2*k+2+i*(4*k+2)+d), r(i+1,bb)])
 
@@ -216,14 +220,16 @@ def three_n_minus_eight(B):
     return IncidenceStructure(3*n-8,Y,check=False,copy=False)
 
 # Construction 4
+
+
 def three_n_minus_four(B):
     r"""
     Return a Steiner Quadruple System on `3n-4` points.
 
     INPUT:
 
-    - ``B`` -- A Steiner Quadruple System on `n` points where `n\equiv
-      10\pmod{12}`.
+    - ``B`` -- a Steiner Quadruple System on `n` points where `n\equiv
+      10\pmod{12}`
 
     EXAMPLES::
 
@@ -233,21 +239,20 @@ def three_n_minus_four(B):
         ....:         sqs = designs.steiner_quadruple_system(n)
         ....:         if not three_n_minus_four(sqs).is_t_design(3,3*n-4,4,1):
         ....:             print("Something is wrong !")
-
     """
     n = B.num_points()
 
-    if n%12 != 10:
+    if n % 12 != 10:
         raise ValueError("n must be equal to 10 mod 12")
 
     B = relabel_system(B)
-    r = lambda i,x : (i%3)*(n-2)+(x%(n-2))
+    r = lambda i,x : (i % 3)*(n-2)+(x % (n-2))
 
     # Line 1/2.
     Y = []
     for s in B._blocks:
         for i in range(3):
-            Y.append([r(i,x) if x<= n-3 else x+2*(n-2) for x in s])
+            Y.append([r(i,x) if x <= n-3 else x+2*(n-2) for x in s])
 
     # Line 3.
     for a in range(2):
@@ -261,7 +266,7 @@ def three_n_minus_four(B):
     for i in range(3):
         for b in range(n-2):
             for bb in range(n-2):
-                bbb = -(b+bb)%(n-2)
+                bbb = -(b+bb) % (n-2)
                 for d in range(2*k+1):
                     Y.append([r(i+2,bbb), r(i, b+2*k+1+i*(4*k+2)-d) , r(i, b+2*k+2+i*(4*k+2)+d), r(i+1,bb)])
 
@@ -281,13 +286,15 @@ def three_n_minus_four(B):
     return IncidenceStructure(3*n-4,Y,check=False,copy=False)
 
 # Construction 5
+
+
 def four_n_minus_six(B):
     """
     Return a Steiner Quadruple System on `4n-6` points.
 
     INPUT:
 
-    - ``B`` -- A Steiner Quadruple System on `n` points.
+    - ``B`` -- a Steiner Quadruple System on `n` points
 
     EXAMPLES::
 
@@ -297,18 +304,17 @@ def four_n_minus_six(B):
         ....:         sqs = designs.steiner_quadruple_system(n)
         ....:         if not four_n_minus_six(sqs).is_t_design(3,4*n-6,4,1):
         ....:             print("Something is wrong !")
-
     """
     n = B.num_points()
     f = n-2
-    r = lambda i,ii,x : (2*(i%2)+(ii%2))*(n-2)+(x)%(n-2)
+    r = lambda i,ii,x : (2*(i % 2)+(ii % 2))*(n-2)+(x) % (n-2)
 
     # Line 1.
     Y = []
     for s in B._blocks:
         for i in range(2):
             for ii in range(2):
-                Y.append([r(i,ii,x) if x<= n-3 else x+3*(n-2) for x in s])
+                Y.append([r(i,ii,x) if x <= n-3 else x+3*(n-2) for x in s])
 
     # Line 2/3/4/5
     k = f // 2
@@ -316,7 +322,7 @@ def four_n_minus_six(B):
         for eps in range(2):
             for c in range(k):
                 for cc in range(k):
-                    ccc = -(c+cc)%k
+                    ccc = -(c+cc) % k
                     Y.append([4*(n-2)+l, r(0,0,2*c)  , r(0,1,2*cc-eps)  , r(1,eps,2*ccc+l)  ])
                     Y.append([4*(n-2)+l, r(0,0,2*c+1), r(0,1,2*cc-1-eps), r(1,eps,2*ccc+1-l)])
                     Y.append([4*(n-2)+l, r(1,0,2*c)  , r(1,1,2*cc-eps)  , r(0,eps,2*ccc+1-l)])
@@ -329,7 +335,7 @@ def four_n_minus_six(B):
                 assert len(barP(ccc,k)) == k-1
                 for rc,sc in barP(ccc,k):
                     for c in range(k):
-                        cc = -(c+ccc)%k
+                        cc = -(c+ccc) % k
                         Y.append([r(h,0,2*c+eps)  , r(h,1,2*cc-eps), r(h+1,0,rc), r(h+1,0,sc)])
                         Y.append([r(h,0,2*c-1+eps), r(h,1,2*cc-eps), r(h+1,1,rc), r(h+1,1,sc)])
 
@@ -339,7 +345,7 @@ def four_n_minus_six(B):
             for ccc in range(k):
                 for rc,sc in barP(k+ccc,k):
                     for c in range(k):
-                        cc = -(c+ccc)%k
+                        cc = -(c+ccc) % k
                         Y.append([r(h,0,2*c+eps)  , r(h,1,2*cc-eps), r(h+1,1,rc), r(h+1,1,sc)])
                         Y.append([r(h,0,2*c-1+eps), r(h,1,2*cc-eps), r(h+1,0,rc), r(h+1,0,sc)])
 
@@ -353,13 +359,15 @@ def four_n_minus_six(B):
     return IncidenceStructure(4*n-6,Y,check=False,copy=False)
 
 # Construction 6
+
+
 def twelve_n_minus_ten(B):
     """
     Return a Steiner Quadruple System on `12n-6` points.
 
     INPUT:
 
-    - ``B`` -- A Steiner Quadruple System on `n` points.
+    - ``B`` -- a Steiner Quadruple System on `n` points
 
     EXAMPLES::
 
@@ -369,26 +377,25 @@ def twelve_n_minus_ten(B):
         ....:         sqs = designs.steiner_quadruple_system(n)
         ....:         if not twelve_n_minus_ten(sqs).is_t_design(3,12*n-10,4,1):
         ....:             print("Something is wrong !")
-
     """
     n = B.num_points()
     B14 = steiner_quadruple_system(14)
-    r = lambda i,x : i%(n-1)+(x%12)*(n-1)
+    r = lambda i,x : i % (n-1)+(x % 12)*(n-1)
 
     # Line 1.
     Y = []
     for s in B14._blocks:
         for i in range(n-1):
-            Y.append([r(i,x) if x<= 11 else r(n-2,11)+x-11 for x in s])
+            Y.append([r(i,x) if x <= 11 else r(n-2,11)+x-11 for x in s])
 
     for s in B._blocks:
         if s[-1] == n-1:
             u,v,w,B = s
             dd = {0:u,1:v,2:w}
-            d = lambda x:dd[x%3]
+            d = lambda x:dd[x % 3]
             for b in range(12):
                 for bb in range(12):
-                    bbb = -(b+bb)%12
+                    bbb = -(b+bb) % 12
                     for h in range(2):
                         # Line 2
                         Y.append([r(n-2,11)+1+h,r(u,b),r(v,bb),r(w,bbb+3*h)])
@@ -446,18 +453,19 @@ def twelve_n_minus_ten(B):
             for a in range(12):
                 for aa in range(12):
                     for aaa in range(12):
-                        aaaa = -(a+aa+aaa)%12
+                        aaaa = -(a+aa+aaa) % 12
                         # Line 3
                         Y.append([r(x,a), r(y,aa), r(z,aaa), r(t,aaaa)])
     return IncidenceStructure(12*n-10,Y,check=False,copy=False)
 
+
 def relabel_system(B):
     r"""
-    Relabels the set so that `\{n-4, n-3, n-2, n-1\}` is in `B`.
+    Relabel the set so that `\{n-4, n-3, n-2, n-1\}` is in `B`.
 
     INPUT:
 
-    - ``B`` -- a list of 4-uples on `0,...,n-1`.
+    - ``B`` -- list of 4-uples on `0,...,n-1`
 
     EXAMPLES::
 
@@ -487,9 +495,10 @@ def relabel_system(B):
     B = [[get_label(_) for _ in s] for s in B]
     return IncidenceStructure(n,B)
 
+
 def P(alpha, m):
     r"""
-    Return the collection of pairs `P_{\alpha}(m)`
+    Return the collection of pairs `P_{\alpha}(m)`.
 
     For more information on this system, see [Han1960]_.
 
@@ -501,28 +510,28 @@ def P(alpha, m):
     """
     if alpha >= 2*m-1:
         raise Exception
-    if m%2==0:
+    if m % 2 == 0:
         if alpha < m:
-            if alpha%2 == 0:
+            if alpha % 2 == 0:
                 b = alpha // 2
-                return [(2*a, (2*a + 2*b + 1)%(2*m)) for a in range(m)]
+                return [(2*a, (2*a + 2*b + 1) % (2*m)) for a in range(m)]
             else:
                 b = (alpha-1) // 2
-                return [(2*a, (2*a - 2*b - 1)%(2*m)) for a in range(m)]
+                return [(2*a, (2*a - 2*b - 1) % (2*m)) for a in range(m)]
         else:
             y = alpha - m
-            pairs = [(b,(2*y-b)%(2*m)) for b in range(y)]
-            pairs += [(c,(2*m+2*y-c-2)%(2*m)) for c in range(2*y+1,m+y-1)]
+            pairs = [(b,(2*y-b) % (2*m)) for b in range(y)]
+            pairs += [(c,(2*m+2*y-c-2) % (2*m)) for c in range(2*y+1,m+y-1)]
             pairs += [(2*m+int(-1.5-.5*(-1)**y),y),(2*m+int(-1.5+.5*(-1)**y),m+y-1)]
             return pairs
     else:
         if alpha < m-1:
             if alpha % 2 == 0:
                 b = alpha // 2
-                return [(2*a,(2*a+2*b+1)%(2*m)) for a in range(m)]
+                return [(2*a,(2*a+2*b+1) % (2*m)) for a in range(m)]
             else:
                 b = (alpha-1) // 2
-                return [(2*a,(2*a-2*b-1)%(2*m)) for a in range(m)]
+                return [(2*a,(2*a-2*b-1) % (2*m)) for a in range(m)]
         else:
             y = alpha-m+1
             pairs = [(b,2*y-b) for b in range(y)]
@@ -530,7 +539,8 @@ def P(alpha, m):
             pairs += [(y,m+y)]
             return pairs
 
-def _missing_pair(n,l):
+
+def _missing_pair(n, l):
     r"""
     Return the smallest `(x,x+1)` that is not contained in `l`.
 
@@ -552,7 +562,7 @@ def _missing_pair(n,l):
 
 def barP(eps, m):
     r"""
-    Return the collection of pairs `\overline P_{\alpha}(m)`
+    Return the collection of pairs `\overline P_{\alpha}(m)`.
 
     For more information on this system, see [Han1960]_.
 
@@ -564,10 +574,11 @@ def barP(eps, m):
     """
     return barP_system(m)[eps]
 
+
 @cached_function
 def barP_system(m):
     r"""
-    Return the 1-factorization of `K_{2m}` `\overline P(m)`
+    Return the 1-factorization of `K_{2m}` `\overline P(m)`.
 
     For more information on this system, see [Han1960]_.
 
@@ -591,8 +602,8 @@ def barP_system(m):
         # pairs. Those are added to 'last', a new list of pairs
         last = []
         for n in range(1, (m-2)//2+1):
-            pairs.append([p for p in P(2*n,m) if not isequal(p,(2*n,(4*n+1)%(2*m)))])
-            last.append((2*n,(4*n+1)%(2*m)))
+            pairs.append([p for p in P(2*n,m) if not isequal(p,(2*n,(4*n+1) % (2*m)))])
+            last.append((2*n,(4*n+1) % (2*m)))
             pairs.append([p for p in P(2*n-1,m) if not isequal(p,(2*m-2-2*n,2*m-1-4*n))])
             last.append((2*m-2-2*n,2*m-1-4*n))
 
@@ -618,12 +629,12 @@ def barP_system(m):
         # Now the points must be relabeled
         relabel = {}
         for n in range(1, (m-2)//2+1):
-            relabel[2*n] = (4*n)%(2*m)
-            relabel[4*n+1] = (4*n+1)%(2*m)
-            relabel[2*m-2-2*n] = (4*n-2)%(2*m)
-            relabel[2*m-1-4*n] = (4*n-1)%(2*m)
+            relabel[2*n] = (4*n) % (2*m)
+            relabel[4*n+1] = (4*n+1) % (2*m)
+            relabel[2*m-2-2*n] = (4*n-2) % (2*m)
+            relabel[2*m-1-4*n] = (4*n-1) % (2*m)
 
-        relabel[2*m-2] = (1)%(2*m)
+        relabel[2*m-2] = (1) % (2*m)
         relabel[0] = 0
         relabel[2*m-1] = 2*m-1
         relabel[1] = 2*m-2
@@ -634,8 +645,8 @@ def barP_system(m):
 
         last = []
         for n in range((m - 3) // 2 + 1):
-            pairs.append([p for p in P(2*n,m) if not isequal(p,(2*n,(4*n+1)%(2*m)))])
-            last.append((2*n,(4*n+1)%(2*m)))
+            pairs.append([p for p in P(2*n,m) if not isequal(p,(2*n,(4*n+1) % (2*m)))])
+            last.append((2*n,(4*n+1) % (2*m)))
             pairs.append([p for p in P(2*n+1,m) if not isequal(p,(2*m-2-2*n,2*m-3-4*n))])
             last.append((2*m-2-2*n,2*m-3-4*n))
 
@@ -656,11 +667,11 @@ def barP_system(m):
         # Now the points must be relabeled
         relabel = {}
         for n in range((m - 3) // 2 + 1):
-            relabel[2*n] = (4*n)%(2*m)
-            relabel[4*n+1] = (4*n+1)%(2*m)
-            relabel[2*m-2-2*n] = (4*n+2)%(2*m)
-            relabel[2*m-3-4*n] = (4*n+3)%(2*m)
-        relabel[m-1] = (2*m-2)%(2*m)
+            relabel[2*n] = (4*n) % (2*m)
+            relabel[4*n+1] = (4*n+1) % (2*m)
+            relabel[2*m-2-2*n] = (4*n+2) % (2*m)
+            relabel[2*m-3-4*n] = (4*n+3) % (2*m)
+        relabel[m-1] = (2*m-2) % (2*m)
         relabel[2*m-1] = 2*m-1
 
     assert len(relabel) == 2*m
@@ -676,6 +687,7 @@ def barP_system(m):
 
     return pairs
 
+
 @cached_function
 def steiner_quadruple_system(n, check=False):
     r"""
@@ -683,10 +695,10 @@ def steiner_quadruple_system(n, check=False):
 
     INPUT:
 
-    - ``n`` -- an integer such that `n\equiv 2,4\pmod 6`
+    - ``n`` -- integer such that `n\equiv 2,4\pmod 6`
 
-    - ``check`` (boolean) -- whether to check that the system is a Steiner
-      Quadruple System before returning it (`False` by default)
+    - ``check`` -- boolean (default: ``False``); whether to check that the
+      system is a Steiner Quadruple System before returning it
 
     EXAMPLES::
 
@@ -709,7 +721,7 @@ def steiner_quadruple_system(n, check=False):
         ....:         sqs = designs.steiner_quadruple_system(n, check=True)
     """
     n = int(n)
-    if not ((n%6) in [2, 4]):
+    if (n % 6) not in [2, 4]:
         raise ValueError("n mod 6 must be equal to 2 or 4")
     elif n == 4:
         sqs = IncidenceStructure(4, [[0,1,2,3]], copy=False, check=False)
@@ -717,22 +729,22 @@ def steiner_quadruple_system(n, check=False):
         sqs = IncidenceStructure(14, _SQS14(), copy=False, check=False)
     elif n == 38:
         sqs = IncidenceStructure(38, _SQS38(), copy=False, check=False)
-    elif n%12 in [4, 8]:
+    elif n % 12 in [4, 8]:
         nn = n // 2
         sqs = two_n(steiner_quadruple_system(nn, check=False))
-    elif n%18 in [4,10]:
+    elif n % 18 in [4,10]:
         nn = (n+2) // 3
         sqs = three_n_minus_two(steiner_quadruple_system(nn, check=False))
-    elif (n%36) == 34:
+    elif (n % 36) == 34:
         nn = (n+8) // 3
         sqs = three_n_minus_eight(steiner_quadruple_system(nn, check=False))
-    elif (n%36) == 26:
+    elif (n % 36) == 26:
         nn = (n+4) // 3
         sqs = three_n_minus_four(steiner_quadruple_system(nn, check=False))
-    elif n%24 in [2, 10]:
+    elif n % 24 in [2, 10]:
         nn = (n+6) // 4
         sqs = four_n_minus_six(steiner_quadruple_system(nn, check=False))
-    elif n%72 in [14, 38]:
+    elif n % 72 in [14, 38]:
         nn = (n+10) // 12
         sqs = twelve_n_minus_ten(steiner_quadruple_system(nn, check=False))
     else:
@@ -743,6 +755,7 @@ def steiner_quadruple_system(n, check=False):
 
     return sqs
 
+
 def _SQS14():
     r"""
     Return a Steiner Quadruple System on 14 points.
@@ -776,6 +789,7 @@ def _SQS14():
             [6, 8, 10, 12], [6, 9, 11, 12], [7, 8, 10, 13], [7, 8, 11, 12], [7, 9, 10, 12],
             [8, 9, 10, 11]]
 
+
 def _SQS38():
     r"""
     Return a Steiner Quadruple System on 14 points.
