@@ -81,7 +81,7 @@ class ShuffleProduct_abstract(Parent):
 
             sage: from sage.combinat.shuffle import ShuffleProduct
             sage: SP = ShuffleProduct([1,2],[4,5,7,8,9])
-            sage: TestSuite(SP).run(skip="_test_an_element")
+            sage: TestSuite(SP).run(skip='_test_an_element')
         """
         self._l1 = l1
         self._l2 = l2
@@ -140,7 +140,7 @@ class ShuffleProduct_abstract(Parent):
 
     def __ne__(self, other):
         """
-        Test for unequality
+        Test for unequality.
 
         EXAMPLES::
 
@@ -205,7 +205,7 @@ class SetShuffleProduct(ShuffleProduct_abstract):
 
         - ``l1``, ``l2`` -- iterable: the sets to shuffle
 
-        - ``element_constructor`` --  constructor for the returned elements
+        - ``element_constructor`` -- constructor for the returned elements
 
         TESTS::
 
@@ -213,7 +213,7 @@ class SetShuffleProduct(ShuffleProduct_abstract):
             sage: X = SetShuffleProduct({(1,2,3), (2,3,4)}, {(5,)})
             sage: X   # random
             Shuffle set product of: [(2, 3, 4), (1, 2, 3)] and [(5,)]
-            sage: TestSuite(X).run(skip="_test_an_element")
+            sage: TestSuite(X).run(skip='_test_an_element')
 
             sage: list(SetShuffleProduct({(1,2,3), (2,3,4)}, {(5,)}))   # random
             [[2, 3, 4, 5], [2, 5, 3, 4], [5, 2, 3, 4], [2, 3, 5, 4],
@@ -243,7 +243,6 @@ class SetShuffleProduct(ShuffleProduct_abstract):
             Shuffle set product of: [[1, 2], [3, 4]] and [[1, 4]]
             sage: SetShuffleProduct([()], [[1,4]])
             Shuffle set product of: [()] and [[1, 4]]
-
         """
         return "Shuffle set product of: %s and %s" % (self._element_constructor_(self._l1),
                                                       self._element_constructor_(self._l2))
@@ -259,7 +258,6 @@ class SetShuffleProduct(ShuffleProduct_abstract):
             [       [ o,   o   ] ]
             [       [     / \  ] ]
             [ [  ], [    o   o ] ] and [ [ 1, 4 ] ]
-
         """
         from sage.typeset.ascii_art import ascii_art
         return (ascii_art("Set shuffle product of:") *
@@ -334,7 +332,6 @@ class ShuffleProduct(ShuffleProduct_abstract):
          'abdec']
         sage: list(ShuffleProduct("", "de", element_constructor="".join))
         ['de']
-
     """
 
     def __init__(self, l1, l2, element_constructor=None):
@@ -345,7 +342,7 @@ class ShuffleProduct(ShuffleProduct_abstract):
 
         - ``l1``, ``l2`` -- iterable: iterables to shuffle
 
-        - ``element_constructor``:  constructor for the returned elements
+        - ``element_constructor`` -- constructor for the returned elements
 
         TESTS::
 
@@ -353,7 +350,7 @@ class ShuffleProduct(ShuffleProduct_abstract):
             sage: SP = ShuffleProduct([1,2,3],[4,5])
             sage: SP
             Shuffle product of: [1, 2, 3] and [4, 5]
-            sage: TestSuite(SP).run(skip="_test_an_element")
+            sage: TestSuite(SP).run(skip='_test_an_element')
 
             sage: list(ShuffleProduct(Word("aa"), Word("bbb"), Word))
             [word: aabbb, word: baabb, word: ababb, word: bbaab, word: babab, word: abbab,
@@ -567,7 +564,7 @@ class ShuffleProduct_overlapping_r(ShuffleProduct_abstract):
             sage: from sage.combinat.shuffle import ShuffleProduct_overlapping_r
             sage: w, u = map(Words(range(20)), [[2, 9], [9, 1]])
             sage: S = ShuffleProduct_overlapping_r(w,u,1)
-            sage: TestSuite(S).run(skip="_test_an_element")
+            sage: TestSuite(S).run(skip='_test_an_element')
         """
         self.r = r
         self.add = add
@@ -777,7 +774,7 @@ class ShuffleProduct_overlapping(ShuffleProduct_abstract):
             sage: from sage.combinat.shuffle import ShuffleProduct_overlapping
             sage: w, u = map(Words(range(20)), [[2, 9], [9, 1]])
             sage: S = ShuffleProduct_overlapping(w,u)
-            sage: TestSuite(S).run(skip="_test_an_element")
+            sage: TestSuite(S).run(skip='_test_an_element')
         """
         self._add = add
 
