@@ -44,7 +44,7 @@ class PermutationSpeciesStructure(GenericSpeciesStructure):
 
     def permutation_group_element(self):
         """
-        Returns self as a permutation group element.
+        Return ``self`` as a permutation group element.
 
         EXAMPLES::
 
@@ -59,7 +59,7 @@ class PermutationSpeciesStructure(GenericSpeciesStructure):
 
     def transport(self, perm):
         """
-        Returns the transport of this structure along the permutation
+        Return the transport of this structure along the permutation
         perm.
 
         EXAMPLES::
@@ -77,7 +77,7 @@ class PermutationSpeciesStructure(GenericSpeciesStructure):
 
     def automorphism_group(self):
         """
-        Returns the group of permutations whose action on this structure
+        Return the group of permutations whose action on this structure
         leave it fixed.
 
         EXAMPLES::
@@ -119,7 +119,7 @@ class PermutationSpecies(GenericCombinatorialSpecies, UniqueRepresentation):
 
     def __init__(self, min=None, max=None, weight=None):
         """
-        Returns the species of permutations.
+        Return the species of permutations.
 
         EXAMPLES::
 
@@ -216,7 +216,7 @@ class PermutationSpecies(GenericCombinatorialSpecies, UniqueRepresentation):
 
     def _cis(self, series_ring, base_ring):
         r"""
-        The cycle index series for the species of permutations is given by
+        The cycle index series for the species of permutations is given by.
 
         .. MATH::
 
