@@ -44,6 +44,7 @@ from sage.misc.cachefunc import cached_method
 columns_white_list = ['knot_atlas_anon', 'knotilus_page_anon']
 columns_black_list = ['homfly_polynomial_old']
 
+
 class KnotInfoColumnTypes(Enum):
     r"""
     Enum class to specify if a column from the table of knots and links provided
@@ -334,7 +335,7 @@ class KnotInfoFilename(Enum):
 #----------------------------------------------------------------------------------------------------------------------------
 class KnotInfoDataBase(SageObject, UniqueRepresentation):
     r"""
-    Database interface to KnotInfo
+    Database interface to KnotInfo.
 
     The original data are obtained from KnotInfo web-page (URL see the example
     below). In order to have these data installed during the build process as
@@ -385,8 +386,8 @@ class KnotInfoDataBase(SageObject, UniqueRepresentation):
 
         INPUT:
 
-        - ``force`` -- optional boolean. If set to ``True`` the existing
-          file-cache is overwritten
+        - ``force`` -- boolean (default: ``False``); if set to ``True`` the
+          existing file-cache is overwritten
 
         EXAMPLES::
 
@@ -658,11 +659,9 @@ class KnotInfoDataBase(SageObject, UniqueRepresentation):
     @cached_method
     def read_column_dict(self):
         r"""
-        Read the dictionary for the column names from the according sobj-file
+        Read the dictionary for the column names from the according sobj-file.
 
-        OUTPUT:
-
-        A python dictionary containing the column names and types
+        OUTPUT: a Python dictionary containing the column names and types
 
         EXAMPLES::
 
@@ -711,12 +710,10 @@ class KnotInfoDataBase(SageObject, UniqueRepresentation):
     @cached_method
     def row_names(self):
         r"""
-        Return a dictionary to obtain the original name to a row_dict key
+        Return a dictionary to obtain the original name to a row_dict key.
 
-        OUTPUT:
-
-        A python dictionary containing the names of the knots and links
-        together with their original names from the database,
+        OUTPUT: a Python dictionary containing the names of the knots and links
+        together with their original names from the database
 
         EXAMPLES::
 
@@ -737,9 +734,7 @@ class KnotInfoDataBase(SageObject, UniqueRepresentation):
         Read the number of knots contained in the database (without
         proper links) from the according sobj-file.
 
-        OUTPUT:
-
-        Integer
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -758,16 +753,14 @@ class KnotInfoDataBase(SageObject, UniqueRepresentation):
     @cached_method
     def read(self, column):
         r"""
-        Access a column of KnotInfo / LinkInfo
+        Access a column of KnotInfo / LinkInfo.
 
         INPUT:
 
         - ``column`` -- instance of enum :class:`KnotInfoColumns`
           to select the data to be read in
 
-        OUTPUT:
-
-        A python list containing the data corresponding to the column.
+        OUTPUT: a Python list containing the data corresponding to the column
 
         EXAMPLES::
 
@@ -800,7 +793,7 @@ class KnotInfoDataBase(SageObject, UniqueRepresentation):
 
             sage: from sage.databases.knotinfo_db import KnotInfoDataBase
             sage: ki_db = KnotInfoDataBase()
-            sage: TestSuite(ki_db).run()    # long time indirect doctest
+            sage: TestSuite(ki_db).run()    # optional - database_knotinfo, long time, indirect doctest
         """
         from sage.knots.knotinfo import KnotInfo
         from sage.misc.misc import some_tuples
@@ -845,6 +838,8 @@ column_demo_sample = {
     'fibered':              ['Fibered',              KnotInfoColumnTypes.OnlyKnots],
     'unoriented':           ['Unoriented',           KnotInfoColumnTypes.OnlyLinks],
     'symmetry_type':        ['Symmetry Type',        KnotInfoColumnTypes.OnlyKnots],
+    'geometric_type':       ['Geometric Type',       KnotInfoColumnTypes.OnlyKnots],
+    'cosmetic_crossing':    ['Cosmetic Crossing',    KnotInfoColumnTypes.OnlyKnots],
     'width':                ['Width',                KnotInfoColumnTypes.OnlyKnots],
     'arc_notation':         ['Arc Notation',         KnotInfoColumnTypes.OnlyLinks],
     'dt_code':              ['DT code',              KnotInfoColumnTypes.OnlyLinks]
@@ -1026,6 +1021,18 @@ data_demo_sample = {
         'reversible',
         'reversible'
         ],
+    dc.geometric_type: [
+        '',
+        'torus knot T(2,3)',
+        'hyperbolic',
+        'torus knot T(2,5)',
+        'hyperbolic',
+        'hyperbolic',
+        'hyperbolic',
+        'hyperbolic',
+        'torus knot T(2,7)',
+        'hyperbolic'],
+    dc.cosmetic_crossing: ['', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N'],
     dc.homfly_polynomial: [
         '',
         '(2*v^2-v^4)+v^2*z^2',
