@@ -166,9 +166,7 @@ class Hyperplane(LinearExpression):
         """
         Return a string representation.
 
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -182,9 +180,7 @@ class Hyperplane(LinearExpression):
         r"""
         Return a LaTeX representation.
 
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -208,9 +204,7 @@ class Hyperplane(LinearExpression):
         """
         Return the normal vector.
 
-        OUTPUT:
-
-        A vector over the base ring.
+        OUTPUT: a vector over the base ring
 
         EXAMPLES::
 
@@ -228,9 +222,7 @@ class Hyperplane(LinearExpression):
         """
         Return the index of the largest entry of the normal vector.
 
-        OUTPUT:
-
-        An integer. The index of the largest entry.
+        OUTPUT: integer; the index of the largest entry
 
         EXAMPLES::
 
@@ -265,9 +257,7 @@ class Hyperplane(LinearExpression):
 
         - ``q`` -- point (as a vector, list, or tuple)
 
-        OUTPUT:
-
-        A boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -287,9 +277,7 @@ class Hyperplane(LinearExpression):
         """
         Return the hyperplane as a polyhedron.
 
-        OUTPUT:
-
-        A :func:`~sage.geometry.polyhedron.constructor.Polyhedron` instance.
+        OUTPUT: a :func:`~sage.geometry.polyhedron.constructor.Polyhedron` instance
 
         EXAMPLES::
 
@@ -426,9 +414,7 @@ class Hyperplane(LinearExpression):
         r"""
         The dimension of the hyperplane.
 
-        OUTPUT:
-
-        An integer.
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -448,9 +434,7 @@ class Hyperplane(LinearExpression):
         - ``other`` -- a hyperplane, a polyhedron, or something that
           defines a polyhedron
 
-        OUTPUT:
-
-        A polyhedron.
+        OUTPUT: a polyhedron
 
         EXAMPLES::
 
@@ -484,7 +468,7 @@ class Hyperplane(LinearExpression):
         A vector in the ambient vector space that lies on the
         hyperplane.
 
-        In finite characteristic, a :class:`ValueError` is raised if the
+        In finite characteristic, a :exc:`ValueError` is raised if the
         the norm of the hyperplane normal is zero.
 
         EXAMPLES::
@@ -634,9 +618,7 @@ class Hyperplane(LinearExpression):
         """
         Plot the hyperplane.
 
-        OUTPUT:
-
-        A graphics object.
+        OUTPUT: a graphics object
 
         EXAMPLES::
 
@@ -716,9 +698,7 @@ class AmbientVectorSpace(LinearExpressionModule):
         """
         Return a string representation.
 
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -736,9 +716,7 @@ class AmbientVectorSpace(LinearExpressionModule):
         """
         Return the ambient space dimension.
 
-        OUTPUT:
-
-        An integer.
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -760,9 +738,7 @@ class AmbientVectorSpace(LinearExpressionModule):
 
         - ``base_ring`` -- a ring; the new base ring
 
-        OUTPUT:
-
-        A new :class:`AmbientVectorSpace`.
+        OUTPUT: a new :class:`AmbientVectorSpace`
 
         EXAMPLES::
 
