@@ -36,6 +36,7 @@ Define methods relying on :mod:`sage.graphs`.
 from sage.misc.cachefunc import cached_method
 from .base3 import Polyhedron_base3
 
+
 class Polyhedron_base4(Polyhedron_base3):
     """
     Methods relying on :mod:`sage.graphs`.
@@ -70,7 +71,7 @@ class Polyhedron_base4(Polyhedron_base3):
 
         This function constructs a directed bipartite graph.
         The nodes of the graph correspond to the vertices of the polyhedron
-        and the facets of the polyhedron. There is an directed edge
+        and the facets of the polyhedron. There is a directed edge
         from a vertex to a face if and only if the vertex is incident to the face.
 
         INPUT:
@@ -110,28 +111,28 @@ class Polyhedron_base4(Polyhedron_base3):
              An inequality (0, 0, 1) x + 1 >= 0,
              An inequality (0, 1, 0) x + 1 >= 0,
              An inequality (1, 0, 0) x + 1 >= 0]
-            sage: G.automorphism_group().is_isomorphic(P.hasse_diagram().automorphism_group())
+            sage: G.automorphism_group().is_isomorphic(P.hasse_diagram().automorphism_group())      # needs sage.groups
             True
             sage: O = polytopes.octahedron(); O
             A 3-dimensional polyhedron in ZZ^3 defined as the convex hull of 6 vertices
             sage: O.vertex_facet_graph()
             Digraph on 14 vertices
             sage: H = O.vertex_facet_graph()
-            sage: G.is_isomorphic(H)
+            sage: G.is_isomorphic(H)                                                                # needs sage.groups
             False
             sage: G2 = copy(G)
             sage: G2.reverse_edges(G2.edges(sort=True))
-            sage: G2.is_isomorphic(H)
+            sage: G2.is_isomorphic(H)                                                               # needs sage.groups
             True
 
         TESTS:
 
-        Check that :trac:`28828` is fixed::
+        Check that :issue:`28828` is fixed::
 
             sage: G._immutable
             True
 
-        Check that :trac:`29188` is fixed::
+        Check that :issue:`29188` is fixed::
 
             sage: P = polytopes.cube()
             sage: P.vertex_facet_graph().is_isomorphic(P.vertex_facet_graph(False))
@@ -169,7 +170,7 @@ class Polyhedron_base4(Polyhedron_base3):
 
             sage: g3 = polytopes.hypercube(3).vertex_graph(); g3
             Graph on 8 vertices
-            sage: g3.automorphism_group().cardinality()
+            sage: g3.automorphism_group().cardinality()                                             # needs sage.groups
             48
             sage: s4 = polytopes.simplex(4).vertex_graph(); s4
             Graph on 5 vertices
@@ -192,7 +193,7 @@ class Polyhedron_base4(Polyhedron_base3):
 
         TESTS:
 
-        Check for a line segment (:trac:`30545`)::
+        Check for a line segment (:issue:`30545`)::
 
             sage: polytopes.simplex(1).graph().edges(sort=True)
             [(A vertex at (0, 1), A vertex at (1, 0), None)]
@@ -218,8 +219,8 @@ class Polyhedron_base4(Polyhedron_base3):
             - a vector ; in this case the linear form is obtained by duality
               using the dot product: ``f(v) = v.dot_product(f)``.
 
-        - ``increasing`` -- boolean (default ``True``) whether to orient
-          edges in the increasing or decreasing direction.
+        - ``increasing`` -- boolean (default: ``True``); whether to orient
+          edges in the increasing or decreasing direction
 
         By default, an edge is oriented from `v` to `w` if
         `f(v) \leq f(w)`.
@@ -308,7 +309,7 @@ class Polyhedron_base4(Polyhedron_base3):
 
         .. NOTE::
 
-            The face lattice is not cached, as long as this creates a memory leak, see :trac:`28982`.
+            The face lattice is not cached, as long as this creates a memory leak, see :issue:`28982`.
 
         EXAMPLES::
 
@@ -383,7 +384,6 @@ class Polyhedron_base4(Polyhedron_base3):
             [[()], [(0, 1)]]
             sage: [[ls.ambient_V_indices() for ls in lss] for lss in Polyhedron(lines=[(1,0)], vertices=[(0,0)]).face_lattice().level_sets()]
             [[()], [(0, 1)]]
-
         """
         from sage.combinat.posets.lattices import FiniteLatticePoset
         return FiniteLatticePoset(self.hasse_diagram())
@@ -406,7 +406,7 @@ class Polyhedron_base4(Polyhedron_base3):
             sage: D.degree_polynomial()
             x^5 + x^4*y + x*y^4 + y^5 + 4*x^3*y + 8*x^2*y^2 + 4*x*y^3
 
-        Faces of an mutable polyhedron are not hashable. Hence those are not suitable as
+        Faces of a mutable polyhedron are not hashable. Hence those are not suitable as
         vertices of the hasse diagram. Use the combinatorial polyhedron instead::
 
             sage: # needs sage.rings.number_field
@@ -471,12 +471,10 @@ class Polyhedron_base4(Polyhedron_base3):
 
         INPUT:
 
-        - ``args`` -- integers (optional); specify an entry of the
+        - ``args`` -- integer (optional); specify an entry of the
           flag-f-vector; must be an increasing sequence of integers
 
-        OUTPUT:
-
-        - a dictionary, if no arguments were given
+        OUTPUT: a dictionary, if no arguments were given
 
         - an Integer, if arguments were given
 
@@ -603,7 +601,7 @@ class Polyhedron_base4(Polyhedron_base3):
     @cached_method
     def combinatorial_automorphism_group(self, vertex_graph_only=False):
         """
-        Computes the combinatorial automorphism group.
+        Compute the combinatorial automorphism group.
 
         If ``vertex_graph_only`` is ``True``,  the automorphism group
         of the vertex-edge graph of the polyhedron is returned. Otherwise
@@ -645,21 +643,22 @@ class Polyhedron_base4(Polyhedron_base3):
         EXAMPLES::
 
             sage: quadrangle = Polyhedron(vertices=[(0,0),(1,0),(0,1),(2,3)])
-            sage: quadrangle.combinatorial_automorphism_group().is_isomorphic(
+            sage: quadrangle.combinatorial_automorphism_group().is_isomorphic(          # needs sage.groups
             ....:     groups.permutation.Dihedral(4))
             True
-            sage: quadrangle.restricted_automorphism_group()
+            sage: quadrangle.restricted_automorphism_group()                            # needs sage.groups
             Permutation Group with generators [()]
 
         Permutations of the vertex graph only exchange vertices with vertices::
 
             sage: P = Polyhedron(vertices=[(1,0), (1,1)], rays=[(1,0)])
-            sage: P.combinatorial_automorphism_group(vertex_graph_only=True)
+            sage: P.combinatorial_automorphism_group(vertex_graph_only=True)            # needs sage.groups
             Permutation Group with generators [(A vertex at (1,0),A vertex at (1,1))]
 
         This shows an example of two polytopes whose vertex-edge graphs are isomorphic,
         but their face lattices are not isomorphic::
 
+            sage: # needs sage.groups
             sage: Q = Polyhedron([[-123984206864/2768850730773, -101701330976/922950243591, -64154618668/2768850730773, -2748446474675/2768850730773],
             ....:                 [-11083969050/98314591817, -4717557075/98314591817, -32618537490/98314591817, -91960210208/98314591817],
             ....:                 [-9690950/554883199, -73651220/554883199, 1823050/554883199, -549885101/554883199],
@@ -680,13 +679,13 @@ class Polyhedron_base4(Polyhedron_base3):
 
         The automorphism group of the face lattice is isomorphic to the combinatorial automorphism group::
 
+            sage: # needs sage.groups
             sage: CG = C.hasse_diagram().automorphism_group()
             sage: C.combinatorial_automorphism_group().is_isomorphic(CG)
             True
             sage: QG = Q.hasse_diagram().automorphism_group()
             sage: Q.combinatorial_automorphism_group().is_isomorphic(QG)
             True
-
         """
         if vertex_graph_only:
             G = self.graph()
@@ -695,7 +694,7 @@ class Polyhedron_base4(Polyhedron_base3):
         return G.automorphism_group(edge_labels=True)
 
     @cached_method
-    def restricted_automorphism_group(self, output="abstract"):
+    def restricted_automorphism_group(self, output='abstract'):
         r"""
         Return the restricted automorphism group.
 
@@ -762,22 +761,22 @@ class Polyhedron_base4(Polyhedron_base3):
 
         - ``output`` -- how the group should be represented:
 
-          - ``"abstract"`` (default) -- return an abstract permutation
-            group without further meaning.
+          - ``'abstract'`` -- default; return an abstract permutation
+            group without further meaning
 
-          - ``"permutation"`` -- return a permutation group on the
+          - ``'permutation'`` -- return a permutation group on the
             indices of the polyhedron generators. For example, the
             permutation ``(0,1)`` would correspond to swapping
             ``self.Vrepresentation(0)`` and ``self.Vrepresentation(1)``.
 
-          - ``"matrix"`` -- return a matrix group representing affine
+          - ``'matrix'`` -- return a matrix group representing affine
             transformations. When acting on affine vectors, you should
             append a `1` to every vector. If the polyhedron is not full
             dimensional, the returned matrices act as the identity on
             the orthogonal complement of the affine space spanned by
             the polyhedron.
 
-          - ``"matrixlist"`` -- like ``matrix``, but return the list of
+          - ``'matrixlist'`` -- like ``matrix``, but return the list of
             elements of the matrix group. Useful for fields without a
             good implementation of matrix groups or to avoid the
             overhead of creating the group.
@@ -799,16 +798,18 @@ class Polyhedron_base4(Polyhedron_base3):
 
         A cross-polytope example::
 
+            sage: # needs sage.groups
             sage: P = polytopes.cross_polytope(3)
             sage: P.restricted_automorphism_group() == PermutationGroup([[(3,4)], [(2,3),(4,5)],[(2,5)],[(1,2),(5,6)],[(1,6)]])
             True
-            sage: P.restricted_automorphism_group(output="permutation") == PermutationGroup([[(2,3)],[(1,2),(3,4)],[(1,4)],[(0,1),(4,5)],[(0,5)]])
+            sage: P.restricted_automorphism_group(output='permutation') == PermutationGroup([[(2,3)],[(1,2),(3,4)],[(1,4)],[(0,1),(4,5)],[(0,5)]])
             True
             sage: mgens = [[[1,0,0,0],[0,1,0,0],[0,0,-1,0],[0,0,0,1]], [[1,0,0,0],[0,0,1,0],[0,1,0,0],[0,0,0,1]], [[0,1,0,0],[1,0,0,0],[0,0,1,0],[0,0,0,1]]]
 
         We test groups for equality in a fool-proof way; they can have different generators, etc::
 
-            sage: poly_g = P.restricted_automorphism_group(output="matrix")
+            sage: # needs sage.groups
+            sage: poly_g = P.restricted_automorphism_group(output='matrix')
             sage: matrix_g = MatrixGroup([matrix(QQ,t) for t in mgens])
             sage: all(t.matrix() in poly_g for t in matrix_g.gens())
             True
@@ -817,6 +818,7 @@ class Polyhedron_base4(Polyhedron_base3):
 
         24-cell example::
 
+            sage: # needs sage.groups
             sage: P24 = polytopes.twenty_four_cell()
             sage: AutP24 = P24.restricted_automorphism_group()
             sage: PermutationGroup([
@@ -829,19 +831,20 @@ class Polyhedron_base4(Polyhedron_base3):
 
         Here is the quadrant example mentioned in the beginning::
 
+            sage: # needs sage.groups
             sage: P = Polyhedron(rays=[(1,0),(0,1)])
             sage: P.Vrepresentation()
             (A vertex at (0, 0), A ray in the direction (0, 1), A ray in the direction (1, 0))
-            sage: P.restricted_automorphism_group(output="permutation")
+            sage: P.restricted_automorphism_group(output='permutation')
             Permutation Group with generators [(1,2)]
 
         Also, the polyhedron need not be full-dimensional::
 
+            sage: # needs sage.groups
             sage: P = Polyhedron(vertices=[(1,2,3,4,5),(7,8,9,10,11)])
             sage: P.restricted_automorphism_group()
             Permutation Group with generators [(1,2)]
-            sage: G = P.restricted_automorphism_group(output="matrixlist")
-            sage: G
+            sage: G = P.restricted_automorphism_group(output='matrixlist'); G
             (
             [1 0 0 0 0 0]  [ -87/55  -82/55    -2/5   38/55   98/55   12/11]
             [0 1 0 0 0 0]  [-142/55  -27/55    -2/5   38/55   98/55   12/11]
@@ -850,8 +853,7 @@ class Polyhedron_base4(Polyhedron_base3):
             [0 0 0 0 1 0]  [-142/55  -82/55    -2/5   38/55  153/55   12/11]
             [0 0 0 0 0 1], [      0       0       0       0       0       1]
             )
-            sage: g = AffineGroup(5, QQ)(G[1])
-            sage: g
+            sage: g = AffineGroup(5, QQ)(G[1]); g
                   [ -87/55  -82/55    -2/5   38/55   98/55]     [12/11]
                   [-142/55  -27/55    -2/5   38/55   98/55]     [12/11]
             x |-> [-142/55  -82/55     3/5   38/55   98/55] x + [12/11]
@@ -873,6 +875,7 @@ class Polyhedron_base4(Polyhedron_base3):
         dihedral group with 6 elements, `D_6`, as its automorphism
         group::
 
+            sage: # needs sage.groups
             sage: initial_points = [vector([1,0]), vector([0,1]), vector([-2,-1])]
             sage: points = initial_points
             sage: Polyhedron(vertices=points).restricted_automorphism_group()
@@ -890,40 +893,45 @@ class Polyhedron_base4(Polyhedron_base3):
         The ``output="matrixlist"`` can be used over fields without a
         complete implementation of matrix groups::
 
+            sage: # needs sage.groups sage.rings.number_field
             sage: P = polytopes.dodecahedron(); P
-            A 3-dimensional polyhedron in (Number Field in sqrt5 with defining polynomial x^2 - 5 with sqrt5 = 2.236067977499790?)^3 defined as the convex hull of 20 vertices
-            sage: G = P.restricted_automorphism_group(output="matrixlist")
+            A 3-dimensional polyhedron in (Number Field in sqrt5 with defining
+             polynomial x^2 - 5 with sqrt5 = 2.236067977499790?)^3
+             defined as the convex hull of 20 vertices
+            sage: G = P.restricted_automorphism_group(output='matrixlist')
             sage: len(G)
             120
 
         Floating-point computations are supported with a simple fuzzy
         zero implementation::
 
-            sage: P = Polyhedron(vertices=[(1/3,0,0,1),(0,1/4,0,1),(0,0,1/5,1)], base_ring=RDF)
-            sage: P.restricted_automorphism_group()
+            sage: P = Polyhedron(vertices=[(1/3,0,0,1),(0,1/4,0,1),(0,0,1/5,1)],
+            ....:                base_ring=RDF)
+            sage: P.restricted_automorphism_group()                                     # needs sage.groups
             Permutation Group with generators [(2,3), (1,2)]
-            sage: len(P.restricted_automorphism_group(output="matrixlist"))
+            sage: len(P.restricted_automorphism_group(output='matrixlist'))
             6
 
         TESTS::
 
             sage: P = Polyhedron(vertices=[(1,0), (1,1)], rays=[(1,0)])
-            sage: P.restricted_automorphism_group(output="permutation")
+            sage: P.restricted_automorphism_group(output='permutation')                 # needs sage.groups
             Permutation Group with generators [(1,2)]
-            sage: P.restricted_automorphism_group(output="matrix")
+            sage: P.restricted_automorphism_group(output='matrix')
             Matrix group over Rational Field with 1 generators (
             [ 1  0  0]
             [ 0 -1  1]
             [ 0  0  1]
             )
-            sage: P.restricted_automorphism_group(output="foobar")
+            sage: P.restricted_automorphism_group(output='foobar')
             Traceback (most recent call last):
             ...
-            ValueError: unknown output 'foobar', valid values are ('abstract', 'permutation', 'matrix', 'matrixlist')
+            ValueError: unknown output 'foobar', valid values are
+            ('abstract', 'permutation', 'matrix', 'matrixlist')
 
-        Check that :trac:`28828` is fixed::
+        Check that :issue:`28828` is fixed::
 
-            sage: P.restricted_automorphism_group(output="matrixlist")[0].is_immutable()
+            sage: P.restricted_automorphism_group(output='matrixlist')[0].is_immutable()
             True
         """
         # The algorithm works as follows:
@@ -1061,8 +1069,8 @@ class Polyhedron_base4(Polyhedron_base3):
         INPUT:
 
         - ``other`` -- a polyhedron object
-        - ``algorithm`` (default = ``'bipartite_graph'``) -- the algorithm to use.
-          The other possible value is ``'face_lattice'``.
+        - ``algorithm`` -- (default: ``'bipartite_graph'``) the algorithm to
+          use; the other possible value is ``'face_lattice'``
 
         OUTPUT:
 
@@ -1162,7 +1170,6 @@ class Polyhedron_base4(Polyhedron_base3):
             Traceback (most recent call last):
             ...
             AssertionError: polyhedron `other` must be bounded
-
         """
         assert isinstance(other, Polyhedron_base4), "input `other` must be a polyhedron"
         assert self.is_compact(), "polyhedron `self` must be bounded"
@@ -1239,7 +1246,6 @@ class Polyhedron_base4(Polyhedron_base3):
             Traceback (most recent call last):
             ...
             ValueError: polyhedron has to be compact
-
         """
         if not self.is_compact():
             raise ValueError("polyhedron has to be compact")
