@@ -30,36 +30,36 @@ from .representation import Inequality, Equation, Vertex, Ray, Line
 def Polyhedra(ambient_space_or_base_ring=None, ambient_dim=None, backend=None, *,
               ambient_space=None, base_ring=None):
     r"""
-    Construct a suitable parent class for polyhedra
+    Construct a suitable parent class for polyhedra.
 
     INPUT:
 
-    - ``base_ring`` -- A ring. Currently there are backends for `\ZZ`,
-      `\QQ`, and `\RDF`.
+    - ``base_ring`` -- a ring; currently there are backends for `\ZZ`,
+      `\QQ`, and `\RDF`
 
-    - ``ambient_dim`` -- integer. The ambient space dimension.
+    - ``ambient_dim`` -- integer; the ambient space dimension
 
-    - ``ambient_space`` -- A free module.
+    - ``ambient_space`` -- a free module
 
     - ``backend`` -- string. The name of the backend for computations. There are
-       several backends implemented:
+      several backends implemented:
 
-         * ``backend="ppl"`` uses the Parma Polyhedra Library
+        * ``backend="ppl"`` uses the Parma Polyhedra Library
 
-         * ``backend="cdd"`` uses CDD
+        * ``backend="cdd"`` uses CDD
 
-         * ``backend="normaliz"`` uses normaliz
+        * ``backend="normaliz"`` uses normaliz
 
-         * ``backend="polymake"`` uses polymake
+        * ``backend="polymake"`` uses polymake
 
-         * ``backend="field"`` a generic Sage implementation
+        * ``backend="field"`` a generic Sage implementation
 
     OUTPUT:
 
     A parent class for polyhedra over the given base ring if the
     backend supports it. If not, the parent base ring can be larger
     (for example, `\QQ` instead of `\ZZ`). If there is no
-    implementation at all, a ``ValueError`` is raised.
+    implementation at all, a :exc:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -125,7 +125,6 @@ def Polyhedra(ambient_space_or_base_ring=None, ambient_dim=None, backend=None, *
 
         sage: Polyhedra(SCR, 2, backend='number_field')                                 # needs sage.symbolic
         Polyhedra in (Symbolic Constants Subring)^2
-
     """
     if ambient_space_or_base_ring is not None:
         if ambient_space_or_base_ring in Rings():
@@ -202,13 +201,13 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
     INPUT:
 
-    - ``base_ring`` -- either ``ZZ``, ``QQ``, or ``RDF``. The base
-      ring of the ambient module/vector space.
+    - ``base_ring`` -- either ``ZZ``, ``QQ``, or ``RDF``; the base
+      ring of the ambient module/vector space
 
-    - ``ambient_dim`` -- integer. The ambient space dimension.
+    - ``ambient_dim`` -- integer; the ambient space dimension
 
-    - ``backend`` -- string. The name of the backend for computations. There are
-       several backends implemented:
+    - ``backend`` -- string; the name of the backend for computations. There are
+      several backends implemented:
 
       * ``backend="ppl"`` uses the Parma Polyhedra Library
 
@@ -263,7 +262,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
     def list(self):
         """
-        Return the two polyhedra in ambient dimension 0, raise an error otherwise
+        Return the two polyhedra in ambient dimension 0, raise an error otherwise.
 
         EXAMPLES::
 
@@ -297,8 +296,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``polyhedron`` -- a polyhedron whose parent is ``self``.
-
+        - ``polyhedron`` -- a polyhedron whose parent is ``self``
 
         EXAMPLES::
 
@@ -465,9 +463,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         This is the vector space or module containing the
         Vrepresentation vectors.
 
-        OUTPUT:
-
-        A free module over the base ring of dimension :meth:`ambient_dim`.
+        OUTPUT: a free module over the base ring of dimension :meth:`ambient_dim`
 
         EXAMPLES::
 
@@ -490,9 +486,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         r"""
         Return the linear space containing the H-representation vectors.
 
-        OUTPUT:
-
-        A free module over the base ring of dimension :meth:`ambient_dim` + 1.
+        OUTPUT: a free module over the base ring of dimension :meth:`ambient_dim` + 1
 
         EXAMPLES::
 
@@ -540,9 +534,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         Return an abbreviated string representation of the ambient
         space.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -562,9 +554,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         """
         Return a string representation.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -582,16 +572,15 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``Vrep`` -- a list ``[vertices, rays, lines]`` or ``None``.
+        - ``Vrep`` -- list ``[vertices, rays, lines]`` or ``None``
 
-        - ``Hrep`` -- a list ``[ieqs, eqns]`` or ``None``.
+        - ``Hrep`` -- list ``[ieqs, eqns]`` or ``None``
 
-        - ``convert`` -- boolean keyword argument (default:
-          ``True``). Whether to convert the coordinates into the base
-          ring.
+        - ``convert`` -- boolean (default: ``True``); whether to convert the
+          coordinates into the base ring
 
-        - ``**kwds`` -- optional remaining keywords that are passed to the
-          polyhedron constructor.
+        - ``**kwds`` -- (optional) remaining keywords that are passed to the
+          polyhedron constructor
 
         EXAMPLES::
 
@@ -747,9 +736,9 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         INPUT:
 
         - ``base_ring``, ``backend`` -- see
-          :func:`~sage.geometry.polyhedron.constructor.Polyhedron`.
+          :func:`~sage.geometry.polyhedron.constructor.Polyhedron`
         - ``ambient_dim`` -- if not ``None`` change ambient dimension
-          accordingly.
+          accordingly
 
         EXAMPLES::
 
@@ -783,9 +772,9 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         INPUT:
 
         - ``base_ring``, ``backend`` -- see
-          :func:`~sage.geometry.polyhedron.constructor.Polyhedron`.
+          :func:`~sage.geometry.polyhedron.constructor.Polyhedron`
         - ``ambient_dim`` -- if not ``None`` change ambient dimension
-          accordingly.
+          accordingly
 
         EXAMPLES::
 
@@ -835,7 +824,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         OUTPUT:
 
-        Either `\ZZ`, `\QQ`, or `RDF`. Raises :class:`TypeError` if
+        Either `\ZZ`, `\QQ`, or `RDF`. Raises :exc:`TypeError` if
         ``other`` is not a suitable input.
 
         .. NOTE::
@@ -918,11 +907,9 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``X`` -- anything.
+        - ``X`` -- anything
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -949,16 +936,14 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``other`` -- a scalar or a vector.
+        - ``other`` -- a scalar or a vector
 
-        - ``op`` -- the operator.
+        - ``op`` -- the operator
 
-        - ``self_is_left`` -- boolean. Whether ``self`` is on the left
-          of the operator.
+        - ``self_is_left`` -- boolean; whether ``self`` is on the left
+          of the operator
 
-        OUTPUT:
-
-        An action that is used by the coercion model.
+        OUTPUT: an action that is used by the coercion model
 
         EXAMPLES::
 
@@ -1003,7 +988,6 @@ class Polyhedra_base(UniqueRepresentation, Parent):
              Identity endomorphism of Polyhedra in ZZ^2
             with precomposition on right by
              Generic endomorphism of Ambient free module of rank 2 over the principal ideal domain Integer Ring
-
         """
         import operator
         from sage.structure.coerce_actions import ActedUponAction
@@ -1046,13 +1030,11 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``polyhedron`` -- the new polyhedron.
+        - ``polyhedron`` -- the new polyhedron
 
-        - ``data`` -- the H-representation data.
+        - ``data`` -- the H-representation data
 
-        OUTPUT:
-
-        A new :class:`~sage.geometry.polyhedron.representation.Inequality` object.
+        OUTPUT: a new :class:`~sage.geometry.polyhedron.representation.Inequality` object
 
         EXAMPLES::
 
@@ -1073,13 +1055,11 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``polyhedron`` -- the new polyhedron.
+        - ``polyhedron`` -- the new polyhedron
 
-        - ``data`` -- the H-representation data.
+        - ``data`` -- the H-representation data
 
-        OUTPUT:
-
-        A new :class:`~sage.geometry.polyhedron.representation.Equation` object.
+        OUTPUT: a new :class:`~sage.geometry.polyhedron.representation.Equation` object
 
         EXAMPLES::
 
@@ -1100,13 +1080,11 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``polyhedron`` -- the new polyhedron.
+        - ``polyhedron`` -- the new polyhedron
 
-        - ``data`` -- the V-representation data.
+        - ``data`` -- the V-representation data
 
-        OUTPUT:
-
-        A new :class:`~sage.geometry.polyhedron.representation.Vertex` object.
+        OUTPUT: a new :class:`~sage.geometry.polyhedron.representation.Vertex` object
 
         EXAMPLES::
 
@@ -1127,13 +1105,11 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``polyhedron`` -- the new polyhedron.
+        - ``polyhedron`` -- the new polyhedron
 
-        - ``data`` -- the V-representation data.
+        - ``data`` -- the V-representation data
 
-        OUTPUT:
-
-        A new :class:`~sage.geometry.polyhedron.representation.Ray` object.
+        OUTPUT: a new :class:`~sage.geometry.polyhedron.representation.Ray` object
 
         EXAMPLES::
 
@@ -1154,13 +1130,11 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``polyhedron`` -- the new polyhedron.
+        - ``polyhedron`` -- the new polyhedron
 
-        - ``data`` -- the V-representation data.
+        - ``data`` -- the V-representation data
 
-        OUTPUT:
-
-        A new :class:`~sage.geometry.polyhedron.representation.Line` object.
+        OUTPUT: a new :class:`~sage.geometry.polyhedron.representation.Line` object
 
         EXAMPLES::
 
