@@ -176,14 +176,14 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
     We can also create Coxeter groups from Cartan types using the
     ``implementation`` keyword::
 
-        sage: W = CoxeterGroup(['D',5], implementation="reflection"); W
+        sage: W = CoxeterGroup(['D',5], implementation='reflection'); W
         Finite Coxeter group over Integer Ring with Coxeter matrix:
         [1 3 2 2 2]
         [3 1 3 2 2]
         [2 3 1 3 3]
         [2 2 3 1 2]
         [2 2 3 2 1]
-        sage: W = CoxeterGroup(['H',3], implementation="reflection"); W                 # needs sage.libs.gap sage.rings.number_field
+        sage: W = CoxeterGroup(['H',3], implementation='reflection'); W                 # needs sage.libs.gap sage.rings.number_field
         Finite Coxeter group over
          Number Field in a with defining polynomial x^2 - 5 with a = 2.236067977499790?
          with Coxeter matrix:
@@ -198,7 +198,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
 
         EXAMPLES::
 
-            sage: W1 = CoxeterGroup(['A',2], implementation="reflection", base_ring=ZZ)
+            sage: W1 = CoxeterGroup(['A',2], implementation='reflection', base_ring=ZZ)
             sage: W2 = CoxeterGroup([[1,3],[3,1]], index_set=(1,2))
             sage: W1 is W2
             True
@@ -362,7 +362,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
             sage: W2 = WeylGroup(["A",4])
             sage: W._coerce_map_from_(W2)
             True
-            sage: W3 = WeylGroup(["A",4], implementation="permutation")
+            sage: W3 = WeylGroup(["A",4], implementation='permutation')
             sage: W._coerce_map_from_(W3)
             True
             sage: W4 = WeylGroup(["A",3])
@@ -513,7 +513,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
 
         EXAMPLES::
 
-            sage: W = CoxeterGroup(['A',3], implementation="reflection")
+            sage: W = CoxeterGroup(['A',3], implementation='reflection')
             sage: W.simple_reflection(1)
             [-1  1  0]
             [ 0  1  0]
@@ -727,7 +727,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
 
             EXAMPLES::
 
-                sage: W = CoxeterGroup(['A',3], implementation="reflection")
+                sage: W = CoxeterGroup(['A',3], implementation='reflection')
                 sage: a,b,c = W.gens()
                 sage: elt = b*a*c
                 sage: elt.first_descent()
@@ -766,11 +766,11 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
             - ``index_set`` -- (default: all of them) a subset (as a list
               or iterable) of the nodes of the Dynkin diagram
             - ``side`` -- (default: ``'right'``) ``'left'`` or ``'right'``
-            - ``positive`` -- (default: ``False``) boolean
+            - ``positive`` -- boolean (default: ``False``)
 
             EXAMPLES::
 
-                sage: W = CoxeterGroup(['A',3], implementation="reflection")
+                sage: W = CoxeterGroup(['A',3], implementation='reflection')
                 sage: a,b,c = W.gens()
                 sage: elt = b*a*c
                 sage: elt.descents()
@@ -809,7 +809,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
             `\ell(ws) < \ell(w)` then `w(\alpha_s) < 0`.
             Thus `i \in I` is a right descent if `w(\alpha_{s_i}) < 0`
             or equivalently if the matrix representing `w` has all entries
-            of the `i`-th column being non-positive.
+            of the `i`-th column being nonpositive.
 
             INPUT:
 
@@ -817,7 +817,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
 
             EXAMPLES::
 
-                sage: W = CoxeterGroup(['A',3], implementation="reflection")
+                sage: W = CoxeterGroup(['A',3], implementation='reflection')
                 sage: a,b,c = W.gens()
                 sage: elt = b*a*c
                 sage: [elt.has_right_descent(i) for i in [1, 2, 3]]
@@ -836,7 +836,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
 
             EXAMPLES::
 
-                sage: W = CoxeterGroup(['A',3], implementation="reflection")
+                sage: W = CoxeterGroup(['A',3], implementation='reflection')
                 sage: a,b,c = W.gens()
                 sage: elt = a*b*c
                 sage: elt.canonical_matrix()
@@ -847,7 +847,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
             return self.matrix()
 
         @cached_method
-        def action_on_root_indices(self, i, side="left"):
+        def action_on_root_indices(self, i, side='left'):
             """
             Return the action on the set of roots.
 
@@ -855,7 +855,7 @@ class CoxeterMatrixGroup(UniqueRepresentation, FinitelyGeneratedMatrixGroup_gene
 
             EXAMPLES::
 
-                sage: W = CoxeterGroup(['A',3], implementation="reflection")
+                sage: W = CoxeterGroup(['A',3], implementation='reflection')
                 sage: w = W.w0
                 sage: w.action_on_root_indices(0)
                 11
@@ -896,7 +896,7 @@ def _matrix_test_right_descent(M, i, n, zero):
     EXAMPLES::
 
         sage: from sage.groups.matrix_gps.coxeter_group import _matrix_test_right_descent
-        sage: W = CoxeterGroup(['A',3], implementation="reflection")
+        sage: W = CoxeterGroup(['A',3], implementation='reflection')
         sage: a,b,c = W.gens()
         sage: elt = b*a*c
         sage: zero = W.base_ring().zero()
