@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.gap sage.libs.pari sage.libs.singular sage.symbolic
 r"""
 Common Interface Functionality
 
@@ -23,7 +24,7 @@ AUTHORS:
 - Simon King (2015): Improve pickling for InterfaceElement
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -36,7 +37,7 @@ AUTHORS:
 #  The full text of the GPL is available at:
 #
 #                  https://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 
 import operator
 
@@ -178,7 +179,7 @@ class Interface(WithEqualityById, ParentWithBase):
         Press :kbd:`Ctrl` + :kbd:`D` or type 'quit' or 'exit' to exit and
         return to Sage.
 
-        .. note::
+        .. NOTE::
 
            This is completely different than the console() member
            function. The console function opens a new copy of the
@@ -272,23 +273,23 @@ class Interface(WithEqualityById, ParentWithBase):
 
         TESTS:
 
-        Check conversion of Booleans (:trac:`28705`)::
+        Check conversion of Booleans (:issue:`28705`)::
 
-            sage: giac(True)
+            sage: giac(True)  # needs giac
             true
             sage: maxima(True)
             true
         """
         cls = self._object_class()
 
-        #Handle the case when x is an object
-        #in some interface.
+        # Handle the case when x is an object
+        # in some interface.
         if isinstance(x, InterfaceElement):
             if x.parent() is self:
                 return x
 
-            #We convert x into an object in this
-            #interface by first going through Sage.
+            # We convert x into an object in this
+            # interface by first going through Sage.
             try:
                 return self(x._sage_())
             except (NotImplementedError, TypeError):
@@ -319,12 +320,12 @@ class Interface(WithEqualityById, ParentWithBase):
 
     def _coerce_from_special_method(self, x):
         """
-        Tries to coerce to self by calling a special underscore method.
+        Try to coerce to ``self`` by calling a special underscore method.
 
-        If no such method is defined, raises an AttributeError instead of a
-        TypeError.
+        If no such method is defined, raises an :exc:`AttributeError` instead
+        of a :exc:`TypeError`.
         """
-        s = '_%s_'%self.name()
+        s = '_%s_' % self.name()
         if s == '_maxima_lib_':
             s = '_maxima_'
         if s == '_pari_':
@@ -340,22 +341,22 @@ class Interface(WithEqualityById, ParentWithBase):
 
         TESTS:
 
-        Check that python type ``complex`` can be converted (:trac:`31775`)::
+        Check that python type ``complex`` can be converted (:issue:`31775`)::
 
-            sage: giac(complex(I))**2  # should not return `j^2`
+            sage: giac(complex(I))**2  # should not return `j^2`  # needs giac
             -1
         """
         if isinstance(x, bool):
             return self(self._true_symbol() if x else self._false_symbol())
         elif isinstance(x, int):
-            import sage.rings.all
-            return self(sage.rings.all.Integer(x))
+            from sage.rings.integer import Integer
+            return self(Integer(x))
         elif isinstance(x, float):
-            import sage.rings.all
-            return self(sage.rings.all.RDF(x))
+            from sage.rings.real_double import RDF
+            return self(RDF(x))
         elif isinstance(x, complex):
-            import sage.rings.all
-            return self(sage.rings.all.CDF(x))
+            from sage.rings.complex_double import CDF
+            return self(CDF(x))
         if use_special:
             try:
                 return self._coerce_from_special_method(x)
@@ -375,11 +376,11 @@ class Interface(WithEqualityById, ParentWithBase):
                     A.append(w.name())
                     z.append(w)
             X = ','.join(A)
-            r = self.new('%s%s%s'%(self._left_list_delim(), X, self._right_list_delim()))
+            r = self.new('%s%s%s' % (self._left_list_delim(), X, self._right_list_delim()))
             r.__sage_list = z   # do this to avoid having the entries of the list be garbage collected
             return r
 
-        raise TypeError("unable to coerce element into %s"%self.name())
+        raise TypeError("unable to coerce element into %s" % self.name())
 
     def new(self, code):
         return self(code)
@@ -412,14 +413,14 @@ class Interface(WithEqualityById, ParentWithBase):
         try:
             return self.__true_symbol
         except AttributeError:
-            self.__true_symbol = self.get('1 %s 1'%self._equality_symbol())
+            self.__true_symbol = self.get('1 %s 1' % self._equality_symbol())
             return self.__true_symbol
 
     def _false_symbol(self):
         try:
             return self.__false_symbol
         except AttributeError:
-            self.__false_symbol = self.get('1 %s 2'%self._equality_symbol())
+            self.__false_symbol = self.get('1 %s 2' % self._equality_symbol())
             return self.__false_symbol
 
     def _lessthan_symbol(self):
@@ -433,7 +434,7 @@ class Interface(WithEqualityById, ParentWithBase):
 
     def _relation_symbols(self):
         """
-        Returns a dictionary with operators as the keys and their
+        Return a dictionary with operators as the keys and their
         string representation as the values.
 
         EXAMPLES::
@@ -443,13 +444,16 @@ class Interface(WithEqualityById, ParentWithBase):
             sage: symbols[operator.eq]
             '=='
         """
-        return dict([(operator.eq, self._equality_symbol()), (operator.ne, self._inequality_symbol()),
-                     (operator.lt, self._lessthan_symbol()), (operator.le, "<="),
-                     (operator.gt, self._greaterthan_symbol()), (operator.ge, ">=")])
+        return {operator.eq: self._equality_symbol(),
+                operator.ne: self._inequality_symbol(),
+                operator.lt: self._lessthan_symbol(),
+                operator.le: "<=",
+                operator.gt: self._greaterthan_symbol(),
+                operator.ge: ">="}
 
     def _exponent_symbol(self):
         """
-        Return the symbol used to denote ``*10^`` in floats, e.g 'e' in 1.5e6
+        Return the symbol used to denote ``*10^`` in floats, e.g 'e' in 1.5e6.
 
         EXAMPLES::
 
@@ -470,7 +474,7 @@ class Interface(WithEqualityById, ParentWithBase):
         """
         Set the variable var to the given value.
         """
-        cmd = '%s%s%s;'%(var,self._assign_symbol(), value)
+        cmd = '%s%s%s;' % (var, self._assign_symbol(), value)
         self.eval(cmd)
 
     def get(self, var):
@@ -509,7 +513,7 @@ class Interface(WithEqualityById, ParentWithBase):
             del self._available_vars[0]
             return v
         self.__seq += 1
-        return "sage%s"%self.__seq
+        return "sage%s" % self.__seq
 
     def _create(self, value, name=None):
         name = self._next_var_name() if name is None else name
@@ -548,7 +552,7 @@ class Interface(WithEqualityById, ParentWithBase):
 
     def _convert_args_kwds(self, args=None, kwds=None):
         """
-        Converts all of the args and kwds to be elements of this
+        Convert all of the ``args`` and ``kwds`` to be elements of this
         interface.
 
         EXAMPLES::
@@ -578,7 +582,7 @@ class Interface(WithEqualityById, ParentWithBase):
 
     def _check_valid_function_name(self, function):
         """
-        Checks to see if function is a valid function name in this
+        Check to see if function is a valid function name in this
         interface. If it is not, an exception is raised. Otherwise, nothing
         is done.
 
@@ -612,19 +616,19 @@ class Interface(WithEqualityById, ParentWithBase):
         self._check_valid_function_name(function)
         s = self._function_call_string(function,
                                        [s.name() for s in args],
-                                       ['%s=%s'%(key,value.name()) for key, value in kwds.items()])
+                                       ['%s=%s' % (key, value.name()) for key, value in kwds.items()])
         return self.new(s)
 
     def _function_call_string(self, function, args, kwds):
         """
-        Returns the string used to make function calls.
+        Return the string used to make function calls.
 
         EXAMPLES::
 
             sage: maxima._function_call_string('diff', ['f(x)', 'x'], [])
             'diff(f(x),x)'
         """
-        return "%s(%s)"%(function, ",".join(list(args) + list(kwds)))
+        return "%s(%s)" % (function, ",".join(list(args) + list(kwds)))
 
     def call(self, function_name, *args, **kwds):
         return self.function_call(function_name, args, kwds)
@@ -637,6 +641,7 @@ class Interface(WithEqualityById, ParentWithBase):
         TESTS::
 
             sage: from sage.structure.parent_base import ParentWithBase
+            sage: from sage.interfaces.singular import singular
             sage: ParentWithBase.__getattribute__(singular, '_coerce_map_from_')
             <bound method Singular._coerce_map_from_ of Singular>
         """
@@ -711,7 +716,7 @@ class InterfaceFunctionElement(SageObject):
 
 def is_InterfaceElement(x):
     """
-    Return True if ``x`` is of type :class:`InterfaceElement`.
+    Return ``True`` if ``x`` is of type :class:`InterfaceElement`.
 
     EXAMPLES::
 
@@ -787,7 +792,7 @@ class InterfaceElement(Element):
 
     def __reduce__(self):
         """
-        The default linearisation is to return self's parent,
+        The default linearisation is to return ``self``'s parent,
         which will then get the items returned by :meth:`_reduce`
         as arguments to reconstruct the element.
 
@@ -841,7 +846,6 @@ class InterfaceElement(Element):
             Traceback (most recent call last):
             ...
             TypeError: unable to make sense of Maxima expression '"abc"' in Sage
-
         """
         return self.parent(), (self._reduce(),)
 
@@ -849,11 +853,11 @@ class InterfaceElement(Element):
         """
         Helper for pickling.
 
-        By default, if self is a string, then the representation of
+        By default, if ``self`` is a string, then the representation of
         that string is returned (not the string itself). Otherwise,
         it is attempted to return the corresponding Sage object.
-        If this fails with a NotImplementedError, the string
-        representation of self is returned instead.
+        If this fails with a :exc:`NotImplementedError`, the string
+        representation of ``self`` is returned instead.
 
         EXAMPLES::
 
@@ -881,13 +885,13 @@ class InterfaceElement(Element):
         by the doctests because the original identifier was reused. This test makes sure
         that does not happen again::
 
-            sage: a = r("'abc'")                                                  # optional - rpy2
-            sage: b = dumps(a)                                                    # optional - rpy2
-            sage: r.set(a.name(), 0) # make sure that identifier reuse            # optional - rpy2
+            sage: # optional - rpy2
+            sage: a = r("'abc'")
+            sage: b = dumps(a)
+            sage: r.set(a.name(), 0) # make sure that identifier reuse
             ....:                    # does not accidentally lead to success
-            sage: loads(b)                                                        # optional - rpy2
+            sage: loads(b)
             [1] "abc"
-
         """
         if self.is_string():
             return repr(self.sage())
@@ -918,8 +922,8 @@ class InterfaceElement(Element):
 
     def __hash__(self):
         """
-        Returns the hash of self. This is a default implementation of hash
-        which just takes the hash of the string of self.
+        Return the hash of ``self``. This is a default implementation of hash
+        which just takes the hash of the string of ``self``.
         """
         return hash('%s' % self)
 
@@ -953,27 +957,26 @@ class InterfaceElement(Element):
 
         Here, GAP fails to compare, and so ``False`` is returned.
         In previous Sage versions, this example actually resulted
-        in an error; compare :trac:`5962`.
+        in an error; compare :issue:`5962`.
         ::
 
             sage: gap('DihedralGroup(8)')==gap('DihedralGroup(8)')
             False
-
         """
         P = self._check_valid()
         try:
-            if P.eval("%s %s %s"%(self.name(), P._equality_symbol(),
+            if P.eval("%s %s %s" % (self.name(), P._equality_symbol(),
                                      other.name())) == P._true_symbol():
                 return rich_to_bool(op, 0)
         except RuntimeError:
             pass
         try:
-            if P.eval("%s %s %s"%(self.name(), P._lessthan_symbol(), other.name())) == P._true_symbol():
+            if P.eval("%s %s %s" % (self.name(), P._lessthan_symbol(), other.name())) == P._true_symbol():
                 return rich_to_bool(op, -1)
         except RuntimeError:
             pass
         try:
-            if P.eval("%s %s %s"%(self.name(), P._greaterthan_symbol(), other.name())) == P._true_symbol():
+            if P.eval("%s %s %s" % (self.name(), P._greaterthan_symbol(), other.name())) == P._true_symbol():
                 return rich_to_bool(op, 1)
         except Exception:
             pass
@@ -1004,7 +1007,7 @@ class InterfaceElement(Element):
         try:
             P = self.parent()
             if P is None:
-                raise ValueError("The %s session in which this object was defined is no longer running."%P.name())
+                raise ValueError("The %s session in which this object was defined is no longer running." % P.name())
         except AttributeError:
             raise ValueError("The session in which this object was defined is no longer running.")
         return P
@@ -1014,9 +1017,9 @@ class InterfaceElement(Element):
             self._check_valid()
         except ValueError:
             return
-        if hasattr(self,'_name'):
+        if hasattr(self, '_name'):
             P = self.parent()
-            if not (P is None):
+            if P is not None:
                 P.clear(self._name)
 
     def _sage_repr(self):
@@ -1042,8 +1045,7 @@ class InterfaceElement(Element):
         ::
 
             sage: gp(10.^80)._sage_repr()
-            '1.0000000000000000000000000000000000000e80'    # 64-bit
-            '1.000000000000000000000000000e80'              # 32-bit
+            '1.0000000000000000000000000000000000000e80'
             sage: mathematica('10.^80')._sage_repr()  # optional - mathematica
             '1.e80'
 
@@ -1051,9 +1053,9 @@ class InterfaceElement(Element):
 
         - Felix Lawrence (2009-08-21)
         """
-        #TO DO: this could use file transfers when self.is_remote()
+        # TO DO: this could use file transfers when self.is_remote()
 
-        string = repr(self).replace('\n',' ').replace('\r', '')
+        string = repr(self).replace('\n', ' ').replace('\r', '')
         # Translate the external program's function notation to Sage's
         lfd = self.parent()._left_func_delim()
         if '(' != lfd:
@@ -1158,7 +1160,6 @@ class InterfaceElement(Element):
             sage: singular.quit()
             sage: s
             (invalid Singular object -- The singular session in which this object was defined is no longer running.)
-
         """
         try:
             self._check_valid()
@@ -1169,11 +1170,8 @@ class InterfaceElement(Element):
             s = cr
         else:
             s = self._repr_()
-        if self._name in s:
-            try:
-                s = s.replace(self._name, getattr(self, '__custom_name'))
-            except AttributeError:
-                pass
+        if self._name in s and self.get_custom_name() is not None:
+            s = s.replace(self._name, self.get_custom_name())
         if cr:
             self._cached_repr = s
         return s
@@ -1188,7 +1186,7 @@ class InterfaceElement(Element):
 
         TESTS:
 
-        In :trac:`22501`, several string representation methods have been
+        In :issue:`22501`, several string representation methods have been
         removed in favour of using the default implementation. The corresponding
         tests have been moved here::
 
@@ -1197,12 +1195,12 @@ class InterfaceElement(Element):
             sage: gap(2)
             2
             sage: x = var('x')
-            sage: giac(x)
+            sage: giac(x)  # needs giac
             sageVARx
-            sage: giac(5)
+            sage: giac(5)  # needs giac
             5
             sage: M = matrix(QQ,2,range(4))
-            sage: giac(M)
+            sage: giac(M)  # needs giac
             [[0,1],[2,3]]
             sage: x = var('x')                  # optional - maple
             sage: maple(x)                      # optional - maple
@@ -1217,7 +1215,6 @@ class InterfaceElement(Element):
             sage: mupad.package('"MuPAD-Combinat"')  # optional - mupad-Combinat
             sage: S = mupad.examples.SymmetricFunctions(); S # optional - mupad-Combinat
             examples::SymmetricFunctions(Dom::ExpressionField())
-
         """
         P = self.parent()
         try:
@@ -1238,7 +1235,7 @@ class InterfaceElement(Element):
     def get_using_file(self):
         """
         Return this element's string representation using a file. Use this
-        if self has a huge string representation. It'll be way faster.
+        if ``self`` has a huge string representation. It'll be way faster.
 
         EXAMPLES::
 
@@ -1254,7 +1251,7 @@ class InterfaceElement(Element):
 
     def hasattr(self, attrname):
         """
-        Returns whether the given attribute is already defined by this
+        Return whether the given attribute is already defined by this
         object, and in particular is not dynamically generated.
 
         EXAMPLES::
@@ -1288,14 +1285,14 @@ class InterfaceElement(Element):
             -122023936/161051
         """
         P = self._check_valid()
-        return P('%s.%s'%(self.name(), attrname))
+        return P('%s.%s' % (self.name(), attrname))
 
     def __getitem__(self, n):
         P = self._check_valid()
         if not isinstance(n, tuple):
-            return P.new('%s[%s]'%(self._name, n))
+            return P.new('%s[%s]' % (self._name, n))
         else:
-            return P.new('%s[%s]'%(self._name, str(n)[1:-1]))
+            return P.new('%s[%s]' % (self._name, str(n)[1:-1]))
 
     def __int__(self):
         """
@@ -1318,7 +1315,6 @@ class InterfaceElement(Element):
             False
             sage: singular(1).bool()
             True
-
         """
         return bool(self)
 
@@ -1342,9 +1338,9 @@ class InterfaceElement(Element):
         TESTS:
 
         By default this returns ``True`` for elements that are considered to be
-        not ``False`` by the interface (:trac:`28705`)::
+        not ``False`` by the interface (:issue:`28705`)::
 
-            sage: bool(giac('"a"'))
+            sage: bool(giac('"a"'))  # needs giac
             True
         """
         P = self._check_valid()
@@ -1376,8 +1372,8 @@ class InterfaceElement(Element):
             sage: QQ(m)
             1
         """
-        import sage.rings.all
-        return sage.rings.all.Integer(repr(self))
+        from sage.rings.integer import Integer
+        return Integer(repr(self))
 
     def _rational_(self):
         """
@@ -1391,26 +1387,27 @@ class InterfaceElement(Element):
             sage: QQ(m)
             1/2
         """
-        import sage.rings.all
-        return sage.rings.all.Rational(repr(self))
+        from sage.rings.rational import Rational
+        return Rational(repr(self))
 
     def name(self, new_name=None):
         """
-        Returns the name of self. If new_name is passed in, then this
-        function returns a new object identical to self whose name is
-        new_name.
+        Return the name of ``self``. If ``new_name`` is passed in, then this
+        function returns a new object identical to ``self`` whose name is
+        ``new_name``.
 
         Note that this can overwrite existing variables in the system.
 
         EXAMPLES::
 
-            sage: x = r([1,2,3]); x                                               # optional - rpy2
+            sage: # optional - rpy2
+            sage: x = r([1,2,3]); x
             [1] 1 2 3
-            sage: x.name()                                                        # optional - rpy2
+            sage: x.name()
             'sage...'
-            sage: x = r([1,2,3]).name('x'); x                                     # optional - rpy2
+            sage: x = r([1,2,3]).name('x'); x
             [1] 1 2 3
-            sage: x.name()                                                        # optional - rpy2
+            sage: x.name()
             'x'
 
         ::
@@ -1432,7 +1429,7 @@ class InterfaceElement(Element):
 
     def gen(self, n):
         P = self._check_valid()
-        return P.new('%s.%s'%(self._name, int(n)))
+        return P.new('%s.%s' % (self._name, int(n)))
 
     def _operation(self, operation, other=None):
         r"""
@@ -1446,11 +1443,11 @@ class InterfaceElement(Element):
 
         INPUT:
 
-        - ``operation`` -- a string representing the operation
-          being performed. For example, '*', or '1/'.
+        - ``operation`` -- string representing the operation
+          being performed; for example, '*', or '1/'
 
-        - ``other`` -- the other operand. If ``other`` is ``None``,
-          then the operation is assumed to be unary rather than binary.
+        - ``other`` -- the other operand; if ``other`` is ``None``,
+          then the operation is assumed to be unary rather than binary
 
         OUTPUT: an interface element
 
@@ -1469,9 +1466,9 @@ class InterfaceElement(Element):
         """
         P = self._check_valid()
         if other is None:
-            cmd = '%s %s'%(operation, self._name)
+            cmd = '%s %s' % (operation, self._name)
         else:
-            cmd = '%s %s %s'%(self._name, operation, other._name)
+            cmd = '%s %s %s' % (self._name, operation, other._name)
         try:
             return P.new(cmd)
         except Exception as msg:
