@@ -5,7 +5,7 @@ Sage provides an interface to the Magma computational algebra
 system. This system provides extensive functionality for number
 theory, group theory, combinatorics and algebra.
 
-.. note::
+.. NOTE::
 
    You must have Magma installed on your
    computer for this interface to work. Magma is not free, so it is
@@ -14,15 +14,15 @@ theory, group theory, combinatorics and algebra.
 
 The Magma interface offers three pieces of functionality:
 
-#. ``magma_console()`` -- A function that dumps you into an interactive command-line Magma session.
+#. ``magma_console()`` -- a function that dumps you into an interactive command-line Magma session.
 
-#. ``magma.new(obj)`` and alternatively ``magma(obj)`` -- Creation of a Magma object from a Sage object ``obj``.
+#. ``magma.new(obj)`` and alternatively ``magma(obj)`` -- creation of a Magma object from a Sage object ``obj``.
    This provides a Pythonic interface to Magma. For example, if ``f=magma.new(10)``, then
    ``f.Factors()`` returns the prime factorization of 10 computed using Magma. If obj is a string containing
    an arbitrary Magma expression, then the expression is evaluated in Magma to create a Magma object. An example
    is ``magma.new('10 div 3')``, which returns Magma integer 3.
 
-#. ``magma.eval(expr)`` -- Evaluation of the Magma expression ``expr``, with the result returned as a string.
+#. ``magma.eval(expr)`` -- evaluation of the Magma expression ``expr``, with the result returned as a string.
 
 Type ``magma.[tab]`` for a list of all functions available from your Magma.
 Type ``magma.Function?`` for Magma's help about the Magma ``Function``.
@@ -281,7 +281,7 @@ class Magma(ExtraTabCompletion, Expect):
     object, and ``magma.eval(...)`` to run a string using
     Magma (and get the result back as a string).
 
-    .. note::
+    .. NOTE::
 
        If you do not own a local copy of Magma, try using the
        ``magma_free`` command instead, which uses the free demo web
@@ -309,23 +309,23 @@ class Magma(ExtraTabCompletion, Expect):
         """
         INPUT:
 
-        -  ``script_subdirectory`` -- directory where scripts
-           are read from
+        - ``script_subdirectory`` -- directory where scripts
+          are read from
 
-        -  ``logfile`` -- output logged to this file
+        - ``logfile`` -- output logged to this file
 
-        -  ``server`` -- address of remote server
+        - ``server`` -- address of remote server
 
         - ``server_tmpdir`` -- temporary directory to use in remote server
 
-        -  ``user_config`` -- if True, then local user
-           configuration files will be read by Magma. If False (the default),
-           then Magma is started with the -n option which suppresses user
-           configuration files.
+        - ``user_config`` -- if ``True``, then local user
+          configuration files will be read by Magma. If ``False`` (the default),
+          then Magma is started with the -n option which suppresses user
+          configuration files.
 
-        - ``seed`` -- Seed to use in the random number generator.
+        - ``seed`` -- seed to use in the random number generator
 
-        -  ``command`` -- (Default: 'magma') The command to execute to start Magma.
+        - ``command`` -- (default: ``'magma'``) the command to execute to start Magma
 
         EXAMPLES::
 
@@ -344,8 +344,8 @@ class Magma(ExtraTabCompletion, Expect):
             seed = os.getenv('SAGE_MAGMA_SEED')
 
         Expect.__init__(self,
-                        name="magma",
-                        prompt=">>SAGE>>",
+                        name='magma',
+                        prompt='>>SAGE>>',
                         command=command,
                         server=server,
                         server_tmpdir=server_tmpdir,
@@ -420,15 +420,11 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``filename`` -- string
-
+        - ``filename`` -- string
 
         OUTPUT:
 
-
-        -  ``string`` -- a magma command
-
+        - ``string`` -- a magma command
 
         EXAMPLES::
 
@@ -446,11 +442,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``s`` -- string
 
-        -  ``s`` -- a string
-
-
-        OUTPUT: a string
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -471,15 +465,13 @@ class Magma(ExtraTabCompletion, Expect):
     def __getattr__(self, attrname):
         """
         Return a formal wrapper around a Magma function, or raise an
-        AttributeError if attrname starts with an underscore.
+        :exc:`AttributeError` if attrname starts with an underscore.
 
         INPUT:
 
+        - ``attrname`` -- string
 
-        -  ``attrname`` -- a string
-
-
-        OUTPUT: MagmaFunction instance
+        OUTPUT: :class:`MagmaFunction` instance
 
         EXAMPLES::
 
@@ -509,10 +501,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-        -  ``x`` -- string of code
-
-        -  ``strip`` -- ignored
+        - ``x`` -- string of code
 
+        - ``strip`` -- ignored
 
         OUTPUT: string
 
@@ -552,7 +543,6 @@ class Magma(ExtraTabCompletion, Expect):
             True
             sage: magma.eval("[a,b];")                  # optional - magma
             '[ 3, 5 ]'
-
         """
         x = self._preparse(x)
         x = str(x).rstrip()
@@ -615,11 +605,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``var`` -- string; a variable name
 
-        -  ``var`` -- string; a variable name
-
-        -  ``value`` -- string; what to set var equal to
-
+        - ``value`` -- string; what to set var equal to
 
         EXAMPLES::
 
@@ -637,17 +625,10 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``var`` -- string; name of a variable defined in the
+          Magma session
 
-        -  ``var`` -- string; name of a variable defined in the
-           Magma session
-
-
-        OUTPUT:
-
-
-        -  ``string`` -- string representation of the value of
-           the variable.
-
+        OUTPUT: string representation of the value of the variable
 
         EXAMPLES::
 
@@ -663,13 +644,11 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
         - ``value`` -- something coercible to an element of this Magma
-           interface
+          interface
 
         - ``gens`` -- string; comma separated list of variable names
 
-
         OUTPUT: new Magma element that is equal to value with given gens
 
         EXAMPLES::
@@ -706,14 +685,12 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``x`` -- object
 
-        -  ``x`` -- object
+        - ``gens`` -- string; names of generators of self,
+          separated by commas
 
-        -  ``gens`` -- string; names of generators of self,
-           separated by commas
-
-
-        OUTPUT: MagmaElement
+        OUTPUT: :class:`MagmaElement`
 
         EXAMPLES::
 
@@ -816,10 +793,10 @@ class Magma(ExtraTabCompletion, Expect):
 
     def _coerce_from_special_method(self, x):
         """
-        Tries to coerce to self by calling a special underscore method.
+        Try to coerce to ``self`` by calling a special underscore method.
 
-        If no such method is defined, raises an AttributeError instead of a
-        TypeError.
+        If no such method is defined, raises an :exc:`AttributeError` instead
+        of a :exc:`TypeError`.
 
         EXAMPLES::
 
@@ -852,11 +829,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``s`` -- string
 
-        -  ``s`` -- string
-
-        -  ``names`` -- list of strings
-
+        - ``names`` -- list of strings
 
         OUTPUT: string
 
@@ -875,9 +850,7 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``var`` -- a string
-
+        - ``var`` -- string
 
         EXAMPLES::
 
@@ -926,16 +899,12 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``t`` -- float (default: None); if not None, return
-           cputime since t
-
+        - ``t`` -- float (default: ``None``); if not None, return
+          cputime since t
 
         OUTPUT:
 
-
-        -  ``float`` -- seconds
-
+        - ``float`` -- seconds
 
         EXAMPLES::
 
@@ -959,7 +928,7 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-        -  ``dir`` -- a string
+        - ``dir`` -- string
 
         EXAMPLES::
 
@@ -982,9 +951,7 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``filename`` -- a string
-
+        - ``filename`` -- string
 
         EXAMPLES: Attaching a file that exists is fine::
 
@@ -1012,9 +979,7 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``filename`` -- a string
-
+        - ``filename`` -- string
 
         EXAMPLES::
 
@@ -1043,16 +1008,14 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``filename`` -- string
-
+        - ``filename`` -- string
 
         OUTPUT: output printed when loading the file
 
         EXAMPLES::
 
             sage: from tempfile import NamedTemporaryFile as NTF
-            sage: with NTF(mode="w+t", suffix=".m") as f:  # optional - magma
+            sage: with NTF(mode='w+t', suffix='.m') as f:  # optional - magma
             ....:     _ = f.write('function f(n) return n^2; end function;\nprint "hi";')
             ....:     print(magma.load(f.name))
             Loading ".../a.m"
@@ -1120,20 +1083,19 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``function`` -- string, a Magma function name
 
-        -  ``function`` -- string, a Magma function name
+        - ``args`` -- list of objects coercible into this magma
+          interface
 
-        -  ``args`` -- list of objects coercible into this magma
-           interface
+        - ``params`` -- Magma parameters, passed in after a
+          colon
 
-        -  ``params`` -- Magma parameters, passed in after a
-           colon
+        - ``nvals`` -- number of return values from the
+          function to ask Magma for
 
-        -  ``nvals`` -- number of return values from the
-           function to ask Magma for
-
-
-        OUTPUT: MagmaElement or tuple of nvals MagmaElement's
+        OUTPUT: instance of :class:`MagmaElement` or a tuple of ``nvals`` many
+        :class:`MagmaElement` instances
 
         EXAMPLES::
 
@@ -1178,11 +1140,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``code`` -- string; code to evaluate
 
-        -  ``code`` -- a string; code to evaluate
-
-        -  ``nvals`` -- an integer; number of return values
-
+        - ``nvals`` -- integer; number of return values
 
         OUTPUT: nvals distinct values
 
@@ -1232,7 +1192,7 @@ class Magma(ExtraTabCompletion, Expect):
 
     def bar_call(self, left, name, gens, nvals=1):
         """
-        This is a wrapper around the Magma constructor
+        This is a wrapper around the Magma constructor.
 
         nameleft gens
 
@@ -1240,18 +1200,16 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``left`` -- something coerceable to a magma object
 
-        -  ``left`` -- something coerceable to a magma object
+        - ``name`` -- name of the constructor, e.g., sub, quo,
+          ideal, etc.
 
-        -  ``name`` -- name of the constructor, e.g., sub, quo,
-           ideal, etc.
-
-        -  ``gens`` -- if a list/tuple, each item is coerced to
-           magma; otherwise gens itself is converted to magma
-
-        -  ``nvals`` -- positive integer; number of return
-           values
+        - ``gens`` -- if a list/tuple, each item is coerced to
+          magma; otherwise gens itself is converted to magma
 
+        - ``nvals`` -- positive integer; number of return
+          values
 
         OUTPUT: a single magma object if nvals == 1; otherwise a tuple of
         nvals magma objects.
@@ -1420,11 +1378,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         OUTPUT:
 
+        - ``numbers`` -- 3-tuple: major, minor, etc.
 
-        -  ``numbers`` -- 3-tuple: major, minor, etc.
-
-        -  ``string`` -- version as a string
-
+        - ``string`` -- version as a string
 
         EXAMPLES::
 
@@ -1442,9 +1398,7 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``s`` -- string
-
+        - ``s`` -- string
 
         OUTPUT: string
 
@@ -1474,14 +1428,12 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``verbose`` -- boolean (default: ``True``); whether to
+          verbosely output status info the first time the command list is
+          built
 
-        -  ``verbose`` -- bool (default: ``True``); whether to
-           verbosely output status info the first time the command list is
-           built
-
-        -  ``use_disk_cache`` -- bool (default: ``True``); use
-           cached command list, which is saved to disk.
-
+        - ``use_disk_cache`` -- boolean (default: ``True``); use
+          cached command list, which is saved to disk
 
         OUTPUT: list of strings
 
@@ -1536,12 +1488,10 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``L`` -- list of elements of a Sage multivariate
+          polynomial ring
 
-        -  ``L`` -- a list of elements of a Sage multivariate
-           polynomial ring.
-
-
-        OUTPUT: The magma ideal generated by the elements of L.
+        OUTPUT: the magma ideal generated by the elements of L
 
         EXAMPLES::
 
@@ -1574,9 +1524,9 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-        -  ``type`` -- string (e.g. 'Groebner')
+        - ``type`` -- string (e.g. 'Groebner')
 
-        -  ``level`` -- integer >= 0
+        - ``level`` -- integer >= 0
 
         EXAMPLES::
 
@@ -1596,10 +1546,8 @@ class Magma(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``type`` -- string (e.g. 'Groebner'), see Magma
-           documentation
-
+        - ``type`` -- string (e.g. 'Groebner'), see Magma
+          documentation
 
         EXAMPLES::
 
@@ -1828,13 +1776,14 @@ class MagmaFunction(ExpectFunction):
 
 def is_MagmaElement(x):
     """
-    Return True if ``x`` is of type :class:`MagmaElement`, and False otherwise.
+    Return ``True`` if ``x`` is of type :class:`MagmaElement`, and ``False``
+    otherwise.
 
     INPUT:
 
-    -  ``x`` -- any object
+    - ``x`` -- any object
 
-    OUTPUT: bool
+    OUTPUT: boolean
 
     EXAMPLES::
 
@@ -1901,15 +1850,15 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
         """
         INPUT:
 
-        -  ``attrname`` -- string
+        - ``attrname`` -- string
 
-        OUTPUT: a Magma function partially evaluated with self as the first
-        input.
+        OUTPUT: a Magma function partially evaluated with ``self`` as the first
+        input
 
-        .. note::
+        .. NOTE::
 
            If the input ``attrname`` starts with an underscore, an
-           :class:`AttributeError` is raised so that the actual
+           :exc:`AttributeError` is raised so that the actual
            Python _ method/value can be accessed.
 
         EXAMPLES::
@@ -2121,16 +2070,15 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def gen(self, n):
         """
-        Return the n-th generator of this Magma element. Note that
-        generators are 1-based in Magma rather than 0 based!
+        Return the `n`-th generator of this Magma element. Note that
+        generators are 1-based in Magma rather than 0-based!
 
         INPUT:
 
-
-        -  ``n`` -- a *positive* integer
+        - ``n`` -- *positive* integer
 
 
-        OUTPUT: MagmaElement
+        OUTPUT: :class:`MagmaElement`
 
         EXAMPLES::
 
@@ -2162,7 +2110,7 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
         """
         Return generators for ``self``.
 
-        If self is named X in Magma, this function evaluates X.1, X.2,
+        If ``self`` is named X in Magma, this function evaluates X.1, X.2,
         etc., in Magma until an error occurs. It then returns a Sage tuple
         of the resulting X.i. Note - I don't think there is a Magma command
         that returns the list of valid X.i. There are numerous ad hoc
@@ -2201,9 +2149,9 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def gen_names(self):
         """
-        Return list of Magma variable names of the generators of self.
+        Return list of Magma variable names of the generators of ``self``.
 
-        .. note::
+        .. NOTE::
 
            As illustrated below, these are not the print names of the
            the generators of the Magma object, but special variable
@@ -2226,11 +2174,11 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def evaluate(self, *args):
         r"""
-        Evaluate self at the inputs.
+        Evaluate ``self`` at the inputs.
 
         INPUT:
 
-        -  ``*args`` -- import arguments
+        - ``*args`` -- import arguments
 
         OUTPUT: self(\*args)
 
@@ -2292,7 +2240,7 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
         .. warning::
 
-           Internally this constructs the list of elements in self in
+           Internally this constructs the list of elements in ``self`` in
            Magma, which is not a lazy operation. This is because Magma
            doesn't have a notion of lazy iterators, unfortunately.
 
@@ -2338,8 +2286,8 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def _polynomial_(self, R):
         """
-        Try to convert self into a polynomial in the univariate polynomial
-        ring R.
+        Try to convert ``self`` into a polynomial in the univariate polynomial
+        ring `R`.
 
         EXAMPLES::
 
@@ -2356,32 +2304,30 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def _latex_(self):
         r"""
-        Return latex representation of self.
+        Return latex representation of ``self``.
 
         AUTHORS:
 
         - Jennifer Balakrishnan
 
-        Types that are nicely latex include:
+        Types that are nicely latexed include:
 
+        - rationals
 
-        -  rationals
+        - matrices
 
-        -  matrices
+        - polynomials
 
-        -  polynomials
+        - binary quadratic forms
 
-        -  binary quadratic forms
+        - elements of quadratic, cyclotomic number fields, and general
+          number fields
 
-        -  elements of quadratic, cyclotomic number fields, and general
-           number fields
+        - points
 
-        -  points
-
-        -  elliptic curves
-
-        -  power series
+        - elliptic curves
 
+        - power series
 
         IMPLEMENTATION: Calls latex.m, which is in
         SAGE_EXTCODE/magma/latex.m
@@ -2465,7 +2411,7 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
             sage: latex(magma('(-1/(2+x + O(x^3)))'))
             \frac{-1}{2}+\frac{1}{4}x-\frac{1}{8}x^{2}+O(x^{3})
 
-        p-adic Numbers::
+        `p`-adic Numbers::
 
             sage: latex(magma('pAdicField(7,4)!9333294394/49'))              # optional - magma
             4\cdot{}7^{-2} + 5\cdot{}7^{-1} + 5+ 6\cdot{}7^{1} + O(7^{2})
@@ -2479,8 +2425,10 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def set_magma_attribute(self, attrname, value):
         """
-        INPUT: attrname - string value - something coercible to a
-        MagmaElement
+        INPUT:
+
+        - ``attrname`` -- string
+        - ``value`` -- something coercible to a MagmaElement
 
         EXAMPLES::
 
@@ -2502,7 +2450,7 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
         Return value of a given Magma attribute. This is like selfattrname
         in Magma.
 
-        OUTPUT: MagmaElement
+        OUTPUT: :class:`MagmaElement`
 
         EXAMPLES::
 
@@ -2539,19 +2487,17 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
         Return all Magma functions that have this Magma element as first
         input. This is used for tab completion.
 
-        .. note::
+        .. NOTE::
 
            This function can unfortunately be slow if there are a very
-           large number of functions, e.g., when self is an
+           large number of functions, e.g., when ``self`` is an
            integer. (This could be fixed by the addition of an
            appropriate function to the Magma kernel, which is
            something that can only be done by the Magma developers.)
 
         OUTPUT:
 
-
-        -  ``list`` -- sorted list of distinct strings
-
+        - ``list`` -- sorted list of distinct strings
 
         EXAMPLES::
 
@@ -2570,13 +2516,13 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def methods(self, any=False):
         """
-        Return signatures of all Magma intrinsics that can take self as the
+        Return signatures of all Magma intrinsics that can take ``self`` as the
         first argument, as strings.
 
         INPUT:
 
-        - ``any`` -- (bool: default is False) if True, also
-          include signatures with Any as first argument.
+        - ``any`` -- boolean (default: ``False``); if ``True``, also
+          include signatures with Any as first argument
 
         OUTPUT: list of strings
 
@@ -2602,8 +2548,8 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def __floordiv__(self, x):
         """
-        Quotient of division of self by other. This is denoted // ("div" in
-        magma).
+        Quotient of division of ``self`` by ``other``. This is denoted ``//``
+        (``div`` in magma).
 
         EXAMPLES::
 
@@ -2685,11 +2631,11 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def sub(self, gens):
         """
-        Return the sub-object of self with given gens.
+        Return the sub-object of ``self`` with given gens.
 
         INPUT:
 
-        -  ``gens`` -- object or list/tuple of generators
+        - ``gens`` -- object or list/tuple of generators
 
         EXAMPLES::
 
@@ -2707,24 +2653,20 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def quo(self, gens, **args):
         """
-        Return the quotient of self by the given object or list of
+        Return the quotient of ``self`` by the given object or list of
         generators.
 
         INPUT:
 
-
-        -  ``gens`` -- object or list/tuple of generators
+        - ``gens`` -- object or list/tuple of generators
         - further named arguments that are ignored
 
-
         OUTPUT:
 
+        - ``magma element`` -- the quotient object
 
-        -  ``magma element`` -- the quotient object
-
-        -  ``magma element`` -- mapping from self to the
-           quotient object
-
+        - ``magma element`` -- mapping from ``self`` to the
+          quotient object
 
         EXAMPLES::
 
@@ -2756,19 +2698,15 @@ class MagmaElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.MagmaE
 
     def ideal(self, gens):
         """
-        Return the ideal of self with given list of generators.
+        Return the ideal of ``self`` with given list of generators.
 
         INPUT:
 
-
-        -  ``gens`` -- object or list/tuple of generators
-
+        - ``gens`` -- object or list/tuple of generators
 
         OUTPUT:
 
-
-        -  ``magma element`` -- a Magma ideal
-
+        - ``magma element`` -- a Magma ideal
 
         EXAMPLES::
 
@@ -2840,7 +2778,7 @@ class MagmaGBLogPrettyPrinter:
 
         - ``style`` -- if "magma" the full Magma log is printed; if
           'sage' only the current degree and the number of pairs in
-          the queue is printed (default: "magma").
+          the queue is printed (default: ``'magma'``).
 
         EXAMPLES::
 
@@ -2968,8 +2906,7 @@ class MagmaGBLogPrettyPrinter:
                 pol_curr, col_curr = map(int, match.groups())
 
                 if pol_curr != 0:
-                    if self.max_deg < self.curr_deg:
-                        self.max_deg = self.curr_deg
+                    self.max_deg = max(self.max_deg, self.curr_deg)
 
                     if style == "sage" and verbosity >= 1:
                         print("Leading term degree: %2d. Critical pairs: %d." %
