@@ -92,6 +92,7 @@ from sage.misc.decorators import options
 from sage.symbolic.expression import Expression
 from sage.rings.integer_ring import ZZ
 
+
 class ManifoldPoint(Element):
     r"""
     Point of a topological manifold.
@@ -111,9 +112,9 @@ class ManifoldPoint(Element):
     - ``name`` -- (default: ``None``) name given to the point
     - ``latex_name`` -- (default: ``None``) LaTeX symbol to denote the point;
       if ``None``, the LaTeX symbol is set to ``name``
-    - ``check_coords`` -- (default: ``True``) determines whether ``coords``
-      are valid coordinates for the chart ``chart``; for symbolic
-      coordinates, it is recommended to set ``check_coords`` to ``False``
+    - ``check_coords`` -- boolean (default: ``True``); determines whether ``coords``
+      are valid coordinates for the chart ``chart``. For symbolic
+      coordinates, it is recommended to set ``check_coords`` to ``False``.
 
     EXAMPLES:
 
@@ -179,7 +180,6 @@ class ManifoldPoint(Element):
             sage: q = U((-1,2), name='q'); q
             Point q on the 2-dimensional topological manifold M
             sage: TestSuite(q).run()
-
         """
         if parent.is_empty():
             raise TypeError(f'cannot define a point on the {parent} because it has been declared empty')
@@ -231,7 +231,6 @@ class ManifoldPoint(Element):
             'Point p on the 2-dimensional topological manifold M'
             sage: repr(p)  # indirect doctest
             'Point p on the 2-dimensional topological manifold M'
-
         """
         description = "Point"
         if self._name is not None:
@@ -258,7 +257,6 @@ class ManifoldPoint(Element):
             '\\mathcal{P}'
             sage: latex(p)  # indirect doctest
             \mathcal{P}
-
         """
         if self._latex_name is None:
             return r'\text{' + str(self) + r'}'
@@ -366,7 +364,6 @@ class ManifoldPoint(Element):
             {Chart (M, (u, v)): (a - b, a + b),
              Chart (M, (w, z)): (a^3 - 3*a^2*b + 3*a*b^2 - b^3,
                                  a^3 + 3*a^2*b + 3*a*b^2 + b^3)}
-
         """
         if chart is None:
             dom = self.parent()
@@ -436,7 +433,7 @@ class ManifoldPoint(Element):
 
     def set_coordinates(self, coords, chart=None):
         r"""
-        Sets the point coordinates in the specified chart.
+        Set the point coordinates in the specified chart.
 
         Coordinates with respect to other charts are deleted, in order to
         avoid any inconsistency. To keep them, use the method :meth:`add_coord`
@@ -484,7 +481,6 @@ class ManifoldPoint(Element):
             sage: p.set_coord(Y(p), chart=Y)
             sage: p._coordinates
             {Chart (M, (u, v)): (-1, 5)}
-
         """
         self._coordinates.clear()
         self.add_coord(coords, chart)
@@ -493,7 +489,7 @@ class ManifoldPoint(Element):
 
     def add_coordinates(self, coords, chart=None):
         r"""
-        Adds some coordinates in the specified chart.
+        Add some coordinates in the specified chart.
 
         The previous coordinates with respect to other charts are kept. To
         clear them, use :meth:`set_coord` instead.
@@ -551,7 +547,6 @@ class ManifoldPoint(Element):
             sage: p.set_coordinates((-1,5), chart=Y)
             sage: p._coordinates
             {Chart (M, (u, v)): (-1, 5)}
-
         """
         if len(coords) != self.parent().manifold()._dim:
             raise ValueError("the number of coordinates must be equal to " +
@@ -568,7 +563,7 @@ class ManifoldPoint(Element):
 
     def __eq__(self, other):
         r"""
-        Compares the current point with another one.
+        Compare the current point with another one.
 
         EXAMPLES:
 
@@ -627,7 +622,6 @@ class ManifoldPoint(Element):
             sage: q = M((3*pi,1), chart=Y)
             sage: p == q or q == p
             False
-
         """
         if other is self:
             return True
@@ -696,7 +690,7 @@ class ManifoldPoint(Element):
             diff = xs - xo
             period = periods[ind]
             if period is not None:
-                if not (diff/period in ZZ):
+                if diff/period not in ZZ:
                     return False
             else:
                 if isinstance(diff, Expression) and not diff.is_trivial_zero():
@@ -719,7 +713,6 @@ class ManifoldPoint(Element):
             True
             sage: p != M((2,-3), chart=X)
             False
-
         """
         return not (self == other)
 
@@ -746,7 +739,6 @@ class ManifoldPoint(Element):
             sage: p = M((2,-3), chart=X)
             sage: hash(p) == hash(M)
             True
-
         """
         return hash(self.parent().manifold())
 
@@ -942,7 +934,6 @@ class ManifoldPoint(Element):
             g = p.plot(X, ambient_coords=(y,z), label_offset=0.4)
             gX = X.plot(X, ambient_coords=(y,z))
             sphinx_plot(g+gX)
-
         """
         from sage.plot.point import point2d
         from sage.plot.text import text
