@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-repl
 r"""
 Format Sage documentation for viewing with IPython and the notebook
 
@@ -16,11 +17,11 @@ AUTHORS:
 TESTS:
 
 Check that argspecs of extension function/methods appear correctly,
-see :trac:`12849`::
+see :issue:`12849`::
 
     sage: from sage.env import SAGE_DOC
     sage: docfilename = os.path.join(SAGE_DOC, 'html', 'en', 'reference', 'calculus', 'sage', 'symbolic', 'expression.html')
-    sage: with open(docfilename) as fobj:  # optional - sagemath_doc_html
+    sage: with open(docfilename) as fobj:                                               # needs sagemath_doc_html
     ....:     for line in fobj:
     ....:         if "#sage.symbolic.expression.Expression.numerical_approx" in line:
     ....:             print(line)
@@ -45,8 +46,8 @@ import shutil
 import sys
 import pydoc
 from sage.misc.temporary_file import tmp_dir
-from .viewer import browser
-from . import sageinspect
+from sage.misc.viewer import browser
+from sage.misc import sageinspect
 import sage.version
 from sage.env import SAGE_DOC, SAGE_SRC
 
@@ -126,13 +127,13 @@ def _rmcmd(s, cmd, left='', right=''):
 
     INPUT:
 
-    - ``s`` - (string) string from which to remove the command
+    - ``s`` -- string; string from which to remove the command
 
-    - ``cmd`` - (string) command to be removed.  This should be a
+    - ``cmd`` -- string; command to be removed.  This should be a
       command which takes a single argument, like 'emph' or 'url'; the
       command is removed, but its argument is not.
 
-    - ``left``, ``right`` - (string, optional, default '') add these
+    - ``left``, ``right`` -- string (default: ``''``); add these
       strings at the left and right ends of the command. See the
       examples.
 
@@ -196,16 +197,14 @@ def detex(s, embedded=False):
 
     INPUT:
 
-    - ``s`` - string
-    - ``embedded`` - boolean (optional, default False)
+    - ``s`` -- string
+    - ``embedded`` -- boolean (default: ``False``)
 
-    If ``embedded`` is False, then do the replacements in both
-    ``math_substitutes`` and ``nonmath_substitutes``.  If True, then
+    If ``embedded`` is ``False``, then do the replacements in both
+    ``math_substitutes`` and ``nonmath_substitutes``.  If ``True``, then
     only do ``nonmath_substitutes``.
 
-    OUTPUT:
-
-    string
+    OUTPUT: string
 
     EXAMPLES::
 
@@ -263,7 +262,7 @@ def skip_TESTS_block(docstring):
 
     INPUT:
 
-    - ``docstring``, a string
+    - ``docstring`` -- string
 
     A "TESTS" block is a block starting "TESTS:" (or
     the same with two colons), on a line on its own, and ending either
@@ -338,7 +337,7 @@ def skip_TESTS_block(docstring):
         sage: skip_TESTS_block(start + test + another_fake).rstrip() == start.rstrip()
         True
 
-    Double colons ``::`` are also not considered as headers (:trac:`27896`)::
+    Double colons ``::`` are also not considered as headers (:issue:`27896`)::
 
         sage: colons = ' ::\n\n     sage: 2+2\n     4\n\n'
         sage: skip_TESTS_block(start + test2 + colons).rstrip() == start.rstrip()
@@ -502,18 +501,35 @@ def process_dollars(s):
     return s
 
 
-# Sage github issue shortcuts. For example, :trac:`7549` .
+# When adding roles here, also add them to SAGE_ROOT/src/tox.ini [flake8]
+# and document them in SAGE_ROOT/src/doc/en/developer/sage_manuals.rst
+#
+# Sage github issue shortcuts. For example, :issue:`7549`.
 pythonversion = sys.version.split(' ')[0]
 extlinks = {
     'python': (f'https://docs.python.org/release/{pythonversion}/%s', None),
-    'trac': ('https://github.com/sagemath/sage/issues/%s', 'github issue #%s'), # support :trac: for backward compatibility
-    'issue': ('https://github.com/sagemath/sage/issues/%s', 'github issue #%s'),
+    'issue': ('https://github.com/sagemath/sage/issues/%s', 'Issue #%s'),
+    'sage_root': ('https://github.com/sagemath/sage/tree/develop/%s', 'SAGE_ROOT/%s'),
     'wikipedia': ('https://en.wikipedia.org/wiki/%s', 'Wikipedia article %s'),
     'arxiv': ('https://arxiv.org/abs/%s', 'arXiv %s'),
     'oeis': ('https://oeis.org/%s', 'OEIS sequence %s'),
     'doi': ('https://doi.org/%s', 'doi:%s'),
     'pari': ('https://pari.math.u-bordeaux.fr/dochtml/help/%s', 'pari:%s'),
-    'mathscinet': ('https://www.ams.org/mathscinet-getitem?mr=%s', 'MathSciNet %s')
+    'mathscinet': ('https://www.ams.org/mathscinet-getitem?mr=%s', 'MathSciNet %s'),
+    'common_lisp': ('https://www.lispworks.com/documentation/lw50/CLHS/Body/%s.htm', 'Common Lisp: %s'),
+    'ecl': ('https://ecl.common-lisp.dev/static/manual/%s.html', 'ECL: %s'),
+    'gap': ('https://docs.gap-system.org/doc/ref/%s_mj.html', 'GAP: %s'),
+    'gap_package': ('https://docs.gap-system.org/pkg/%s', 'GAP package %s'),
+    'giac_cascmd': ('https://www-fourier.ujf-grenoble.fr/~parisse/giac/doc/en/cascmd_en/%s.html', 'Giac: %s'),
+    'giac_us': ('https://www-fourier.ujf-grenoble.fr/~parisse/giac_us.html#%s', 'Giac API: %s'),
+    'maxima': ('https://maxima.sourceforge.io/docs/manual/maxima_singlepage.html#%s', 'Maxima: %s'),
+    'meson': ('https://mesonbuild.com/%s', 'Meson: %s'),
+    'polymake': ('https://polymake.org/doku.php/documentation/latest/%s', 'polymake: %s'),
+    'ppl': ('https://www.bugseng.com/products/ppl/documentation/user/ppl-user-1.2-html/%s.html', 'PPL: %s'),
+    'qepcad': ('https://www.usna.edu/CS/qepcadweb/B/%s.html', 'QEPCAD: %s'),
+    'scip': ('https://scipopt.org/doc/html/%s.php', 'SCIP: %s'),
+    'singular': ('https://www.singular.uni-kl.de/Manual/4-3-2/%s.htm', 'Singular: %s'),
+    'soplex': ('https://soplex.zib.de/doc/html/%s.php', 'SoPlex: %s'),
 }
 
 
@@ -533,7 +549,7 @@ def process_extlinks(s, embedded=False):
     INPUT:
 
     - ``s`` -- string, in practice a docstring
-    - ``embedded`` -- boolean (optional, default False)
+    - ``embedded`` -- boolean (default: ``False``)
 
     This function is called by :func:`format`, and if in the notebook,
     it sets ``embedded`` to be ``True``, otherwise ``False``.
@@ -541,7 +557,7 @@ def process_extlinks(s, embedded=False):
     EXAMPLES::
 
         sage: from sage.misc.sagedoc import process_extlinks
-        sage: process_extlinks('See :trac:`1234`, :wikipedia:`Wikipedia <Sage_(mathematics_software)>`, and :trac:`4321` ...')
+        sage: process_extlinks('See :issue:`1234`, :wikipedia:`Wikipedia <Sage_(mathematics_software)>`, and :issue:`4321` ...')
         'See https://github.com/sagemath/sage/issues/1234, https://en.wikipedia.org/wiki/Sage_(mathematics_software), and https://github.com/sagemath/sage/issues/4321 ...'
         sage: process_extlinks('See :issue:`1234` for more information.', embedded=True)
         'See :issue:`1234` for more information.'
@@ -571,7 +587,7 @@ def process_mathtt(s):
 
     INPUT:
 
-    - ``s`` - string, in practice a docstring
+    - ``s`` -- string, in practice a docstring
 
     This function is called by :func:`format`.
 
@@ -623,7 +639,7 @@ def format(s, embedded=False):
     r"""noreplace
     Format Sage documentation ``s`` for viewing with IPython.
 
-    This calls ``detex`` on ``s`` to convert LaTeX commands to plain
+    This calls :func:`detex` on ``s`` to convert LaTeX commands to plain
     text, unless the directive ``nodetex`` is given in the first line
     of the string.
 
@@ -637,13 +653,13 @@ def format(s, embedded=False):
 
     INPUT:
 
-    - ``s`` - string
-    - ``embedded`` - boolean (optional, default False)
+    - ``s`` -- string
+    - ``embedded`` -- boolean (default: ``False``)
 
     OUTPUT: string
 
-    Set ``embedded`` equal to True if formatting for use in the
-    notebook; this just gets passed as an argument to ``detex``.
+    Set ``embedded`` equal to ``True`` if formatting for use in the
+    notebook; this just gets passed as an argument to :func:`detex`.
 
     .. SEEALSO::
 
@@ -653,10 +669,7 @@ def format(s, embedded=False):
     EXAMPLES::
 
         sage: from sage.misc.sagedoc import format
-        sage: identity_matrix(2).rook_vector.__doc__[191:263]
-        'Let `A` be an `m` by `n` (0,1)-matrix. We identify `A` with a chessboard'
-
-        sage: format(identity_matrix(2).rook_vector.__doc__[191:263])
+        sage: format('Let `A` be an `m` by `n` (0,1)-matrix. We identify `A` with a chessboard')
         'Let A be an m by n (0,1)-matrix. We identify A with a chessboard\n'
 
     If the first line of the string is 'nodetex', remove 'nodetex' but
@@ -671,20 +684,20 @@ def format(s, embedded=False):
         '<<<identity_matrix\n'
         sage: format('identity_matrix>>>')
         'identity_matrix>>>\n'
-        sage: format('<<<identity_matrix>>>')
+        sage: format('<<<identity_matrix>>>')                                           # needs sage.modules
         '...Definition: identity_matrix(...'
-        sage: format('<<<identity_matrix>>>')[:28]                            # optional - sphinx
+        sage: format('<<<identity_matrix>>>')[:28]                                      # needs sphinx
         'Definition: identity_matrix('
 
     TESTS:
 
     We check that the todo Sphinx extension is correctly activated::
 
-        sage: sage.misc.sagedoc.format(sage.combinat.ranker.on_fly.__doc__)   # optional - sphinx
-        "   Returns ...  Todo: add tests as in combinat::rankers\n"
+        sage: sage.misc.sagedoc.format(sage.combinat.ranker.on_fly.__doc__)             # needs sphinx
+        "...Return ...Todo: add tests as in combinat::rankers\n"
 
     In the following use case, the ``nodetex`` directive would have been ignored prior
-    to :trac:`11815`::
+    to :issue:`11815`::
 
         sage: cython_code = ["def testfunc(x):",
         ....: "    '''",
@@ -694,9 +707,9 @@ def format(s, embedded=False):
         ....: "    `x \\geq y`",
         ....: "    '''",
         ....: "    return -x"]
-        sage: cython('\n'.join(cython_code))                                    # optional - sage.misc.cython
+        sage: cython('\n'.join(cython_code))                                            # needs sage.misc.cython
         sage: from sage.misc.sageinspect import sage_getdoc
-        sage: print(sage_getdoc(testfunc))                                      # optional - sage.misc.cython
+        sage: print(sage_getdoc(testfunc))                                              # needs sage.misc.cython
         <BLANKLINE>
             This is a doc string with raw latex
         <BLANKLINE>
@@ -704,7 +717,7 @@ def format(s, embedded=False):
         <BLANKLINE>
 
     We check that the ``noreplace`` directive works, even combined with
-    ``nodetex`` (see :trac:`11817`)::
+    ``nodetex`` (see :issue:`11817`)::
 
         sage: print(format('''nodetex, noreplace\n<<<identity_matrix>>>`\\not= 0`'''))
         <<<identity_matrix>>>`\not= 0`
@@ -722,9 +735,9 @@ def format(s, embedded=False):
            Return the n x n identity matrix over the given ring.
         ...
 
-    Check that backslashes are preserved in code blocks (:trac:`29140`)::
+    Check that backslashes are preserved in code blocks (:issue:`29140`)::
 
-        sage: format('::\n'                                                   # optional - sphinx
+        sage: format('::\n'                                                             # needs sphinx
         ....:        '\n'
         ....:        r'    sage: print(r"\\\\.")' '\n'
         ....:        r'    \\\\.')
@@ -759,7 +772,7 @@ def format(s, embedded=False):
     except ImportError:
         pass
 
-    docs = set([])
+    docs = set()
     if 'noreplace' not in directives:
         i_0 = 0
         while True:
@@ -812,7 +825,9 @@ def format_src(s):
     If ``s`` contains a string of the form "<<<obj>>>", then it
     replaces it with the source code for "obj".
 
-    INPUT: ``s`` - string
+    INPUT:
+
+    - ``s`` -- string
 
     OUTPUT: string
 
@@ -821,12 +836,12 @@ def format_src(s):
         sage: from sage.misc.sagedoc import format_src
         sage: format_src('unladen swallow')
         'unladen swallow'
-        sage: format_src('<<<Sq>>>')[5:15]
+        sage: format_src('<<<Sq>>>')[5:15]                                              # needs sage.combinat sage.modules
         'Sq(*nums):'
     """
     if not isinstance(s, str):
         raise TypeError("s must be a string")
-    docs = set([])
+    docs = set()
 
     try:
         import sage.all
@@ -866,10 +881,10 @@ def _search_src_or_doc(what, string, extra1='', extra2='', extra3='',
 
     INPUT:
 
-    - ``what``: either ``'src'`` or ``'doc'``, according to whether you
-      are searching the documentation or source code.
+    - ``what`` -- either ``'src'`` or ``'doc'``, according to whether you
+      are searching the documentation or source code
     - the rest of the input is the same as :func:`search_src`,
-      :func:`search_doc`, and :func:`search_def`.
+      :func:`search_doc`, and :func:`search_def`
 
     OUTPUT:
 
@@ -907,7 +922,7 @@ def _search_src_or_doc(what, string, extra1='', extra2='', extra3='',
         sage: from sage.misc.sagedoc import _search_src_or_doc
         sage: len(_search_src_or_doc('src', r'matrix\(', 'incidence_structures', 'self', 'combinat', interact=False).splitlines()) > 1
         True
-        sage: 'abvar/homology' in _search_src_or_doc('doc', 'homology', 'variety', interact=False)  # optional - sagemath_doc_html, long time (4s on sage.math, 2012)
+        sage: 'abvar/homology' in _search_src_or_doc('doc', 'homology', 'variety', interact=False)  # long time (4s on sage.math, 2012), needs sagemath_doc_html
         True
         sage: 'divisors' in _search_src_or_doc('src', '^ *def prime', interact=False)
         True
@@ -1033,45 +1048,47 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
 
     INPUT:
 
-    - ``string`` - a string to find in the Sage source code.
+    - ``string`` -- string to find in the Sage source code
 
-    - ``extra1``, ..., ``extra5`` - additional strings to require when
-      searching.  Lines must match all of these, as well as ``string``.
+    - ``extra1``, ..., ``extra5`` -- additional strings to require when
+      searching.  Lines must match all of these, as well as ``string``
 
-    - ``whole_word`` (optional, default False) - if True, search for
+    - ``whole_word`` -- (default: ``False``) if ``True``, search for
       ``string`` and ``extra1`` (etc.) as whole words only.  This
       assumes that each of these arguments is a single word, not a
       regular expression, and it might have unexpected results if used
       with regular expressions.
 
-    - ``ignore_case`` (optional, default True) - if False, perform a
+    - ``ignore_case`` -- boolean (default: ``True``); if ``False``, perform a
       case-sensitive search
 
-    - ``multiline`` (optional, default False) - if True, search more
+    - ``multiline`` -- (default: ``False``) if ``True``, search more
       than one line at a time.  In this case, print any matching file
       names, but don't print line numbers.
 
-    - ``interact`` (optional, default ``True``) - if ``False``, return
+    - ``interact`` -- boolean (default: ``True``); if ``False``, return
       a string with all the matches. Otherwise, this function returns
       ``None``, and the results are displayed appropriately, according
       to whether you are using the notebook or the command-line
       interface. You should not ordinarily need to use this.
 
-    - ``path_re`` (optional, default '') - regular expression which
-      the filename (including the path) must match.
+    - ``path_re`` -- (default: ``''``) regular expression which
+      the filename (including the path) must match
 
-    - ``module`` (optional, default 'sage') - the module in which to
+    - ``module`` -- (default: ``'sage'``) the module in which to
       search.  The default is 'sage', the entire Sage library.  If
       ``module`` doesn't start with "sage", then the links in the
       notebook output may not function.
 
-    OUTPUT: If ``interact`` is False, then return a string with all of
+    OUTPUT:
+
+    If ``interact`` is ``False``, then return a string with all of
     the matches, separated by newlines.  On the other hand, if
-    ``interact`` is True (the default), there is no output.  Instead:
+    ``interact`` is ``True`` (the default), there is no output.  Instead:
     at the command line, the search results are printed on the screen
     in the form ``filename:line_number:line of text``, showing the
     filename in which each match occurs, the line number where it
-    occurs, and the actual matching line.  (If ``multiline`` is True,
+    occurs, and the actual matching line.  (If ``multiline`` is ``True``,
     then only the filename is printed for each match.)  The file paths
     in the output are relative to ``$SAGE_SRC``.  In the
     notebook, each match produces a link to the actual file in which
@@ -1080,9 +1097,9 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
     The ``string`` and ``extraN`` arguments are treated as regular
     expressions, as is ``path_re``, and errors will be raised if they
     are invalid. The matches will be case-insensitive unless
-    ``ignore_case`` is False.
+    ``ignore_case`` is ``False``.
 
-    .. note::
+    .. NOTE::
 
         The ``extraN`` parameters are present only because
         ``search_src(string, *extras, interact=False)``
@@ -1098,37 +1115,39 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
     You can search for "matrix" by typing ``search_src("matrix")``.
     This particular search will produce many results::
 
-        sage: len(search_src("matrix", interact=False).splitlines()) # random # long time
+        sage: len(search_src("matrix", interact=False).splitlines())  # random # long time
         9522
 
     You can restrict to the Sage calculus code with
     ``search_src("matrix", module="sage.calculus")``, and this
     produces many fewer results::
 
-        sage: len(search_src("matrix", module="sage.calculus", interact=False).splitlines()) # random
+        sage: len(search_src("matrix", module="sage.calculus", interact=False).splitlines())  # random
         26
 
     Note that you can do tab completion on the ``module`` string.
     Another way to accomplish a similar search::
 
-        sage: len(search_src("matrix", path_re="calc", interact=False).splitlines()) > 15
+        sage: len(search_src("matrix", path_re="calc",                                  # needs sage.modules
+        ....:                interact=False).splitlines()) > 15
         True
 
     The following produces an error because the string 'fetch(' is a
     malformed regular expression::
 
-        sage: print(search_src(" fetch(", "def", interact=False))
-        Traceback (most recent call last):
-        ...
-        error: missing ), unterminated subpattern at position 6
+        sage: try:
+        ....:     print(search_src(" fetch(", "def", interact=False))
+        ....: except Exception as e:
+        ....:     print(e)
+        missing ), unterminated subpattern at position 6
 
     To fix this, *escape* the parenthesis with a backslash::
 
-        sage: print(search_src(r" fetch\(", "def", interact=False)) # random # long time
+        sage: print(search_src(r" fetch\(", "def", interact=False))  # random # long time
         matrix/matrix0.pyx:    cdef fetch(self, key):
         matrix/matrix0.pxd:    cdef fetch(self, key)
 
-        sage: print(search_src(r" fetch\(", "def", "pyx", interact=False)) # random # long time
+        sage: print(search_src(r" fetch\(", "def", "pyx", interact=False))  # random # long time
         matrix/matrix0.pyx:    cdef fetch(self, key):
 
     As noted above, the search is case-insensitive, but you can make it
@@ -1140,7 +1159,8 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
         sage: s = search_src('MatRiX', path_re='matrix', interact=False); s.find('x') > 0
         True
 
-        sage: s = search_src('MatRiX', path_re='matrix', interact=False, ignore_case=False); s.find('x') > 0
+        sage: s = search_src('MatRiX', path_re='matrix',
+        ....:                interact=False, ignore_case=False); s.find('x') > 0
         False
 
     Searches are by default restricted to single lines, but this can
@@ -1152,7 +1172,8 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
 
         sage: len(search_src('log', 'derivative', interact=False).splitlines()) < 40
         True
-        sage: len(search_src('log', 'derivative', interact=False, multiline=True).splitlines()) > 70
+        sage: len(search_src('log', 'derivative',
+        ....:                interact=False, multiline=True).splitlines()) > 70
         True
 
     A little recursive narcissism: let's do a doctest that searches for
@@ -1162,22 +1183,22 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
 
     ::
 
-        sage: print(search_src(r'^ *sage[:] .*search_src\(', interact=False)) # long time
-        misc/sagedoc.py:... len(search_src("matrix", interact=False).splitlines()) # random # long time
-        misc/sagedoc.py:... len(search_src("matrix", module="sage.calculus", interact=False).splitlines()) # random
-        misc/sagedoc.py:... len(search_src("matrix", path_re="calc", interact=False).splitlines()) > 15
-        misc/sagedoc.py:... print(search_src(" fetch(", "def", interact=False))
-        misc/sagedoc.py:... print(search_src(r" fetch\(", "def", interact=False)) # random # long time
-        misc/sagedoc.py:... print(search_src(r" fetch\(", "def", "pyx", interact=False)) # random # long time
-        misc/sagedoc.py:... s = search_src('Matrix', path_re='matrix', interact=False); s.find('x') > 0
-        misc/sagedoc.py:... s = search_src('MatRiX', path_re='matrix', interact=False); s.find('x') > 0
-        misc/sagedoc.py:... s = search_src('MatRiX', path_re='matrix', interact=False, ignore_case=False); s.find('x') > 0
-        misc/sagedoc.py:... len(search_src('log', 'derivative', interact=False).splitlines()) < 40
-        misc/sagedoc.py:... len(search_src('log', 'derivative', interact=False, multiline=True).splitlines()) > 70
-        misc/sagedoc.py:... print(search_src(r'^ *sage[:] .*search_src\(', interact=False)) # long time
-        misc/sagedoc.py:... len(search_src("matrix", interact=False).splitlines()) > 9000 # long time
-        misc/sagedoc.py:... print(search_src('matrix', 'column', 'row', 'sub', 'start', 'index', interact=False)) # random # long time
-        misc/sagedoc.py:... sage: results = search_src('format_search_as_html', # long time
+        sage: print(search_src(r'^ *sage[:] .*search_src\(', interact=False))  # long time
+        misc/sagedoc.py:... len(search_src("matrix", interact=False).splitlines())...
+        misc/sagedoc.py:... len(search_src("matrix", module="sage.calculus", interact=False).splitlines())...
+        misc/sagedoc.py:... len(search_src("matrix", path_re="calc"...
+        misc/sagedoc.py:... print(search_src(" fetch(", "def", interact=False))...
+        misc/sagedoc.py:... print(search_src(r" fetch\(", "def", interact=False))...
+        misc/sagedoc.py:... print(search_src(r" fetch\(", "def", "pyx", interact=False))...
+        misc/sagedoc.py:... s = search_src('Matrix', path_re='matrix', interact=False); s.find('x') > 0...
+        misc/sagedoc.py:... s = search_src('MatRiX', path_re='matrix', interact=False); s.find('x') > 0...
+        misc/sagedoc.py:... s = search_src('MatRiX', path_re='matrix',...
+        misc/sagedoc.py:... len(search_src('log', 'derivative', interact=False).splitlines()) < 40...
+        misc/sagedoc.py:... len(search_src('log', 'derivative'...
+        misc/sagedoc.py:... print(search_src(r'^ *sage[:] .*search_src\(', interact=False))...
+        misc/sagedoc.py:... len(search_src("matrix", interact=False).splitlines()) > 9000...
+        misc/sagedoc.py:... print(search_src('matrix', 'column', 'row', 'sub',...
+        misc/sagedoc.py:... sage: results = search_src('format_search_as_html',...
 
     TESTS:
 
@@ -1195,7 +1216,6 @@ def search_src(string, extra1='', extra2='', extra3='', extra4='',
         matrix/matrix0.pyx:607:        Get the 2 x 3 submatrix of M starting at row index and column index
         matrix/matrix0.pyx:924:        Set the 2 x 2 submatrix of M, starting at row index and column
         matrix/matrix0.pyx:933:        Set the 2 x 3 submatrix of M starting at row index and column
-
     """
     return _search_src_or_doc('src', string, extra1=extra1, extra2=extra2,
                               extra3=extra3, extra4=extra4, extra5=extra5,
@@ -1212,7 +1232,7 @@ def search_doc(string, extra1='', extra2='', extra3='', extra4='',
 
     INPUT: same as for :func:`search_src`.
 
-    OUTPUT: same as for :func:`search_src`.
+    OUTPUT: same as for :func:`search_src`
 
     EXAMPLES:
 
@@ -1230,13 +1250,14 @@ def search_doc(string, extra1='', extra2='', extra3='', extra4='',
     counting the length of ``search_doc('tree',
     interact=False).splitlines()`` gives the number of matches. ::
 
-        sage: N = len(search_doc('tree', interact=False).splitlines())  # optional - sagemath_doc_html, long time
-        sage: L = search_doc('tree', whole_word=True, interact=False).splitlines()  # optional - sagemath_doc_html, long time
-        sage: len(L) < N  # optional - sagemath_doc_html, long time
+        sage: # long time, needs sagemath_doc_html
+        sage: N = len(search_doc('tree', interact=False).splitlines())
+        sage: L = search_doc('tree', whole_word=True, interact=False).splitlines()
+        sage: len(L) < N
         True
         sage: import re
         sage: tree_re = re.compile(r'(^|\W)tree(\W|$)', re.I)
-        sage: all(tree_re.search(l) for l in L) # optional - sagemath_doc_html, long time
+        sage: all(tree_re.search(l) for l in L)
         True
     """
     return _search_src_or_doc('doc', string, extra1=extra1, extra2=extra2,
@@ -1252,9 +1273,9 @@ def search_def(name, extra1='', extra2='', extra3='', extra4='',
 
     INPUT: same as for :func:`search_src`.
 
-    OUTPUT: same as for :func:`search_src`.
+    OUTPUT: same as for :func:`search_src`
 
-    .. note::
+    .. NOTE::
 
         The regular expression used by this function only finds function
         definitions that are preceded by spaces, so if you use tabs on a
@@ -1265,11 +1286,11 @@ def search_def(name, extra1='', extra2='', extra3='', extra4='',
 
     See the documentation for :func:`search_src` for more examples. ::
 
-        sage: print(search_def("fetch", interact=False)) # random # long time
+        sage: print(search_def("fetch", interact=False))  # random # long time
         matrix/matrix0.pyx:    cdef fetch(self, key):
         matrix/matrix0.pxd:    cdef fetch(self, key)
 
-        sage: print(search_def("fetch", path_re="pyx", interact=False)) # random # long time
+        sage: print(search_def("fetch", path_re="pyx", interact=False))  # random # long time
         matrix/matrix0.pyx:    cdef fetch(self, key):
     """
     # since we convert name to a regular expression, we need to do the
@@ -1301,11 +1322,11 @@ def format_search_as_html(what, results, search):
 
     INPUT:
 
-    - ``what`` - (string) what was searched (source code or
+    - ``what`` -- string; what was searched (source code or
       documentation)
-    - ``results`` - (string or list) the results of the search as a string or list of
+    - ``results`` -- string or list; the results of the search as a string or list of
       search results
-    - ``search`` - (string or list) what was being searched for, either as a
+    - ``search`` -- string or list; what was being searched for, either as a
       string which is taken verbatim, or a list of multiple search terms if
       there were more than one
 
@@ -1353,7 +1374,7 @@ def format_search_as_html(what, results, search):
     if not isinstance(results, list):
         results = results.splitlines()
 
-    files = set([])
+    files = set()
     for L in results:
         filename = L.strip().split(':', 1)[0]
         if filename:
@@ -1386,8 +1407,8 @@ def my_getsource(obj, oname=''):
 
     - ``obj`` -- a Sage object, function, etc.
 
-    - ``oname`` -- str (optional). A name under which the object is
-      known. Currently ignored by Sage.
+    - ``oname`` -- string (optional); a name under which the object is
+      known. Currently ignored by Sage
 
     OUTPUT:
 
@@ -1396,8 +1417,8 @@ def my_getsource(obj, oname=''):
     EXAMPLES::
 
         sage: from sage.misc.sagedoc import my_getsource
-        sage: s = my_getsource(identity_matrix)
-        sage: s[15:34]
+        sage: s = my_getsource(identity_matrix)                                         # needs sage.modules
+        sage: s[15:34]                                                                  # needs sage.modules
         'def identity_matrix'
     """
     try:
@@ -1427,16 +1448,16 @@ class _sage_doc:
       "browse_sage_doc(identity_matrix, 'html').  ``output`` can be
       either 'html' or 'rst': the form of the output.  ``view`` is
       only relevant if ``output`` is ``html``; in this case, if
-      ``view`` is True (its default value), then open up the
+      ``view`` is ``True`` (its default value), then open up the
       documentation in a web browser.  Otherwise, just output the
       documentation as a string.
 
     EXAMPLES::
 
-        sage: browse_sage_doc._open("reference", testing=True)[0]  # optional - sagemath_doc_html, indirect doctest
+        sage: browse_sage_doc._open("reference", testing=True)[0]                       # needs sagemath_doc_html
         'http://localhost:8000/doc/live/reference/index.html'
-        sage: browse_sage_doc(identity_matrix, 'rst')[-107:-47]
-        'Full MatrixSpace of 3 by 3 sparse matrices over Integer Ring'
+        sage: browse_sage_doc(identity_matrix, 'rst')[-107:-47]                         # needs sage.modules
+        '...Full MatrixSpace of 3 by 3 sparse matrices...'
     """
     def __init__(self):
         """
@@ -1454,28 +1475,28 @@ class _sage_doc:
 
         INPUT:
 
-        - ``obj`` - a Sage object
-        - ``output`` - 'html', 'rst', or 'text': return documentation in this form
-        - ``view`` - only has an effect if output is 'html': in this
+        - ``obj`` -- a Sage object
+        - ``output`` -- 'html', 'rst', or 'text': return documentation in this form
+        - ``view`` -- only has an effect if output is 'html': in this
           case, if ``view`` is ``True``, display the documentation in
           a web browser.  Otherwise, return the documentation as a
           string.
 
         EXAMPLES::
 
-            sage: browse_sage_doc(identity_matrix, 'rst')
+            sage: browse_sage_doc(identity_matrix, 'rst')                               # needs sage.modules
             "...**File:**...**Type:**...**Definition:** identity_matrix..."
-            sage: identity_matrix.__doc__ in browse_sage_doc(identity_matrix, 'rst')
+            sage: identity_matrix.__doc__ in browse_sage_doc(identity_matrix, 'rst')    # needs sage.modules
             True
-            sage: browse_sage_doc(identity_matrix, 'html', False)             # optional - sphinx sagemath_doc_html
+            sage: browse_sage_doc(identity_matrix, 'html', False)                       # needs sagemath_doc_html sphinx
             '...div...File:...Type:...Definition:...identity_matrix...'
 
         In the 'text' version, double colons have been replaced with
         single ones (among other things)::
 
-            sage: '::' in browse_sage_doc(identity_matrix, 'rst')
+            sage: '::' in browse_sage_doc(identity_matrix, 'rst')                       # needs sage.modules
             True
-            sage: '::' in browse_sage_doc(identity_matrix, 'text')            # optional - sphinx
+            sage: '::' in browse_sage_doc(identity_matrix, 'text')                      # needs sphinx
             False
         """
         if output != 'html' and view:
@@ -1597,17 +1618,17 @@ class _sage_doc:
 
         INPUT:
 
-        - ``name`` - string, name of the documentation
+        - ``name`` -- string; name of the documentation
 
-        - ``testing`` - boolean (optional, default False): if True,
-          then just return the URL and path-name for this document;
-          don't open the web browser.
+        - ``testing`` -- boolean (default: ``False``); if ``True``,
+          then just return the URL and path-name for this document
+          (don't open the web browser)
 
         EXAMPLES::
 
-            sage: browse_sage_doc._open("reference", testing=True)[0]  # optional - sagemath_doc_html
+            sage: browse_sage_doc._open("reference", testing=True)[0]                   # needs sagemath_doc_html
             'http://localhost:8000/doc/live/reference/index.html'
-            sage: browse_sage_doc._open("tutorial", testing=True)[1]  # optional - sagemath_doc_html
+            sage: browse_sage_doc._open("tutorial", testing=True)[1]                    # needs sagemath_doc_html
             '.../html/en/tutorial/index.html'
         """
         url = self._base_url + os.path.join(name, "index.html")
@@ -1637,8 +1658,8 @@ with 'sage -docbuild {0} html' and try again.""".format(name))
 
         EXAMPLES::
 
-            sage: reference() # indirect doctest, not tested
-            sage: manual() # indirect doctest, not tested
+            sage: reference()  # indirect doctest, not tested
+            sage: manual()  # indirect doctest, not tested
         """
         self._open("reference")
 
