@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.flint sage.libs.pari
 r"""
 Homology of modular abelian varieties
 
@@ -37,7 +38,8 @@ EXAMPLES::
     [-4  0]
     [ 0 -4]
     sage: a.T(7)
-    Hecke operator T_7 on Submodule of rank 2 of Integral Homology of Abelian variety J0(43) of dimension 3
+    Hecke operator T_7 on
+     Submodule of rank 2 of Integral Homology of Abelian variety J0(43) of dimension 3
 """
 
 # ****************************************************************************
@@ -50,11 +52,11 @@ EXAMPLES::
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
+from sage.categories.commutative_rings import CommutativeRings
 from sage.modular.hecke.module import HeckeModule_free_module
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
-from sage.rings.ring import CommutativeRing
 from sage.structure.richcmp import richcmp_method, richcmp, richcmp_not_equal
 
 # TODO: we will probably also need homology that is *not* a Hecke module.
@@ -67,18 +69,16 @@ class Homology(HeckeModule_free_module):
     action.
     """
     def hecke_polynomial(self, n, var='x'):
-        """
-        Return the n-th Hecke polynomial in the given variable.
+        r"""
+        Return the `n`-th Hecke polynomial in the given variable.
 
         INPUT:
 
+        - ``n`` -- positive integer
 
-        -  ``n`` - positive integer
+        - ``var`` -- string (default: ``'x'``); the variable name
 
-        -  ``var`` - string (default: 'x') the variable name
-
-
-        OUTPUT: a polynomial over ZZ in the given variable
+        OUTPUT: a polynomial over `\ZZ` in the given variable
 
         EXAMPLES::
 
@@ -115,7 +115,7 @@ class Homology_abvar(Homology):
             sage: loads(dumps(H)) == H
             True
         """
-        if not isinstance(base, CommutativeRing):
+        if base not in CommutativeRings():
             raise TypeError("base ring must be a commutative ring")
         HeckeModule_free_module.__init__(
             self, base, abvar.level(), weight=2)
@@ -142,7 +142,7 @@ class Homology_abvar(Homology):
 
     def _repr_(self):
         """
-        Return string representation of self. This must be defined in the
+        Return string representation of ``self``. This must be defined in the
         derived class.
 
         EXAMPLES::
@@ -158,7 +158,7 @@ class Homology_abvar(Homology):
 
     def gens(self):
         """
-        Return generators of self.
+        Return generators of ``self``.
 
         This is not yet implemented!
 
@@ -174,7 +174,7 @@ class Homology_abvar(Homology):
 
     def gen(self, n):
         """
-        Return `n^{th}` generator of self.
+        Return `n`-th generator of ``self``.
 
         This is not yet implemented!
 
@@ -248,14 +248,12 @@ class Homology_abvar(Homology):
 
     def hecke_matrix(self, n):
         """
-        Return the matrix of the n-th Hecke operator acting on this
+        Return the matrix of the `n`-th Hecke operator acting on this
         homology group.
 
         INPUT:
 
-
-        -  ``n`` - a positive integer
-
+        - ``n`` -- positive integer
 
         OUTPUT: a matrix over the coefficient ring of this homology group
 
@@ -272,7 +270,8 @@ class Homology_abvar(Homology):
 
             sage: J = J0(23)
             sage: J.homology(QQ[I]).hecke_matrix(3).parent()
-            Full MatrixSpace of 4 by 4 dense matrices over Number Field in I with defining polynomial x^2 + 1 with I = 1*I
+            Full MatrixSpace of 4 by 4 dense matrices over
+             Number Field in I with defining polynomial x^2 + 1 with I = 1*I
         """
         raise NotImplementedError
 
@@ -298,14 +297,13 @@ class Homology_abvar(Homology):
 
         INPUT:
 
+        - ``U`` -- submodule of ambient free module (or
+          something that defines one)
 
-        -  ``U`` - submodule of ambient free module (or
-           something that defines one)
-
-        -  ``check`` - currently ignored.
+        - ``check`` -- currently ignored
 
 
-        .. note::
+        .. NOTE::
 
            We do *not* check that U is invariant under all Hecke
            operators.
@@ -346,9 +344,7 @@ class IntegralHomology(Homology_abvar):
 
         INPUT:
 
-
-        -  ``abvar`` - a modular abelian variety
-
+        - ``abvar`` -- a modular abelian variety
 
         EXAMPLES::
 
@@ -377,7 +373,7 @@ class IntegralHomology(Homology_abvar):
 
     def hecke_matrix(self, n):
         """
-        Return the matrix of the n-th Hecke operator acting on this
+        Return the matrix of the `n`-th Hecke operator acting on this
         homology group.
 
         EXAMPLES::
@@ -397,7 +393,7 @@ class IntegralHomology(Homology_abvar):
 
     def hecke_polynomial(self, n, var='x'):
         """
-        Return the n-th Hecke polynomial on this integral homology group.
+        Return the `n`-th Hecke polynomial on this integral homology group.
 
         EXAMPLES::
 
@@ -424,9 +420,7 @@ class RationalHomology(Homology_abvar):
 
         INPUT:
 
-
-        -  ``abvar`` - a modular abelian variety
-
+        - ``abvar`` -- a modular abelian variety
 
         EXAMPLES::
 
@@ -453,7 +447,7 @@ class RationalHomology(Homology_abvar):
 
     def hecke_matrix(self, n):
         """
-        Return the matrix of the n-th Hecke operator acting on this
+        Return the matrix of the `n`-th Hecke operator acting on this
         homology group.
 
         EXAMPLES::
@@ -478,7 +472,7 @@ class RationalHomology(Homology_abvar):
 
     def hecke_polynomial(self, n, var='x'):
         """
-        Return the n-th Hecke polynomial on this rational homology group.
+        Return the `n`-th Hecke polynomial on this rational homology group.
 
         EXAMPLES::
 
@@ -505,11 +499,9 @@ class Homology_over_base(Homology_abvar):
 
         INPUT:
 
+        - ``abvar`` -- a modular abelian variety
 
-        -  ``abvar`` - a modular abelian variety
-
-        -  ``base_ring`` - a commutative ring
-
+        - ``base_ring`` -- a commutative ring
 
         EXAMPLES::
 
@@ -527,7 +519,7 @@ class Homology_over_base(Homology_abvar):
 
     def _repr_(self):
         """
-        Return string representation of self.
+        Return string representation of ``self``.
 
         EXAMPLES::
 
@@ -539,7 +531,7 @@ class Homology_over_base(Homology_abvar):
 
     def hecke_matrix(self, n):
         """
-        Return the matrix of the n-th Hecke operator acting on this
+        Return the matrix of the `n`-th Hecke operator acting on this
         homology group.
 
         EXAMPLES::
@@ -566,13 +558,11 @@ class Homology_submodule(Homology):
 
         INPUT:
 
+        - ``ambient`` -- the homology of some modular abelian
+          variety with ring coefficients
 
-        -  ``ambient`` - the homology of some modular abelian
-           variety with ring coefficients
-
-        -  ``submodule`` - a submodule of the free module
-           underlying ambient
-
+        - ``submodule`` -- a submodule of the free module
+          underlying ambient
 
         EXAMPLES::
 
@@ -694,16 +684,19 @@ class Homology_submodule(Homology):
 
     def hecke_matrix(self, n):
         """
-        Return the matrix of the n-th Hecke operator acting on this
+        Return the matrix of the `n`-th Hecke operator acting on this
         homology group.
 
         EXAMPLES::
 
             sage: d = J0(125).homology(GF(17)).decomposition(2); d
             [
-            Submodule of rank 4 of Homology with coefficients in Finite Field of size 17 of Abelian variety J0(125) of dimension 8,
-            Submodule of rank 4 of Homology with coefficients in Finite Field of size 17 of Abelian variety J0(125) of dimension 8,
-            Submodule of rank 8 of Homology with coefficients in Finite Field of size 17 of Abelian variety J0(125) of dimension 8
+            Submodule of rank 4 of Homology with coefficients in Finite Field of size 17
+             of Abelian variety J0(125) of dimension 8,
+            Submodule of rank 4 of Homology with coefficients in Finite Field of size 17
+             of Abelian variety J0(125) of dimension 8,
+            Submodule of rank 8 of Homology with coefficients in Finite Field of size 17
+             of Abelian variety J0(125) of dimension 8
             ]
             sage: t = d[0].hecke_matrix(17); t
             [16 15 15  0]
