@@ -317,7 +317,7 @@ class Cusp(Element):
 
     def is_infinity(self):
         """
-        Returns True if this is the cusp infinity.
+        Return ``True`` if this is the cusp infinity.
 
         EXAMPLES::
 
@@ -470,28 +470,28 @@ class Cusp(Element):
 
     def is_gamma0_equiv(self, other, N, transformation=None):
         r"""
-        Return whether self and other are equivalent modulo the action of
+        Return whether ``self`` and ``other`` are equivalent modulo the action of
         `\Gamma_0(N)` via linear fractional transformations.
 
         INPUT:
 
+        - ``other`` -- cusp
 
-        -  ``other`` -- Cusp
-
-        -  ``N`` -- an integer (specifies the group
-           Gamma_0(N))
-
-        -  ``transformation`` -- None (default) or either the string 'matrix' or 'corner'. If 'matrix',
-           it also returns a matrix in Gamma_0(N) that sends self to other. The matrix is chosen such that the lower left entry is as small as possible in absolute value. If 'corner' (or True for backwards compatibility), it returns only the upper left entry of such a matrix.
+        - ``N`` -- integer (specifies the group `\Gamma_0(N)`)
 
+        - ``transformation`` -- ``None`` (default) or either the string 'matrix' or
+          ``'corner'``. If ``'matrix'``, it also returns a matrix in `\Gamma_0(N)` that
+          sends ``self`` to ``other``. The matrix is chosen such that the lower
+          left entry is as small as possible in absolute value. If ``'corner'`` (or
+          ``True`` for backwards compatibility), it returns only the upper left
+          entry of such a matrix.
 
         OUTPUT:
 
+        - a boolean -- ``True`` if ``self`` and ``other`` are equivalent
 
-        -  a boolean -- True if self and other are equivalent
-
-        -  a matrix or an integer- returned only if transformation is 'matrix' or 'corner', respectively.
-
+        - a matrix or an integer -- returned only if transformation is 'matrix'
+          or 'corner', respectively
 
         EXAMPLES::
 
@@ -650,31 +650,26 @@ class Cusp(Element):
             return (True, A)
 
     def is_gamma1_equiv(self, other, N):
-        """
-        Return whether self and other are equivalent modulo the action of
-        Gamma_1(N) via linear fractional transformations.
+        r"""
+        Return whether ``self`` and ``other`` are equivalent modulo the action of
+        `\Gamma_1(N)` via linear fractional transformations.
 
         INPUT:
 
+        - ``other`` -- cusp
 
-        -  ``other`` -- Cusp
-
-        -  ``N`` -- an integer (specifies the group
-           Gamma_1(N))
-
+        - ``N`` -- integer (specifies the group `\Gamma_1(N)`)
 
         OUTPUT:
 
+        - ``bool`` -- ``True`` if ``self`` and ``other`` are equivalent
 
-        -  ``bool`` -- True if self and other are equivalent
-
-        -  ``int`` -- 0, 1 or -1, gives further information
-           about the equivalence: If the two cusps are u1/v1 and u2/v2, then
-           they are equivalent if and only if v1 = v2 (mod N) and u1 = u2 (mod
-           gcd(v1,N)) or v1 = -v2 (mod N) and u1 = -u2 (mod gcd(v1,N)) The
-           sign is +1 for the first and -1 for the second. If the two cusps
-           are not equivalent then 0 is returned.
-
+        - ``int`` -- 0, 1 or -1, gives further information
+          about the equivalence: If the two cusps are u1/v1 and u2/v2, then
+          they are equivalent if and only if v1 = v2 (mod N) and u1 = u2 (mod
+          gcd(v1,N)) or v1 = -v2 (mod N) and u1 = -u2 (mod gcd(v1,N)) The
+          sign is +1 for the first and -1 for the second. If the two cusps
+          are not equivalent then 0 is returned.
 
         EXAMPLES::
 
@@ -711,9 +706,9 @@ class Cusp(Element):
 
     def is_gamma_h_equiv(self, other, G):
         r"""
-        Return a pair (b, t), where b is True or False as self and other
-        are equivalent under the action of G, and t is 1 or -1, as
-        described below.
+        Return a pair ``(b, t)``, where ``b`` is ``True`` or ``False`` as
+        ``self`` and ``other`` are equivalent under the action of `G`, and `t`
+        is 1 or -1, as described below.
 
         Two cusps `u1/v1` and `u2/v2` are equivalent modulo
         Gamma_H(N) if and only if `v1 =  h*v2 (\mathrm{mod} N)` and
@@ -725,19 +720,15 @@ class Cusp(Element):
 
         INPUT:
 
+        - ``other`` -- cusp
 
-        -  ``other`` -- Cusp
-
-        -  ``G`` -- a congruence subgroup Gamma_H(N)
-
+        - ``G`` -- a congruence subgroup Gamma_H(N)
 
         OUTPUT:
 
+        - ``bool`` -- ``True`` if ``self`` and ``other`` are equivalent
 
-        -  ``bool`` -- True if self and other are equivalent
-
-        -  ``int`` -- -1, 0, 1; extra info
-
+        - ``int`` -- -1, 0, 1; extra info
 
         EXAMPLES::
 
@@ -807,7 +798,7 @@ class Cusp(Element):
 
     def _acted_upon_(self, g, self_on_left):
         r"""
-        Implement the left action of `SL_2(\ZZ)` on self.
+        Implement the left action of `SL_2(\ZZ)` on ``self``.
 
         EXAMPLES::
 
@@ -873,13 +864,11 @@ class Cusp(Element):
 
         INPUT:
 
-        - `t` -- integer that is coprime to N
+        - ``t`` -- integer that is coprime to N
 
-        - `N` -- positive integer (level)
+        - ``N`` -- positive integer (level)
 
-        OUTPUT:
-
-        - a cusp
+        OUTPUT: a cusp
 
         .. WARNING::
 
@@ -964,7 +953,6 @@ class Cusp(Element):
         AUTHORS:
 
         - William Stein, 2009-04-18
-
         """
         if self.is_infinity():
             return self
@@ -1066,7 +1054,7 @@ class Cusps_class(Singleton, Parent):
 
     def _latex_(self):
         r"""
-        Return latex representation of self.
+        Return latex representation of ``self``.
 
         EXAMPLES::
 
