@@ -19,15 +19,15 @@ EXAMPLES::
     ]
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2004-2006 William Stein <wstein@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 import weakref
 import re
@@ -56,28 +56,23 @@ def canonical_parameters(group, level, weight, base_ring):
 
     INPUT:
 
+    - ``group`` -- integer, group, or Dirichlet character
 
-    -  ``group`` -- int, long, Sage integer, group,
-       Dirichlet character, or
+    - ``level`` -- integer or group
 
-    -  ``level`` -- int, long, Sage integer, or group
-
-    -  ``weight`` -- coercible to Sage integer
-
-    -  ``base_ring`` -- commutative Sage ring
+    - ``weight`` -- coercible to integer
 
+    - ``base_ring`` -- commutative ring
 
     OUTPUT:
 
+    - ``level`` -- integer
 
-    -  ``level`` -- Sage integer
+    - ``group`` -- congruence subgroup
 
-    -  ``group`` -- congruence subgroup
-
-    -  ``weight`` -- Sage integer
-
-    -  ``ring`` -- commutative Sage ring
+    - ``weight`` -- integer
 
+    - ``ring`` -- commutative ring
 
     EXAMPLES::
 
@@ -99,13 +94,13 @@ def canonical_parameters(group, level, weight, base_ring):
         raise NotImplementedError("weight must be at least 1")
 
     if isinstance(group, dirichlet.DirichletCharacter):
-        if ( group.level() != Integer(level) ):
+        if group.level() != Integer(level):
             raise ValueError("group.level() and level do not match.")
         group = group.minimize_base_ring()
         level = Integer(level)
 
     elif isinstance(group, arithgroup.CongruenceSubgroupBase):
-        if ( Integer(level) != group.level() ):
+        if Integer(level) != group.level():
             raise ValueError("group.level() and level do not match.")
         # normalize the case of SL2Z
         if isinstance(group, arithgroup.SL2Z_class) or \
@@ -137,6 +132,7 @@ def canonical_parameters(group, level, weight, base_ring):
 
 _cache = {}
 
+
 def ModularForms_clear_cache():
     """
     Clear the cache of modular forms.
@@ -168,13 +164,13 @@ def ModularForms(group=1,
 
     INPUT:
 
-    - ``group`` -- A congruence subgroup or a Dirichlet character eps.
+    - ``group`` -- a congruence subgroup or a Dirichlet character eps
 
-    - ``weight`` -- int, the weight, which must be an integer >= 1.
+    - ``weight`` -- integer; the weight (`\geq 1`)
 
     - ``base_ring`` -- the base ring (ignored if group is a Dirichlet character)
 
-    - ``eis_only`` -- if True, compute only the Eisenstein part of the space.
+    - ``eis_only`` -- if ``True``, compute only the Eisenstein part of the space.
       Only permitted (and only useful) in weight 1, where computing dimensions
       of cusp form spaces is expensive.
 
@@ -307,7 +303,6 @@ def ModularForms(group=1,
          Congruence Subgroup Gamma1(59) of weight 1 over Rational Field
         sage: (E.0 + E.2).q_expansion(40)
         1 + q^2 + 196*q^29 - 197*q^30 - q^31 + q^33 + q^34 + q^37 + q^38 - q^39 + O(q^40)
-
     """
     if isinstance(group, dirichlet.DirichletCharacter):
         if base_ring is None:
@@ -315,8 +310,8 @@ def ModularForms(group=1,
     if base_ring is None:
         base_ring = QQ
 
-    if isinstance(group, dirichlet.DirichletCharacter) \
-           or isinstance(group, arithgroup.CongruenceSubgroupBase):
+    if isinstance(group, (dirichlet.DirichletCharacter,
+                          arithgroup.CongruenceSubgroupBase)):
         level = group.level()
     else:
         level = group
@@ -423,25 +418,23 @@ def EisensteinForms(group=1,
 
 def Newforms(group, weight=2, base_ring=None, names=None):
     r"""
-    Returns a list of the newforms of the given weight and level (or weight,
+    Return a list of the newforms of the given weight and level (or weight,
     level and character). These are calculated as
     `\operatorname{Gal}(\overline{F} / F)`-orbits, where `F` is the given base
     field.
 
     INPUT:
 
+    - ``group`` -- the congruence subgroup of the newform, or a Nebentypus
+      character
 
-    -  ``group`` -- the congruence subgroup of the newform, or a Nebentypus
-       character
+    - ``weight`` -- the weight of the newform (default: 2)
 
-    -  ``weight`` -- the weight of the newform (default 2)
-
-    -  ``base_ring`` -- the base ring (defaults to `\QQ` for spaces without
-       character, or the base ring of the character otherwise)
-
-    -  ``names`` -- if the newform has coefficients in a
-       number field, a generator name must be specified
+    - ``base_ring`` -- the base ring (defaults to `\QQ` for spaces without
+      character, or the base ring of the character otherwise)
 
+    - ``names`` -- if the newform has coefficients in a number field, a
+      generator name must be specified
 
     EXAMPLES::
 
@@ -478,7 +471,6 @@ def Newforms(group, weight=2, base_ring=None, names=None):
 
         sage: N = Newforms(719, names='a'); len(N)  # long time (3 s)
         3
-
     """
     return CuspForms(group, weight, base_ring).newforms(names)
 
@@ -487,19 +479,17 @@ def Newform(identifier, group=None, weight=2, base_ring=QQ, names=None):
     """
     INPUT:
 
+    - ``identifier`` -- a canonical label, or the index of
+      the specific newform desired
 
-    -  ``identifier`` -- a canonical label, or the index of
-       the specific newform desired
+    - ``group`` -- the congruence subgroup of the newform
 
-    -  ``group`` -- the congruence subgroup of the newform
+    - ``weight`` -- the weight of the newform (default: 2)
 
-    -  ``weight`` -- the weight of the newform (default 2)
-
-    -  ``base_ring`` -- the base ring
-
-    -  ``names`` -- if the newform has coefficients in a
-       number field, a generator name must be specified
+    - ``base_ring`` -- the base ring
 
+    - ``names`` -- if the newform has coefficients in a
+      number field, a generator name must be specified
 
     EXAMPLES::
 
