@@ -1,70 +1,70 @@
+# sage.doctest: needs sage.libs.flint
 """
 Numerical computation of newforms
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2004-2006 William Stein <wstein@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
-from sage.rings.fast_arith       import prime_range
-from sage.matrix.constructor     import matrix
-from sage.misc.verbose           import verbose
-from sage.misc.cachefunc         import cached_method
-from sage.misc.prandom           import randint
+from sage.rings.fast_arith import prime_range
+from sage.matrix.constructor import matrix
+from sage.misc.verbose import verbose
+from sage.misc.cachefunc import cached_method
+from sage.misc.prandom import randint
 from sage.modular.arithgroup.all import Gamma0
-from sage.modular.modsym.all     import ModularSymbols
+from sage.modular.modsym.all import ModularSymbols
 from sage.modules.free_module_element import free_module_element as vector
-from sage.rings.complex_double   import CDF
-from sage.rings.integer          import Integer
-from sage.rings.rational_field   import QQ
-from sage.structure.richcmp      import richcmp_method, richcmp
-from sage.structure.sage_object  import SageObject
-from sage.structure.sequence     import Sequence
+from sage.rings.complex_double import CDF
+from sage.rings.integer import Integer
+from sage.rings.rational_field import QQ
+from sage.structure.richcmp import richcmp_method, richcmp
+from sage.structure.sage_object import SageObject
+from sage.structure.sequence import Sequence
 
 # This variable controls importing the SciPy library sparingly
-scipy=None
+scipy = None
+
 
 @richcmp_method
 class NumericalEigenforms(SageObject):
     """
-    numerical_eigenforms(group, weight=2, eps=1e-20, delta=1e-2, tp=[2,3,5])
+    numerical_eigenforms(group, weight=2, eps=1e-20, delta=1e-2, tp=[2,3,5]).
 
     INPUT:
 
-    - ``group`` - a congruence subgroup of a Dirichlet character of
+    - ``group`` -- a congruence subgroup of a Dirichlet character of
       order 1 or 2
 
-    - ``weight`` - an integer >= 2
+    - ``weight`` -- integer >= 2
 
-    - ``eps`` - a small float; abs( ) < eps is what "equal to zero" is
-      interpreted as for floating point numbers.
+    - ``eps`` -- a small float; abs( ) < eps is what "equal to zero" is
+      interpreted as for floating point numbers
 
-    - ``delta`` - a small-ish float; eigenvalues are considered distinct
+    - ``delta`` -- a small-ish float; eigenvalues are considered distinct
       if their difference has absolute value at least delta
 
-    - ``tp`` - use the Hecke operators T_p for p in tp when searching
-      for a random Hecke operator with distinct Hecke eigenvalues.
+    - ``tp`` -- use the Hecke operators T_p for p in tp when searching
+      for a random Hecke operator with distinct Hecke eigenvalues
 
-    OUTPUT:
+    OUTPUT: a numerical eigenforms object, with the following useful methods:
 
-    A numerical eigenforms object, with the following useful methods:
+    - :meth:`ap` -- return all eigenvalues of `T_p`
 
-    - :meth:`ap` - return all eigenvalues of `T_p`
-
-    - :meth:`eigenvalues` - list of eigenvalues corresponding
+    - :meth:`eigenvalues` -- list of eigenvalues corresponding
       to the given list of primes, e.g.,::
 
           [[eigenvalues of T_2],
            [eigenvalues of T_3],
            [eigenvalues of T_5], ...]
 
-    - :meth:`systems_of_eigenvalues` - a list of the systems of
+    - :meth:`systems_of_eigenvalues` -- list of the systems of
       eigenvalues of eigenforms such that the chosen random linear
       combination of Hecke operators has multiplicity 1 eigenvalues.
 
@@ -153,7 +153,7 @@ class NumericalEigenforms(SageObject):
 
     def _repr_(self):
         """
-        Print string representation of self.
+        Print string representation of ``self``.
 
         EXAMPLES::
 
@@ -163,7 +163,7 @@ class NumericalEigenforms(SageObject):
             sage: n._repr_()
             'Numerical Hecke eigenvalues for Congruence Subgroup Gamma0(61) of weight 2'
         """
-        return "Numerical Hecke eigenvalues for %s of weight %s"%(
+        return "Numerical Hecke eigenvalues for %s of weight %s" % (
             self._group, self._weight)
 
     @cached_method
@@ -209,7 +209,7 @@ class NumericalEigenforms(SageObject):
         (ostensibly unique) are visible in the test, which should be
         independent of which eigenvectors are returned, but it does presume
         an ordering of these eigenvectors for the test to succeed.
-        This exercises a correction in :trac:`8018`. ::
+        This exercises a correction in :issue:`8018`. ::
 
             sage: n = numerical_eigenforms(61, eps=2.0)
             sage: evectors = n._eigenvectors()
@@ -366,11 +366,9 @@ class NumericalEigenforms(SageObject):
 
         INPUT:
 
-        - ``p`` - integer, a prime number
+        - ``p`` -- integer; a prime number
 
-        OUTPUT:
-
-        - ``list`` - a list of double precision complex numbers
+        OUTPUT: list of double precision complex numbers
 
         EXAMPLES::
 
@@ -399,11 +397,9 @@ class NumericalEigenforms(SageObject):
 
         INPUT:
 
-        - ``primes`` - a list of primes
+        - ``primes`` -- list of primes
 
-        OUTPUT:
-
-        list of lists of eigenvalues.
+        OUTPUT: list of lists of eigenvalues
 
         EXAMPLES::
 
@@ -441,7 +437,7 @@ class NumericalEigenforms(SageObject):
 
     def systems_of_eigenvalues(self, bound):
         """
-        Return all systems of eigenvalues for self for primes
+        Return all systems of eigenvalues for ``self`` for primes
         up to bound.
 
         EXAMPLES::
@@ -469,7 +465,7 @@ class NumericalEigenforms(SageObject):
     def systems_of_abs(self, bound):
         """
         Return the absolute values of all systems of eigenvalues for
-        self for primes up to bound.
+        ``self`` for primes up to bound.
 
         EXAMPLES::
 
@@ -493,6 +489,7 @@ class NumericalEigenforms(SageObject):
         v.set_immutable()
         return v
 
+
 def support(v, eps):
     """
     Given a vector `v` and a threshold eps, return all
@@ -505,6 +502,5 @@ def support(v, eps):
 
         sage: sage.modular.modform.numerical.support( numerical_eigenforms(61)._easy_vector(), 0.5 )
         [0, 4]
-
     """
     return [i for i in range(v.degree()) if abs(v[i]) > eps]
