@@ -266,7 +266,7 @@ class QuasiModularForms(FormsSpace_abstract, Module, UniqueRepresentation):
 
         INPUT:
 
-        - ``v`` -- An element of ``self``.
+        - ``v`` -- an element of ``self``
 
         OUTPUT:
 
@@ -440,7 +440,7 @@ class QuasiCuspForms(FormsSpace_abstract, Module, UniqueRepresentation):
 
         INPUT:
 
-        - ``v`` -- An element of ``self``.
+        - ``v`` -- an element of ``self``
 
         OUTPUT:
 
@@ -708,7 +708,7 @@ class ModularForms(FormsSpace_abstract, Module, UniqueRepresentation):
 
         INPUT:
 
-        - ``v`` -- An element of ``self``.
+        - ``v`` -- an element of ``self``
 
         OUTPUT:
 
@@ -853,7 +853,7 @@ class CuspForms(FormsSpace_abstract, Module, UniqueRepresentation):
 
         INPUT:
 
-        - ``v`` -- An element of ``self``.
+        - ``v`` -- an element of ``self``
 
         OUTPUT:
 
@@ -961,9 +961,9 @@ class ZeroForm(FormsSpace_abstract, Module, UniqueRepresentation):
 
         INPUT:
 
-        - ``k``   -- A rational number, the weight.
+        - ``k`` -- a rational number; the weight
 
-        - ``ep``  -- ``1`` or ``-1``, the multiplier.
+        - ``ep`` -- ``1`` or ``-1``; the multiplier
 
         EXAMPLES::
 
@@ -1017,7 +1017,7 @@ class ZeroForm(FormsSpace_abstract, Module, UniqueRepresentation):
 
         INPUT:
 
-        - ``v`` -- An element of ``self``, i.e. in this case the zero vector.
+        - ``v`` -- an element of ``self``, i.e. in this case the zero vector
 
         EXAMPLES::
 
