@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.pari
 """
 Module of supersingular points
 
@@ -52,7 +53,6 @@ AUTHORS:
 - David Kohel
 
 - Iftikhar Burhanuddin
-
 """
 
 # ****************************************************************************
@@ -68,6 +68,7 @@ AUTHORS:
 # ****************************************************************************
 
 from sage.arith.misc import kronecker, next_prime
+from sage.categories.fields import Fields
 from sage.matrix.matrix_space import MatrixSpace
 from sage.misc.lazy_import import lazy_import
 from sage.modular.arithgroup.all import Gamma0
@@ -99,9 +100,7 @@ def Phi2_quad(J3, ssJ1, ssJ2):
 
     - ``ssJ2``, ``ssJ2`` -- supersingular j-invariants over the finite field
 
-    OUTPUT:
-
-    - polynomial -- defined over the finite field
+    OUTPUT: polynomial; defined over the finite field
 
     EXAMPLES:
 
@@ -118,7 +117,7 @@ def Phi2_quad(J3, ssJ1, ssJ2):
         sage: sage.modular.ssmod.ssmod.Phi2_quad(X, F(8), j_in)
         x^2 + 31*x + 31
 
-    .. note::
+    .. NOTE::
 
         Given a root (j1,j2) to the polynomial `Phi_2(J1,J2)`, the pairs
         (j2,j3) not equal to (j2,j1) which solve `Phi_2(j2,j3)` are roots of
@@ -163,9 +162,7 @@ def Phi_polys(L, x, j):
 
     - ``j`` -- supersingular j-invariant over the finite field
 
-    OUTPUT:
-
-    - polynomial -- defined over the finite field
+    OUTPUT: polynomial; defined over the finite field
 
     EXAMPLES:
 
@@ -203,13 +200,11 @@ def dimension_supersingular_module(prime, level=1):
 
     INPUT:
 
-    - ``prime`` -- integer, prime
+    - ``prime`` -- integer; prime
 
-    - ``level`` -- integer, positive
+    - ``level`` -- integer; positive
 
-    OUTPUT:
-
-    - dimension -- integer, nonnegative
+    OUTPUT: dimension; integer, nonnegative
 
     EXAMPLES:
 
@@ -258,11 +253,9 @@ def supersingular_D(prime):
 
     INPUT:
 
-    - prime -- integer, prime
+    - ``prime`` -- integer, prime
 
-    OUTPUT:
-
-    - D -- integer, negative
+    OUTPUT: d; integer, negative
 
     EXAMPLES:
 
@@ -303,7 +296,7 @@ def supersingular_j(FF):
 
     INPUT:
 
-    - ``FF``  -- finite field with p^2 elements, where p is a prime number
+    - ``FF`` -- finite field with p^2 elements, where p is a prime number
 
     OUTPUT:
 
@@ -332,7 +325,7 @@ def supersingular_j(FF):
 
     - Iftikhar Burhanuddin -- burhanud@usc.edu
     """
-    if not FF.is_field() or not FF.is_finite():
+    if FF not in Fields().Finite():
         raise ValueError("%s is not a finite field" % FF)
     prime = FF.characteristic()
     if not Integer(prime).is_prime():
@@ -416,9 +409,9 @@ class SupersingularModule(HeckeModule_free_module):
         HeckeModule_free_module.__init__(self, base_ring,
                                          prime * level, weight=2)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
-        String representation of self.
+        String representation of ``self``.
 
         EXAMPLES::
 
@@ -428,7 +421,7 @@ class SupersingularModule(HeckeModule_free_module):
         return "Module of supersingular points on X_0(%s)/F_%s over %s" % (
             self.__level, self.__prime, self.base_ring())
 
-    def __richcmp__(self, other, op):
+    def __richcmp__(self, other, op) -> bool:
         r"""
         Compare ``self`` to ``other``.
 
@@ -454,7 +447,7 @@ class SupersingularModule(HeckeModule_free_module):
             sage: X.free_module()
             Ambient free module of rank 3 over the principal ideal domain Integer Ring
 
-        This illustrates the fix at :trac:`4306`::
+        This illustrates the fix at :issue:`4306`::
 
             sage: X = SupersingularModule(389)
             sage: X.basis()
@@ -503,9 +496,7 @@ class SupersingularModule(HeckeModule_free_module):
 
         - ``self`` -- SupersingularModule object
 
-        OUTPUT:
-
-        - integer -- dimension, nonnegative
+        OUTPUT: integer; dimension, nonnegative
 
         EXAMPLES::
 
@@ -552,9 +543,7 @@ class SupersingularModule(HeckeModule_free_module):
 
         - ``self`` -- SupersingularModule object
 
-        OUTPUT:
-
-        - integer -- the level, positive
+        OUTPUT: integer; the level, positive
 
         EXAMPLES::
 
@@ -578,9 +567,7 @@ class SupersingularModule(HeckeModule_free_module):
 
         - ``self`` -- SupersingularModule object
 
-        OUTPUT:
-
-        - integer -- characteristic, positive
+        OUTPUT: integer; characteristic, positive
 
         EXAMPLES::
 
@@ -604,9 +591,7 @@ class SupersingularModule(HeckeModule_free_module):
 
         - ``self`` -- SupersingularModule object
 
-        OUTPUT:
-
-        - integer -- weight, positive
+        OUTPUT: integer; weight, positive
 
         EXAMPLES::
 
@@ -629,7 +614,7 @@ class SupersingularModule(HeckeModule_free_module):
 
         INPUT:
 
-        -  ``self`` -- SupersingularModule object
+        - ``self`` -- SupersingularModule object
 
         OUTPUT:
 
@@ -674,7 +659,7 @@ class SupersingularModule(HeckeModule_free_module):
 
         dim = dimension_supersingular_module(prime, level)
 
-        pos = int(0)
+        pos = 0
         # using list to keep track of explored nodes using pos
         ss_points = [jinv]
 
@@ -696,7 +681,7 @@ class SupersingularModule(HeckeModule_free_module):
                 # root finding (??)
                 neighbors = Phi2_quad(X, ss_points[j_prev], ss_points[pos]).roots()
 
-            for (xj, ej) in neighbors:
+            for xj, ej in neighbors:
                 if xj not in ss_points_dic:
                     j = len(ss_points)
                     ss_points += [xj]
@@ -709,7 +694,7 @@ class SupersingularModule(HeckeModule_free_module):
             if pos != 0:
                 # also record the root from j_prev
                 T2_matrix[pos, j_prev] += 1
-            pos += int(1)
+            pos += 1
 
         self.__hecke_matrices[2] = T2_matrix
         return (ss_points, ss_points_dic)
@@ -782,11 +767,9 @@ class SupersingularModule(HeckeModule_free_module):
 
         - ``self`` -- SupersingularModule object
 
-        - ``L`` -- integer, positive
+        - ``L`` -- integer; positive
 
-        OUTPUT:
-
-        - matrix -- sparse integer matrix
+        OUTPUT: matrix; sparse integer matrix
 
         EXAMPLES:
 
@@ -813,7 +796,7 @@ class SupersingularModule(HeckeModule_free_module):
             [1 1 0 1 0 1]
             [1 1 1 0 1 0]
 
-        .. note::
+        .. NOTE::
 
             The first list --- list_j --- returned by the supersingular_points
             function are the rows *and* column indexes of the above hecke
@@ -835,7 +818,7 @@ class SupersingularModule(HeckeModule_free_module):
         Fp2 = self.__finite_field
         h = len(SS)
         R = self.base_ring()
-        T_L = MatrixSpace(R, h)(0)
+        T_L = MatrixSpace(R, h)(0)  # mutable
         S, X = Fp2['x'].objgen()
 
         for i in range(len(SS)):
