@@ -30,46 +30,58 @@ from .free_monoid_element import FreeMonoidElement
 
 
 def is_StringMonoidElement(x):
-    r"""
-    """
+    from sage.misc.superseded import deprecation
+    deprecation(38280,
+                "The function is_StringMonoidElement is deprecated; "
+                "use 'isinstance(..., StringMonoidElement)' instead.")
     return isinstance(x, StringMonoidElement)
 
 
 def is_AlphabeticStringMonoidElement(x):
-    r"""
-    """
+    from sage.misc.superseded import deprecation
+    deprecation(38280,
+                "The function is_AlphabeticStringMonoidElement is deprecated; "
+                "use 'isinstance(..., StringMonoidElement) and isinstance(x.parent(), AlphabeticStringMonoid)' instead.")
     from .string_monoid import AlphabeticStringMonoid
     return isinstance(x, StringMonoidElement) and \
         isinstance(x.parent(), AlphabeticStringMonoid)
 
 
 def is_BinaryStringMonoidElement(x):
-    r"""
-    """
+    from sage.misc.superseded import deprecation
+    deprecation(38280,
+                "The function is_BinaryStringMonoidElement is deprecated; "
+                "use 'isinstance(..., StringMonoidElement) and isinstance(x.parent(), BinaryStringMonoid)' instead.")
     from .string_monoid import BinaryStringMonoid
     return isinstance(x, StringMonoidElement) and \
         isinstance(x.parent(), BinaryStringMonoid)
 
 
 def is_OctalStringMonoidElement(x):
-    r"""
-    """
+    from sage.misc.superseded import deprecation
+    deprecation(38280,
+                "The function is_OctalStringMonoidElement is deprecated; "
+                "use 'isinstance(..., StringMonoidElement) and isinstance(x.parent(), OctalStringMonoid)' instead.")
     from .string_monoid import OctalStringMonoid
     return isinstance(x, StringMonoidElement) and \
         isinstance(x.parent(), OctalStringMonoid)
 
 
 def is_HexadecimalStringMonoidElement(x):
-    r"""
-    """
+    from sage.misc.superseded import deprecation
+    deprecation(38280,
+                "The function is_HexadecimalStringMonoidElement is deprecated; "
+                "use 'isinstance(..., StringMonoidElement) and isinstance(x.parent(), HexadecimalStringMonoid)' instead.")
     from .string_monoid import HexadecimalStringMonoid
     return isinstance(x, StringMonoidElement) and \
         isinstance(x.parent(), HexadecimalStringMonoid)
 
 
 def is_Radix64StringMonoidElement(x):
-    r"""
-    """
+    from sage.misc.superseded import deprecation
+    deprecation(38280,
+                "The function is_Radix64StringMonoidElement is deprecated; "
+                "use 'isinstance(..., StringMonoidElement) and isinstance(x.parent(), Radix64StringMonoid)' instead.")
     from .string_monoid import Radix64StringMonoid
     return isinstance(x, StringMonoidElement) and \
         isinstance(x.parent(), Radix64StringMonoid)
@@ -140,7 +152,7 @@ class StringMonoidElement(FreeMonoidElement):
 
     def _latex_(self):
         """
-        Return latex representation of self.
+        Return latex representation of ``self``.
 
         EXAMPLES::
 
@@ -191,12 +203,12 @@ class StringMonoidElement(FreeMonoidElement):
             sage: x**(-1)
             Traceback (most recent call last):
             ...
-            IndexError: Argument n (= -1) must be non-negative.
+            IndexError: Argument n (= -1) must be nonnegative.
         """
         if not isinstance(n, (int, Integer)):
             raise TypeError("Argument n (= %s) must be an integer." % n)
         if n < 0:
-            raise IndexError("Argument n (= %s) must be non-negative." % n)
+            raise IndexError("Argument n (= %s) must be nonnegative." % n)
         elif n == 0:
             return self.parent()('')
         elif n == 1:
@@ -444,7 +456,7 @@ class StringMonoidElement(FreeMonoidElement):
 
         INPUT:
 
-        - ``length`` -- (default ``1``) if ``length=1`` then consider the
+        - ``length`` -- (default: ``1``) if ``length=1`` then consider the
           probability space of monogram frequency, i.e. probability
           distribution of single characters. If ``length=2`` then consider
           the probability space of digram frequency, i.e. probability
@@ -452,7 +464,7 @@ class StringMonoidElement(FreeMonoidElement):
           supports the generation of probability spaces for monogram
           frequency (``length=1``) and digram frequency (``length=2``).
 
-        - ``prec`` -- (default ``0``) a non-negative integer representing
+        - ``prec`` -- (default: ``0``) a nonnegative integer representing
           the precision (in number of bits) of a floating-point number. The
           default value ``prec=0`` means that we use 53 bits to represent
           the mantissa of a floating-point number. For more information on
