@@ -31,11 +31,9 @@ def parity(self, allow_rescaling_flag=True):
     INPUT:
 
     - ``self`` -- a quadratic form with base ring `\ZZ`, which we may
-      require to have integer Gram matrix.
+      require to have integer Gram matrix
 
-    OUTPUT:
-
-    One of the strings: "even" or "odd"
+    OUTPUT: one of the strings: ``'even'`` or ``'odd'``
 
     EXAMPLES::
 
@@ -143,7 +141,6 @@ def is_odd(self, allow_rescaling_flag=True):
         sage: Q = QuadraticForm(ZZ, 2, [1, 1, 1])
         sage: Q.is_odd()
         False
-
     """
     return self.parity(allow_rescaling_flag) == "odd"
 
@@ -158,7 +155,7 @@ def conway_species_list_at_odd_prime(self, p):
     number is always positive, otherwise it may be positive or
     negative (or zero, but that is considered positive by convention).
 
-    .. NOTE:
+    .. NOTE::
 
         The species of a zero dimensional form is always 0+, so we
         interpret the return value of zero as positive here! =)
@@ -167,7 +164,7 @@ def conway_species_list_at_odd_prime(self, p):
 
     - ``p`` -- a positive prime number
 
-    OUTPUT: a list of integers
+    OUTPUT: list of integers
 
     EXAMPLES::
 
@@ -182,7 +179,6 @@ def conway_species_list_at_odd_prime(self, p):
         [5, 2]
         sage: Q.conway_species_list_at_odd_prime(5)
         [-6, 1]
-
     """
     # Sanity Check:
     if not (p > 2 and is_prime(p)):
@@ -233,7 +229,7 @@ def conway_species_list_at_2(self):
         The species of a zero dimensional form is always 0+, so we
         interpret the return value of zero as positive here! =)
 
-    OUTPUT: a list of integers
+    OUTPUT: list of integers
 
     EXAMPLES::
 
@@ -246,7 +242,6 @@ def conway_species_list_at_2(self):
         sage: Q = DiagonalQuadraticForm(ZZ, range(1,8))
         sage: Q.conway_species_list_at_2()
         [1, 3, 1, 1, 1]
-
     """
     # Some useful variables
     n = self.dim()
@@ -312,7 +307,7 @@ def conway_octane_of_this_unimodular_Jordan_block_at_2(self):
     unimodular blocks of size `\leq 2` and the `1 \times 1` blocks are all in the upper
     leftmost position.
 
-    OUTPUT: an integer `0 \leq x \leq 7`
+    OUTPUT: integer `0 \leq x \leq 7`
 
     EXAMPLES::
 
@@ -555,13 +550,13 @@ def conway_standard_mass(self):
     EXAMPLES::
 
         sage: Q = QuadraticForm(ZZ, 3, [2, -2, 0, 3, -5, 4])
-        sage: Q.conway_standard_mass()                                              # optional - sage.symbolic
+        sage: Q.conway_standard_mass()                                                  # needs sage.symbolic
         1/6
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1,1])
-        sage: Q.conway_standard_mass()                                              # optional - sage.symbolic
+        sage: Q.conway_standard_mass()                                                  # needs sage.symbolic
         1/6
     """
     from sage.quadratic_forms.special_values import gamma__exact, zeta__exact, quadratic_L_function__exact
@@ -595,19 +590,19 @@ def conway_mass(self):
     EXAMPLES::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1,1])
-        sage: Q.conway_mass()                                                       # optional - sage.symbolic
+        sage: Q.conway_mass()                                                           # needs sage.symbolic
         1/48
 
         sage: Q = DiagonalQuadraticForm(ZZ, [7,1,1])
-        sage: Q.conway_mass()                                                       # optional - sage.symbolic
+        sage: Q.conway_mass()                                                           # needs sage.symbolic
         3/16
 
         sage: Q = QuadraticForm(ZZ, 3, [7, 2, 2, 2, 0, 2]) + DiagonalQuadraticForm(ZZ, [1])
-        sage: Q.conway_mass()                                                       # optional - sage.symbolic
+        sage: Q.conway_mass()                                                           # needs sage.symbolic
         3/32
 
         sage: Q = QuadraticForm(Matrix(ZZ, 2, [2,1,1,2]))
-        sage: Q.conway_mass()                                                       # optional - sage.symbolic
+        sage: Q.conway_mass()                                                           # needs sage.symbolic
         1/12
     """
     # Try to use the cached result
