@@ -260,7 +260,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             Traceback (most recent call last):
             ...
             TypeError: the domain of the derivation must coerce to the domain of the twisting homomorphism
-
         """
         if domain not in Rings().Commutative():
             raise TypeError("the domain must be a commutative ring")
@@ -457,7 +456,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: M = R.derivation_module()
             sage: hash(M) == hash((M.domain(), M.codomain(), M.twisting_morphism()))
             True
-
         """
         return hash((self._domain, self._codomain, self._twist))
 
@@ -546,7 +544,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             Module of derivations over Multivariate Polynomial Ring in x, y over Integer Ring
             sage: M.domain()
             Multivariate Polynomial Ring in x, y over Integer Ring
-
         """
         return self._domain
 
@@ -561,7 +558,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             Module of derivations over Multivariate Polynomial Ring in x, y over Integer Ring
             sage: M.codomain()
             Multivariate Polynomial Ring in x, y over Integer Ring
-
         """
         return self._codomain
 
@@ -592,7 +588,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
               From: Univariate Polynomial Ring in x over Rational Field
               To:   Rational Field
               Defn: x |--> 0
-
         """
         return self._defining_morphism
 
@@ -616,7 +611,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
 
             sage: M = R.derivation_module()
             sage: M.twisting_morphism()
-
         """
         return self._twist
 
@@ -650,7 +644,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             1
             sage: M.gen()
             [x |--> y, y |--> x] - id
-
         """
         if self._gens is None:
             raise NotImplementedError("generators are not implemented for this derivation module")
@@ -679,7 +672,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
              Ring in x, y over Integer Ring (twisting morphism: x |--> y, y |--> x)
             sage: M.gens()
             ([x |--> y, y |--> x] - id,)
-
         """
         if self._gens is None:
             raise NotImplementedError("generators are not implemented for this derivation module")
@@ -687,11 +679,11 @@ class RingDerivationModule(Module, UniqueRepresentation):
 
     def gen(self, n=0):
         r"""
-        Return the ``n``-th generator of this module of derivations.
+        Return the `n`-th generator of this module of derivations.
 
         INPUT:
 
-        - ``n`` -- an integer (default: ``0``)
+        - ``n`` -- integer (default: `0`)
 
         EXAMPLES::
 
@@ -720,7 +712,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: M = R.derivation_module()
             sage: M.basis()
             Family (d/dx, d/dy)
-
         """
         if self._basis is None:
             raise NotImplementedError("basis is not implemented for this derivation module")
@@ -745,7 +736,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             Family (d/dx, d/dy)
             sage: M.dual_basis()
             Family (x, y)
-
         """
         if self._dual_basis is None:
             raise NotImplementedError("basis is not implemented for this derivation module")
@@ -764,7 +754,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             Family (d/dx, d/dy)
             sage: M.ring_of_constants()
             Rational Field
-
         """
         if not self._constants[1]:
             raise NotImplementedError("the computation of the ring of constants"
@@ -781,7 +770,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: M = R.derivation_module()
             sage: M.random_element()  # random
             (x^2 + x*y - 3*y^2 + x + 1)*d/dx + (-2*x^2 + 3*x*y + 10*y^2 + 2*x + 8)*d/dy
-
         """
         if self._gens is None:
             raise NotImplementedError("generators are not implemented for this derivation module")
@@ -797,7 +785,6 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: M = R.derivation_module()
             sage: M.some_elements()
             [d/dx, d/dy, x*d/dx, x*d/dy, y*d/dx, y*d/dy]
-
         """
         if self._gens is None:
             return self.an_element()
@@ -821,7 +808,6 @@ class RingDerivation(ModuleElement):
         d/dx + 2*d/dy
         sage: f(x*y)
         2*x + y
-
     """
     def __call__(self, x):
         """
@@ -850,7 +836,6 @@ class RingDerivation(ModuleElement):
             Multivariate Polynomial Ring in x, y over Rational Field
             sage: f.domain() is R
             True
-
         """
         return self.parent().domain()
 
@@ -877,7 +862,6 @@ class RingDerivation(ModuleElement):
              Univariate Polynomial Ring in x over Rational Field
             sage: M.random_element().codomain() is S
             True
-
         """
         return self.parent().codomain()
 
@@ -1008,7 +992,6 @@ class RingDerivationWithoutTwist(RingDerivation):
             x*d/dx + y*d/dy
             sage: f.list()
             [x, y]
-
         """
         parent = self.parent()
         return [self(x) for x in parent.dual_basis()]
@@ -1037,7 +1020,6 @@ class RingDerivationWithoutTwist(RingDerivation):
             x*d/dx + y*d/dy
             sage: f.monomial_coefficients()
             {0: x, 1: y}
-
         """
         dual_basis = self.parent().dual_basis()
         dict = { }
@@ -1079,7 +1061,6 @@ class RingDerivationWithoutTwist(RingDerivation):
             x*d/dx + y*d/dy + z*d/dz
             sage: D.pth_power() == D
             True
-
         """
         if op == op_EQ:
             if isinstance(other, RingDerivationWithoutTwist):
@@ -1128,7 +1109,6 @@ class RingDerivationWithoutTwist(RingDerivation):
             sage: f = R.random_element()
             sage: X.bracket(f*Y) == X(f)*Y + f*X.bracket(Y)
             True
-
         """
         parent = self.parent()
         if parent.domain() is not parent.codomain():
@@ -1191,7 +1171,6 @@ class RingDerivationWithoutTwist(RingDerivation):
 
             sage: D.bracket(Dp)                                                         # needs sage.rings.finite_rings
             0
-
         """
         parent = self.parent()
         if parent.domain() is not parent.codomain():
@@ -1255,7 +1234,6 @@ class RingDerivationWithoutTwist(RingDerivation):
             Traceback (most recent call last):
             ...
             TypeError: the given ring does not coerce to the domain of the derivation
-
         """
         parent = self.parent()
         if morphism in Rings().Commutative():
@@ -1313,7 +1291,6 @@ class RingDerivationWithoutTwist(RingDerivation):
             Traceback (most recent call last):
             ...
             TypeError: you must give a homomorphism of rings
-
         """
         parent = self.parent()
         if morphism in Rings().Commutative():
@@ -1380,7 +1357,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             True
 
             sage: TestSuite(der).run()
-
         """
         if isinstance(arg, list) and len(arg) == 1 and isinstance(arg[0], RingDerivation):
             arg = arg[0]
@@ -1422,7 +1398,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: f = R.derivation(x)
             sage: hash(f)  # random
             3713081631936575706
-
         """
         return hash(tuple(self.list()))
 
@@ -1437,7 +1412,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: Dy = R.derivation(y)
             sage: Dx + Dy
             d/dx + d/dy
-
         """
         return other
 
@@ -1452,7 +1426,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: Dy = R.derivation(y)
             sage: Dx - Dy
             d/dx - d/dy
-
         """
         return -other
 
@@ -1466,7 +1439,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: Dx = R.derivation(x)
             sage: -Dx
             -d/dx
-
         """
         return self
 
@@ -1482,7 +1454,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             2*d/dx
             sage: Dx * x^2
             x^2*d/dx
-
         """
         return self
 
@@ -1498,7 +1469,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             2*d/dx
             sage: x^2 * Dx
             x^2*d/dx
-
         """
         return self
 
@@ -1512,7 +1482,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: f = x*R.derivation(x) + y*R.derivation(y)
             sage: f(x^2 + 3*x*y - y^2)
             2*x^2 + 6*x*y - 2*y^2
-
         """
         return self.parent().codomain().zero()
 
@@ -1528,7 +1497,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: Dy = R.derivation(y)
             sage: Dx._bracket_(Dy)
             0
-
         """
         return self
 
@@ -1541,7 +1509,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: M = QQ.derivation_module()
             sage: M().is_zero()
             True
-
         """
         return True
 
@@ -1555,7 +1522,6 @@ class RingDerivationWithoutTwist_zero(RingDerivationWithoutTwist):
             sage: M = QQ.derivation_module()
             sage: M().list()
             []
-
         """
         return []
 
@@ -1583,7 +1549,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             sage: isinstance(der, RingDerivationWithoutTwist_wrapper)
             True
             sage: TestSuite(der).run()
-
         """
         if isinstance(arg, list) and len(arg) == 1 and isinstance(arg[0], RingDerivation):
             arg = arg[0]
@@ -1603,7 +1568,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             sage: f = R.derivation(x)
             sage: hash(f)  # random
             3713081631936575706
-
         """
         return hash(tuple(self.list()))
 
@@ -1620,7 +1584,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             sage: Dy = S.derivation(y)
             sage: Dx + Dy
             d/dx + d/dy
-
         """
         return type(self)(self.parent(), self._base_derivation + other._base_derivation)
 
@@ -1637,7 +1600,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             sage: Dy = S.derivation(y)
             sage: Dx - Dy
             d/dx - d/dy
-
         """
         return type(self)(self.parent(), self._base_derivation - other._base_derivation)
 
@@ -1653,7 +1615,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             sage: Dx = S.derivation(x)
             sage: -Dx
             -d/dx
-
         """
         return type(self)(self.parent(), -self._base_derivation)
 
@@ -1671,7 +1632,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             2*d/dx
             sage: Dx * x^2
             x^2*d/dx
-
         """
         return type(self)(self.parent(), self._base_derivation * factor)
 
@@ -1689,7 +1649,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             2*d/dx
             sage: x^2 * Dx
             x^2*d/dx
-
         """
         return type(self)(self.parent(), factor * self._base_derivation)
 
@@ -1714,7 +1673,6 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
             x*d/dx + y*d/dy
             sage: f.list()
             [x, y]
-
         """
         return self._base_derivation.list()
 
@@ -1739,7 +1697,6 @@ class RingDerivationWithoutTwist_function(RingDerivationWithoutTwist):
             d/dx + 2*d/dy
 
             sage: TestSuite(der).run()
-
         """
         domain = parent.domain()
         codomain = parent.codomain()
@@ -1781,7 +1738,6 @@ class RingDerivationWithoutTwist_function(RingDerivationWithoutTwist):
             sage: f = R.derivation(x)
             sage: hash(f)  # random
             3713081631936575706
-
         """
         return hash(tuple(self.list()))
 
@@ -1796,7 +1752,6 @@ class RingDerivationWithoutTwist_function(RingDerivationWithoutTwist):
             sage: Dy = R.derivation(y)
             sage: Dx + Dy
             d/dx + d/dy
-
         """
         base_derivation = self._base_derivation + other._base_derivation
         im = [ self._images[i] + other._images[i] for i in range(self.parent().domain().ngens()) ]
@@ -1920,7 +1875,6 @@ class RingDerivationWithoutTwist_function(RingDerivationWithoutTwist):
             x*d/dx + y*d/dy
             sage: f.list()
             [x, y]
-
         """
         return self._base_derivation.list() + self._images
 
@@ -1939,7 +1893,6 @@ class RingDerivationWithoutTwist_fraction_field(RingDerivationWithoutTwist_wrapp
             sage: f = R.derivation(x)
             sage: hash(f)  # random
             3713081631936575706
-
         """
         return hash(tuple(self.list()))
 
@@ -1955,7 +1908,6 @@ class RingDerivationWithoutTwist_fraction_field(RingDerivationWithoutTwist_wrapp
             d/dx
             sage: f(1/x)
             (-1)/x^2
-
         """
         defining_morphism = self.parent().defining_morphism()
         num = x.numerator()
@@ -1981,7 +1933,6 @@ class RingDerivationWithoutTwist_quotient(RingDerivationWithoutTwist_wrapper):
             sage: f = R.derivation(x)
             sage: hash(f)  # random
             3713081631936575706
-
         """
         return hash(tuple(self.list()))
 
@@ -1998,7 +1949,6 @@ class RingDerivationWithoutTwist_quotient(RingDerivationWithoutTwist_wrapper):
             x^3*d/dx
             sage: f(x^3)
             0
-
         """
         return self._base_derivation(x.lift())
 
@@ -2025,7 +1975,6 @@ class RingDerivationWithTwist_generic(RingDerivation):
 
             sage: der = R.derivation(x, twist=theta)
             sage: TestSuite(der).run()
-
         """
         codomain = parent.codomain()
         self._scalar = codomain(scalar)
@@ -2042,7 +1991,6 @@ class RingDerivationWithTwist_generic(RingDerivation):
             sage: f = R.derivation(1, twist=theta)
             sage: hash(f)  # random
             -6511057926760520014
-
         """
         return hash(self._scalar)
 
@@ -2233,7 +2181,6 @@ class RingDerivationWithTwist_generic(RingDerivation):
             (x + y)*(twisting_morphism - id)
             sage: f.list()
             [x + y]
-
         """
         return [ self._scalar ]
 
@@ -2266,7 +2213,6 @@ class RingDerivationWithTwist_generic(RingDerivation):
             Ring endomorphism of Multivariate Polynomial Ring in x, y over Integer Ring
               Defn: x |--> y^3
                     y |--> x^2
-
         """
         parent = self.parent()
         if morphism in Rings().Commutative():
@@ -2309,7 +2255,6 @@ class RingDerivationWithTwist_generic(RingDerivation):
             Ring endomorphism of Multivariate Polynomial Ring in x, y over Integer Ring
               Defn: x |--> y^2
                     y |--> x^3
-
         """
         parent = self.parent()
         if morphism in Rings().Commutative():
