@@ -1,27 +1,17 @@
-# -*- coding: utf-8 -*-
+# sage.doctest: needs sage.groups sage.rings.number_field
 """
-Galois Groups of Number Fields
+Galois groups of number fields
 
 AUTHORS:
 
 - William Stein (2004, 2005): initial version
-- David Loeffler (2009): rewrite to give explicit homomorphism groups
-
-TESTS:
-
-Standard test of pickleability::
-
-    sage: x = polygen(ZZ, 'x')
-    sage: G = NumberField(x^3 + 2, 'alpha').galois_group(names='beta'); G
-    Galois group 3T2 (S3) with order 6 of x^3 + 2
-    sage: G == loads(dumps(G))
-    True
+- David Loeffler (2009): rewrote to give explicit homomorphism groups
 """
 
 from sage.structure.sage_object import SageObject
-from sage.groups.galois_group import _alg_key, GaloisGroup_perm, GaloisSubgroup_perm
+from sage.groups.galois_group import _alg_key
+from sage.groups.galois_group_perm import GaloisGroup_perm, GaloisSubgroup_perm
 from sage.groups.perm_gps.permgroup import standardize_generator
-
 from sage.groups.perm_gps.permgroup_element import PermutationGroupElement
 from sage.misc.superseded import deprecation
 from sage.misc.cachefunc import cached_method
@@ -76,6 +66,14 @@ class GaloisGroup_v1(SageObject):
             See https://github.com/sagemath/sage/issues/28782 for details.
             Galois group PARI group [4, 1, 2, "E(4) = 2[x]2"] of degree 4 of the
              Number Field in a0 with defining polynomial x^2 + 1 over its base field
+
+        TESTS::
+
+            sage: x = polygen(ZZ, 'x')
+            sage: G = NumberField(x^3 + 2, 'alpha').galois_group(names='beta'); G
+            Galois group 3T2 (S3) with order 6 of x^3 + 2
+            sage: G == loads(dumps(G))
+            True
         """
         deprecation(28782, "GaloisGroup_v1 is deprecated; please use GaloisGroup_v2")
         self.__group = group
@@ -244,7 +242,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
         Subgroup generated by [(1,2,3)(4,5,6)] of
          (Galois group 6T2 ([3]2) with order 6 of x^6 - 6*x^4 + 9*x^2 + 23)
 
-    Subgroups can be specified using generators (:trac:`26816`)::
+    Subgroups can be specified using generators (:issue:`26816`)::
 
         sage: K.<a> = NumberField(x^6 - 6*x^4 + 9*x^2 + 23)
         sage: G = K.galois_group()
@@ -279,7 +277,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
         You can specify the variable name for the Galois closure::
 
             sage: x = polygen(ZZ, 'x')
-            sage: G = NumberField(x^3 - 2, 'b').galois_group(names="c"); G
+            sage: G = NumberField(x^3 - 2, 'b').galois_group(names='c'); G
             Galois group 3T2 (S3) with order 6 of x^3 - 2
             sage: G._galois_closure
             Number Field in c with defining polynomial x^6 + 108
@@ -296,7 +294,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
             sage: G = F.galois_group()
 
         We test that a method inherited from PermutationGroup_generic returns
-        the right type of element (see :trac:`133`)::
+        the right type of element (see :issue:`133`)::
 
             sage: phi = G.random_element()
             sage: type(phi) is G.element_class
@@ -326,7 +324,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
             sage: G = K.galois_group()
             sage: G._pol_galgp()
             PARI group [6, -1, 2, "S3"] of degree 3
-            sage: G._pol_galgp(algorithm="gap") # optional - gap_packages
+            sage: G._pol_galgp(algorithm='gap') # optional - gap_packages
             Transitive group number 2 of degree 3
         """
         algorithm = self._get_algorithm(algorithm)
@@ -344,7 +342,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
             sage: R.<x> = ZZ[]
             sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^3 + 2*x + 2)
-            sage: G = K.galois_group(type="pari")
+            sage: G = K.galois_group(type='pari')
             ...DeprecationWarning: the different Galois types have been merged into one class
             See https://github.com/sagemath/sage/issues/28782 for details.
             sage: G.group()
@@ -359,7 +357,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
     @cached_method(key=_alg_key)
     def order(self, algorithm=None, recompute=False):
         """
-        Return the order of this Galois group
+        Return the order of this Galois group.
 
         EXAMPLES::
 
@@ -425,7 +423,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
             2
             sage: x = polygen(ZZ, 'x')
             sage: L.<b> = NumberField(x^13 + 2*x + 2)
-            sage: H = L.galois_group(algorithm="gap")
+            sage: H = L.galois_group(algorithm='gap')
             sage: H.transitive_number() # optional - gap_packages
             9
         """
@@ -486,7 +484,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
     @lazy_attribute
     def _gcdata(self):
         """
-        Return the Galois closure, together with the embedding of the top field into it
+        Return the Galois closure, together with the embedding of the top field into it.
 
         EXAMPLES::
 
@@ -575,9 +573,8 @@ class GaloisGroup_v2(GaloisGroup_perm):
         """
         if self._gc_numbering:
             # PARI computes all the elements of self anyway, so we might as well store them
-            return sorted([self(x, check=False) for x in self._pari_data[5]])
-        else:
-            return sorted(list(self.iteration()))
+            return sorted(self(x, check=False) for x in self._pari_data[5])
+        return sorted(self.iteration())
 
     @lazy_attribute
     def _gens(self):
@@ -695,7 +692,7 @@ class GaloisGroup_v2(GaloisGroup_perm):
 
     def _repr_(self):
         r"""
-        String representation of this Galois group
+        String representation of this Galois group.
 
         EXAMPLES::
 
@@ -998,8 +995,8 @@ class GaloisGroup_v2(GaloisGroup_perm):
             sage: K.<b> = NumberField(x^4 - 2*x^2 + 2, 'a').galois_closure()
             sage: G = K.galois_group()
             sage: [G.artin_symbol(P) for P in K.primes_above(7)]
-            [(1,4)(2,3)(5,8)(6,7), (1,4)(2,3)(5,8)(6,7),
-             (1,5)(2,6)(3,7)(4,8), (1,5)(2,6)(3,7)(4,8)]
+            [(1,5)(2,6)(3,7)(4,8), (1,5)(2,6)(3,7)(4,8),
+             (1,4)(2,3)(5,8)(6,7), (1,4)(2,3)(5,8)(6,7)]
             sage: G.artin_symbol(17)
             Traceback (most recent call last):
             ...
@@ -1028,26 +1025,30 @@ class GaloisGroup_v2(GaloisGroup_perm):
             raise ValueError("%s is ramified" % P)
         return t[0]
 
+
 class GaloisGroup_subgroup(GaloisSubgroup_perm):
     r"""
-    A subgroup of a Galois group, as returned by functions such as ``decomposition_group``.
+    A subgroup of a Galois group, as returned by functions such as
+    ``decomposition_group``.
 
     INPUT:
 
     - ``ambient`` -- the ambient Galois group
 
-    - ``gens`` -- a list of generators for the group
+    - ``gens`` -- list of generators for the group
 
     - ``gap_group`` -- a gap or libgap permutation group, or a string
         defining one (default: ``None``)
 
-    - ``domain`` -- a set on which this permutation group acts; extracted from ``ambient`` if not specified
+    - ``domain`` -- set on which this permutation group acts; extracted from
+      ``ambient`` if not specified
 
     - ``category`` -- the category for this object
 
     - ``canonicalize`` -- if ``True``, sorts and removes duplicates
 
-    - ``check`` -- whether to check that generators actually lie in the ambient group
+    - ``check`` -- whether to check that generators actually lie in the
+      ambient group
 
     EXAMPLES::
 
@@ -1074,7 +1075,7 @@ class GaloisGroup_subgroup(GaloisSubgroup_perm):
 
     TESTS:
 
-    Check that :trac:`17664` is fixed::
+    Check that :issue:`17664` is fixed::
 
         sage: L.<c> = QuadraticField(-1)
         sage: P = L.primes_above(5)[0]
@@ -1108,7 +1109,7 @@ class GaloisGroup_subgroup(GaloisSubgroup_perm):
 
         INPUT:
 
-        - ``name`` -- a variable name for the new field.
+        - ``name`` -- a variable name for the new field
 
         - ``polred`` -- whether to optimize the generator of the newly created field
             for a simpler polynomial, using PARI's :pari:`polredbest`.
@@ -1156,7 +1157,7 @@ class GaloisGroup_subgroup(GaloisSubgroup_perm):
             Number Field in ac with defining polynomial x^10 + 10*x^8 + 25*x^6 + 3375
 
         An embedding is returned also if the subgroup is trivial
-        (:trac:`26817`)::
+        (:issue:`26817`)::
 
             sage: H = G.subgroup([])
             sage: H.fixed_field()
@@ -1188,6 +1189,7 @@ class GaloisGroup_subgroup(GaloisSubgroup_perm):
             name = G._field.variable_name() + '0'
         return L.subfield(x, name=name)
 
+
 class GaloisGroupElement(PermutationGroupElement):
     r"""
     An element of a Galois group. This is stored as a permutation, but may also
@@ -1230,7 +1232,7 @@ class GaloisGroupElement(PermutationGroupElement):
         TESTS:
 
         Number fields defined by non-monic and non-integral
-        polynomials are supported (:trac:`252`)::
+        polynomials are supported (:issue:`252`)::
 
             sage: R.<x> = QQ[]
             sage: x = polygen(ZZ, 'x')
@@ -1256,8 +1258,8 @@ class GaloisGroupElement(PermutationGroupElement):
 
     def __call__(self, x):
         r"""
-        Return the action of self on an element x in the number field of self
-        (or its Galois closure).
+        Return the action of ``self`` on an element x in the number field of
+        ``self`` (or its Galois closure).
 
         EXAMPLES::
 
@@ -1292,6 +1294,7 @@ class GaloisGroupElement(PermutationGroupElement):
         w = [(self(g) - g).valuation(P) for g in gens]
         return min(w)
 
+
 GaloisGroup_v2.Element = GaloisGroupElement
 GaloisGroup_v2.Subgroup = GaloisGroup_subgroup
 GaloisGroup_subgroup.Element = GaloisGroupElement
