@@ -1,7 +1,7 @@
 """
 Relative extensions of `p`-adic rings
 
-We represent general extensions of p-adic rings as a two-step extension:
+We represent general extensions of `p`-adic rings as a two-step extension:
 first an unramified extension of Qp, followed by an Eisenstein extension
 of the result.
 
@@ -28,6 +28,7 @@ from .relative_ramified_CR import RelativeRamifiedCappedRelativeElement
 from .relative_ramified_FP import RelativeRamifiedFloatingPointElement
 from .pow_computer_relative import PowComputer_relative_maker
 
+
 class pAdicRelativeBaseringInjection(Morphism):
     """
     The injection of the unramified base into the two-step extension.
@@ -35,10 +36,11 @@ class pAdicRelativeBaseringInjection(Morphism):
     INPUT:
 
     - ``R`` -- an unramified `p`-adic ring or field
-    - ``S`` -- an eisenstein extension of ``R``.
+    - ``S`` -- an eisenstein extension of ``R``
 
     EXAMPLES::
 
+        sage: # needs sage.libs.ntl
         sage: K.<a> = Qq(125)
         sage: R.<x> = K[]
         sage: W.<w> = K.extension(x^3 + 15*a*x - 5*(1+a^2))
@@ -53,6 +55,7 @@ class pAdicRelativeBaseringInjection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(125)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^3 + 15*a*x - 5*(1+a^2))
@@ -72,11 +75,12 @@ class pAdicRelativeBaseringInjection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(125,2)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^3 + 15*a*x - 5*(1+a^2))
             sage: f = W.coerce_map_from(K)
-            sage: f(a+5) # indirect doctest
+            sage: f(a+5)  # indirect doctest
             a + (4*a^2 + 4*a + 3)*w^3 + (a + 2)*w^4 + (2*a^2 + 4*a + 2)*w^5 + O(w^6)
         """
         if x.is_zero():
@@ -91,13 +95,14 @@ class pAdicRelativeBaseringInjection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(125,2)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^3 + 15*a*x - 5*(1+a^2))
             sage: f = W.coerce_map_from(K)
             sage: f(5*a,5)
             (4*a^2 + a + 3)*w^3 + (a^2 + 2*a)*w^4 + O(w^5)
-            sage: f(5*a,8,2) # indirect doctest
+            sage: f(5*a,8,2)  # indirect doctest
             (4*a^2 + a + 3)*w^3 + (a^2 + 2*a)*w^4 + O(w^5)
         """
         return self.codomain()([x], *args, **kwds)
@@ -108,6 +113,7 @@ class pAdicRelativeBaseringInjection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(125,2)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^3 + 15*a*x - 5*(1+a^2))
@@ -118,12 +124,14 @@ class pAdicRelativeBaseringInjection(Morphism):
         """
         return pAdicRelativeBaseringSection(self.codomain(), self.domain())
 
+
 class pAdicRelativeBaseringSection(Morphism):
     """
     The map from a two-step extension back to its maximal unramified subextension.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.ntl
         sage: K.<a> = Qq(2^10)
         sage: R.<x> = K[]
         sage: W.<w> = K.extension(x^4 + 2*a*x^2 - 16*x - 6)
@@ -138,6 +146,7 @@ class pAdicRelativeBaseringSection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(2^10)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^4 + 2*a*x^2 - 16*x - 6*a)
@@ -153,11 +162,12 @@ class pAdicRelativeBaseringSection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(2^10)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^4 + 2*a*x^2 - 16*x - 6*a)
             sage: f = K.convert_map_from(W)
-            sage: f(a + w - w) # indirect doctest
+            sage: f(a + w - w)  # indirect doctest
             a + O(2^20)
             sage: f(w)
             Traceback (most recent call last):
@@ -175,21 +185,24 @@ class pAdicRelativeBaseringSection(Morphism):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: K.<a> = Qq(2^10)
             sage: R.<x> = K[]
             sage: W.<w> = K.extension(x^4 + 2*a*x^2 - 16*x - 6*a)
             sage: f = K.convert_map_from(W)
-            sage: f(a, 5) # indirect doctest
+            sage: f(a, 5)  # indirect doctest
             a + O(2^5)
         """
         return self.codomain()(self._call_(x), *args, **kwds)
 
+
 class RelativeRamifiedExtensionRingFixedMod(EisensteinExtensionGeneric, pAdicFixedModRingGeneric):
     """
     Two-step extension ring with fixed-mod precision.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.flint
         sage: A.<a> = ZqFM(2^10)
         sage: R.<x> = A[]
         sage: W.<w> = A.extension(x^4 + 2*a*x^2 - 16*x - 6*a); W
@@ -203,10 +216,11 @@ class RelativeRamifiedExtensionRingFixedMod(EisensteinExtensionGeneric, pAdicFix
 
         EXAMPLES::
 
+            sage: # needs sage.libs.flint
             sage: A.<a> = ZqFM(5^4)
             sage: R.<x> = A[]
             sage: W.<w> = A.extension(x^3 - 25*(a+1)*x + 10*(a^2+2))
-            sage: TestSuite(W).run(max_samples=16) # long time
+            sage: TestSuite(W).run(max_samples=16)      # long time
         """
         self._exact_modulus = exact_modulus
         unram_prec = (prec + approx_modulus.degree() - 1) // approx_modulus.degree()
@@ -219,12 +233,14 @@ class RelativeRamifiedExtensionRingFixedMod(EisensteinExtensionGeneric, pAdicFix
         self.register_coercion(pAdicRelativeBaseringInjection(approx_modulus.base_ring(), self))
         self.register_conversion(pAdicConvert_QQ_FM(self))
 
+
 class RelativeRamifiedExtensionRingCappedAbsolute(EisensteinExtensionGeneric, pAdicCappedAbsoluteRingGeneric):
     """
     Two-step extension ring with capped absolute precision.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.flint
         sage: A.<a> = ZqCA(2^10)
         sage: R.<x> = A[]
         sage: W.<w> = A.extension(x^4 + 2*a*x^2 - 16*x - 6*a); W
@@ -238,10 +254,11 @@ class RelativeRamifiedExtensionRingCappedAbsolute(EisensteinExtensionGeneric, pA
 
         EXAMPLES::
 
+            sage: # needs sage.libs.flint
             sage: A.<a> = ZqCA(5^4)
             sage: R.<x> = A[]
             sage: W.<w> = A.extension(x^3 - 25*(a+1)*x + 10*(a^2+2))
-            sage: TestSuite(W).run(max_samples=16) # long time
+            sage: TestSuite(W).run(max_samples=16)      # long time
         """
         self._exact_modulus = exact_modulus
         unram_prec = (prec + approx_modulus.degree() - 1) // approx_modulus.degree()
@@ -254,12 +271,14 @@ class RelativeRamifiedExtensionRingCappedAbsolute(EisensteinExtensionGeneric, pA
         self.register_coercion(pAdicRelativeBaseringInjection(approx_modulus.base_ring(), self))
         self.register_conversion(pAdicConvert_QQ_CA(self))
 
+
 class RelativeRamifiedExtensionRingCappedRelative(EisensteinExtensionGeneric, pAdicCappedRelativeRingGeneric):
     """
     Two-step extension ring with capped relative precision.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.ntl
         sage: A.<a> = ZqCR(2^10)
         sage: R.<x> = A[]
         sage: W.<w> = A.extension(x^4 + 2*a*x^2 - 16*x - 6*a); W
@@ -273,10 +292,11 @@ class RelativeRamifiedExtensionRingCappedRelative(EisensteinExtensionGeneric, pA
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: A.<a> = ZqCR(5^4)
             sage: R.<x> = A[]
             sage: W.<w> = A.extension(x^3 - 25*(a+1)*x + 10*(a^2+2))
-            sage: TestSuite(W).run(max_samples=16) # long time
+            sage: TestSuite(W).run(max_samples=16)      # long time
         """
         self._exact_modulus = exact_modulus
         unram_prec = (prec + approx_modulus.degree() - 1) // approx_modulus.degree()
@@ -289,12 +309,14 @@ class RelativeRamifiedExtensionRingCappedRelative(EisensteinExtensionGeneric, pA
         self.register_coercion(pAdicRelativeBaseringInjection(approx_modulus.base_ring(), self))
         self.register_conversion(pAdicConvert_QQ_CR(self))
 
+
 class RelativeRamifiedExtensionFieldCappedRelative(EisensteinExtensionGeneric, pAdicCappedRelativeFieldGeneric):
     """
     Two-step extension field with capped relative precision.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.ntl
         sage: A.<a> = QqCR(2^10)
         sage: R.<x> = A[]
         sage: W.<w> = A.extension(x^4 + 2*a*x^2 - 16*x - 6*a); W
@@ -308,10 +330,11 @@ class RelativeRamifiedExtensionFieldCappedRelative(EisensteinExtensionGeneric, p
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: A.<a> = QqCR(5^4)
             sage: R.<x> = A[]
             sage: W.<w> = A.extension(x^3 - 25*(a+1)*x + 10*(a^2+2))
-            sage: TestSuite(W).run(max_samples=16) # long time
+            sage: TestSuite(W).run(max_samples=16)      # long time
         """
         self._exact_modulus = exact_modulus
         unram_prec = (prec + approx_modulus.degree() - 1) // approx_modulus.degree()
@@ -326,12 +349,14 @@ class RelativeRamifiedExtensionFieldCappedRelative(EisensteinExtensionGeneric, p
         self.register_coercion(pAdicRelativeBaseringInjection(approx_modulus.base_ring().integer_ring(), self))
         self.register_coercion(pAdicCoercion_QQ_CR(self))
 
+
 class RelativeRamifiedExtensionRingFloatingPoint(EisensteinExtensionGeneric, pAdicFloatingPointRingGeneric):
     """
     Two-step extension ring with floating point precision.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.flint
         sage: A.<a> = ZqFP(2^10)
         sage: R.<x> = A[]
         sage: W.<w> = A.extension(x^4 + 2*a*x^2 - 16*x - 6*a); W
@@ -345,10 +370,11 @@ class RelativeRamifiedExtensionRingFloatingPoint(EisensteinExtensionGeneric, pAd
 
         EXAMPLES::
 
+            sage: # needs sage.libs.flint
             sage: A.<a> = ZqFP(5^4)
             sage: R.<x> = A[]
             sage: W.<w> = A.extension(x^3 - 25*(a+1)*x + 10*(a^2+2))
-            sage: TestSuite(W).run(max_samples=16) # long time
+            sage: TestSuite(W).run(max_samples=16)      # long time
         """
         self._exact_modulus = exact_modulus
         unram_prec = (prec + approx_modulus.degree() - 1) // approx_modulus.degree()
@@ -361,12 +387,14 @@ class RelativeRamifiedExtensionRingFloatingPoint(EisensteinExtensionGeneric, pAd
         self.register_coercion(pAdicRelativeBaseringInjection(approx_modulus.base_ring(), self))
         self.register_conversion(pAdicConvert_QQ_FP(self))
 
+
 class RelativeRamifiedExtensionFieldFloatingPoint(EisensteinExtensionGeneric, pAdicFloatingPointFieldGeneric):
     """
     Two-step extension field with floating point precision.
 
     EXAMPLES::
 
+        sage: # needs sage.libs.flint
         sage: A.<a> = QqFP(2^10)
         sage: R.<x> = A[]
         sage: W.<w> = A.extension(x^4 + 2*a*x^2 - 16*x - 6*a); W
@@ -380,10 +408,11 @@ class RelativeRamifiedExtensionFieldFloatingPoint(EisensteinExtensionGeneric, pA
 
         EXAMPLES::
 
+            sage: # needs sage.libs.flint
             sage: A.<a> = QqFP(5^4)
             sage: R.<x> = A[]
             sage: W.<w> = A.extension(x^3 - 25*(a+1)*x + 10*(a^2+2))
-            sage: TestSuite(W).run(max_samples=16) # long time
+            sage: TestSuite(W).run(max_samples=16)      # long time
         """
         self._exact_modulus = exact_modulus
         unram_prec = (prec + approx_modulus.degree() - 1) // approx_modulus.degree()
