@@ -27,16 +27,16 @@ from sage.rings.infinity import Infinity, MinusInfinity, PlusInfinity
 
 class IntegerRange(UniqueRepresentation, Parent):
     r"""
-    The class of :class:`Integer <sage.rings.integer.Integer>` ranges
+    The class of :class:`Integer <sage.rings.integer.Integer>` ranges.
 
     Returns an enumerated set containing an arithmetic progression of integers.
 
     INPUT:
 
-    - ``begin``        -- an integer, Infinity or -Infinity
-    - ``end``          -- an integer, Infinity or -Infinity
-    - ``step``         -- a non zero integer (default to 1)
-    - ``middle_point`` -- an integer inside the set (default to ``None``)
+    - ``begin`` -- integer, Infinity or -Infinity
+    - ``end`` -- integer, Infinity or -Infinity
+    - ``step`` -- a nonzero integer (default: 1)
+    - ``middle_point`` -- integer inside the set (default: ``None``)
 
     OUTPUT:
 
@@ -156,7 +156,7 @@ class IntegerRange(UniqueRepresentation, Parent):
         [0, 10, -10, 20, -20, 30, -30, 40, -40, 50, -50, 60, -60, 70, -70, 80, -80, 90, -90, -100]
 
 
-    .. note::
+    .. NOTE::
 
        The input is normalized so that::
 
@@ -201,7 +201,7 @@ class IntegerRange(UniqueRepresentation, Parent):
         ....:         L2.sort()
         ....:         assert L1 == L2
 
-    Thanks to :trac:`8543` empty integer range are allowed::
+    Thanks to :issue:`8543` empty integer range are allowed::
 
         sage: TestSuite(IntegerRange(0, 5, -1)).run()
     """
@@ -217,7 +217,7 @@ class IntegerRange(UniqueRepresentation, Parent):
             ValueError: IntegerRange() step argument must not be zero
             sage: IntegerRange(2) is IntegerRange(0, 2)
             True
-            sage: IntegerRange(1.0)
+            sage: IntegerRange(1.0)                                                     # needs sage.rings.real_mpfr
             Traceback (most recent call last):
             ...
             TypeError: end must be Integer or Infinity, not <... 'sage.rings.real_mpfr.RealLiteral'>
@@ -290,7 +290,7 @@ class IntegerRange(UniqueRepresentation, Parent):
 
 class IntegerRangeEmpty(IntegerRange, FiniteEnumeratedSet):
     r"""
-    A singleton class for empty integer ranges
+    A singleton class for empty integer ranges.
 
     See :class:`IntegerRange` for more details.
     """
@@ -338,7 +338,7 @@ class IntegerRangeFinite(IntegerRange):
 
     def __contains__(self, elt):
         r"""
-        Returns True if ``elt`` is in ``self``.
+        Return ``True`` if ``elt`` is in ``self``.
 
         EXAMPLES::
 
@@ -373,7 +373,7 @@ class IntegerRangeFinite(IntegerRange):
 
     def cardinality(self):
         """
-        Return the cardinality of ``self``
+        Return the cardinality of ``self``.
 
         EXAMPLES::
 
@@ -384,7 +384,7 @@ class IntegerRangeFinite(IntegerRange):
             sage: IntegerRange(123,12,4).cardinality()
             0
         """
-        return (abs((self._end+self._step-self._begin))-1) // abs(self._step)
+        return (abs(self._end+self._step-self._begin)-1) // abs(self._step)
 
     def _repr_(self):
         """
@@ -482,7 +482,7 @@ class IntegerRangeFinite(IntegerRange):
 
     def __iter__(self):
         r"""
-        Returns an iterator over the elements of ``self``
+        Return an iterator over the elements of ``self``.
 
         EXAMPLES::
 
@@ -507,7 +507,7 @@ class IntegerRangeFinite(IntegerRange):
 
     def _an_element_(self):
         r"""
-        Returns an element of ``self``.
+        Return an element of ``self``.
 
         EXAMPLES::
 
@@ -564,7 +564,7 @@ class IntegerRangeInfinite(IntegerRange):
 
     def __contains__(self, elt):
         r"""
-        Returns True if ``elt`` is in ``self``.
+        Return ``True`` if ``elt`` is in ``self``.
 
         EXAMPLES::
 
@@ -608,7 +608,7 @@ class IntegerRangeInfinite(IntegerRange):
 
     def __getitem__(self, i):
         r"""
-        Returns the ``i``-th element of self.
+        Return the ``i``-th element of ``self``.
 
         EXAMPLES::
 
@@ -633,7 +633,7 @@ class IntegerRangeInfinite(IntegerRange):
 
     def __iter__(self):
         r"""
-        Returns an iterator over the elements of ``self``.
+        Return an iterator over the elements of ``self``.
 
         EXAMPLES::
 
@@ -654,7 +654,7 @@ class IntegerRangeInfinite(IntegerRange):
 
     def _an_element_(self):
         r"""
-        Returns an element of ``self``.
+        Return an element of ``self``.
 
         EXAMPLES::
 
@@ -725,7 +725,7 @@ class IntegerRangeFromMiddle(IntegerRange):
 
     def __contains__(self, elt):
         r"""
-        Returns True if ``elt`` is in ``self``.
+        Return ``True`` if ``elt`` is in ``self``.
 
         EXAMPLES::
 
@@ -792,7 +792,7 @@ class IntegerRangeFromMiddle(IntegerRange):
 
     def __iter__(self):
         r"""
-        Returns an iterator over the elements of ``self``.
+        Return an iterator over the elements of ``self``.
 
         EXAMPLES::
 
@@ -813,7 +813,7 @@ class IntegerRangeFromMiddle(IntegerRange):
 
     def _an_element_(self):
         r"""
-        Returns an element of ``self``.
+        Return an element of ``self``.
 
         EXAMPLES::
 
