@@ -625,7 +625,7 @@ class TopMostParentPolicy(SetFactoryPolicy):
     INPUT:
 
     - ``factory`` -- an instance of :class:`SetFactory`
-    - ``top_constraints`` -- the empty set of constraints.
+    - ``top_constraints`` -- the empty set of constraints
     - ``Element`` -- a subclass of :class:`~.element.Element`
 
     Given a factory ``F`` and a class ``E``, returns a policy for
@@ -871,9 +871,9 @@ class ParentWithSetFactory(Parent):
 
     INPUT:
 
-    - ``constraints`` -- a set of constraints
+    - ``constraints`` -- set of constraints
     - ``policy`` -- the policy for element construction
-    - ``category`` -- the category of the parent (default to ``None``)
+    - ``category`` -- the category of the parent (default: ``None``)
 
     Depending on the constraints and the policy, initialize the parent
     in a proper category to set up element construction.
@@ -1018,8 +1018,7 @@ class ParentWithSetFactory(Parent):
 
     def _test_subset(self, **options):
         r"""
-        Tests that subsets with no extra parameters returns
-        ``self``.
+        Test that subsets with no extra parameters returns ``self``.
 
         Currently, only the test that one gets the same parent when no
         more constraints are given, is performed.
@@ -1045,10 +1044,10 @@ class ParentWithSetFactory(Parent):
 
         INPUT:
 
-        - ``x`` -- an instance of ``self.element_class``.
+        - ``x`` -- an instance of ``self.element_class``
 
         - ``check`` -- the level of checking to be performed (usually a
-          boolean).
+          boolean)
 
         This method may assume that ``x`` was properly constructed by
         ``self`` or a possible super-set of ``self`` for which
