@@ -80,11 +80,11 @@ def normalize_prob_list(pl, extra=()):
     r"""
     INPUT:
 
-    - ``pl`` -- A list of tuples, where the first element of each tuple is
+    - ``pl`` -- list of tuples, where the first element of each tuple is
       a floating-point number (representing a relative probability).  The
       second element of each tuple may be a list or any other kind of object.
 
-    - ``extra`` -- A tuple which is to be appended to every tuple in ``pl``.
+    - ``extra`` -- tuple which is to be appended to every tuple in ``pl``
 
     This function takes such a list of tuples (a "probability list") and
     normalizes the probabilities so that they sum to one.  If any of the
@@ -131,9 +131,9 @@ def choose_from_prob_list(lst):
     r"""
     INPUT:
 
-    - ``lst`` -- A list of tuples, where the first element of each tuple
+    - ``lst`` -- list of tuples, where the first element of each tuple
       is a nonnegative float (a probability), and the probabilities sum
-      to one.
+      to one
 
     OUTPUT:
 
@@ -250,7 +250,6 @@ def random_expr_helper(n_nodes, internal, leaves, verbose):
         sage: our_exprs = set()
         sage: while our_exprs != all_exprs:
         ....:    our_exprs.add(next_expr())
-
     """
     if n_nodes == 1:
         return choose_from_prob_list(leaves)[1]
@@ -259,8 +258,7 @@ def random_expr_helper(n_nodes, internal, leaves, verbose):
         n_nodes -= 1
         n_children = r[2]
         n_spare_nodes = n_nodes - n_children
-        if n_spare_nodes <= 0:
-            n_spare_nodes = 0
+        n_spare_nodes = max(0, n_spare_nodes)
         nodes_per_child = random_integer_vector(n_spare_nodes, n_children)
         children = [random_expr_helper(n + 1, internal, leaves, verbose)
                     for n in nodes_per_child]
@@ -311,7 +309,6 @@ def random_expr(size, nvars=1, ncoeffs=None, var_frac=0.5,
         About to apply sgn to [v1]
         About to apply <built-in function add> to [1/31, sgn(v1)]
         sgn(v1) + 1/31
-
     """
     vars = [(1.0, SR.var('v%d' % (n + 1))) for n in range(nvars)]
     if ncoeffs is None:
@@ -349,14 +346,14 @@ def assert_strict_weak_order(a, b, c, cmp_func):
 
     INPUT:
 
-    - ``a``, ``b``, ``c`` -- anything that can be compared by ``cmp_func``.
+    - ``a``, ``b``, ``c`` -- anything that can be compared by ``cmp_func``
 
     - ``cmp_func`` -- function of two arguments that returns their
-      comparison (i.e. either ``True`` or ``False``).
+      comparison (i.e. either ``True`` or ``False``)
 
     OUTPUT:
 
-    Does not return anything. Raises a ``ValueError`` if ``cmp_func``
+    Nothing. Raises a :exc:`ValueError` if ``cmp_func``
     is not a strict weak order on the three given elements.
 
     REFERENCES:
@@ -423,7 +420,7 @@ def assert_strict_weak_order(a, b, c, cmp_func):
 
 def test_symbolic_expression_order(repetitions=100):
     r"""
-    Tests whether the comparison of random symbolic expressions
+    Test whether the comparison of random symbolic expressions
     satisfies the strict weak order axioms.
 
     This is important because the C++ extension class uses
